class Spellbook():
    # NLU model_base_names =
    # These reference tell NLU to which component resolved to route a request, they help NLU map a NLP reference to the correct class
    word_embeddings = ['embed', 'bert', 'electra', 'albert', 'elmo', 'glove', 'xlnet', 'biobert', 'covidbert',
                       'tfhub_use', 'distil', 'xlm.py','roberta']
    sentence_embeddings = ['embed_sentence', 'use', 'bert', 'electra', 'tfhub_use']
    classifiers = ['classify', 'e2e', 'emotion', 'sentiment', 'ner',
                   'pos', 'trec6', 'trec50', 'questions',
                   'sarcasm', 'emotion', 'spam', 'fakenews', 'cyberbullying',
                   'wiki', 'wiki_7', 'wiki_20', 'yake', 'toxic',
                   'assert', 'med_ner'
                   ]
    seq2seq = ['t5', 'marian', 'translate_to']
    actions = ['tokenize', 'sentence', 'embed', 'embed_sentence', 'embed_chunk', 'classify', 'chunk', 'pos', 'ner',
               'dep', 'dep.untyped', 'lemma', 'match', 'norm', 'spell', 'stem', 'stopwords', 'clean', 'ngram',
               'translate_to',

               ]
    trainable_model_references = ['classifier_dl']

    '''
    NLU REFERENCE FORMATS : 
    <lang>.<action>.<
    '''
    trainable_models = {
        # 1 clasifier wraps iuip multiple algos (multi class/class/sentiment)
        # Columns should be X and y, ML style
        #
        # map NLU references to NLP approaches
        'train.deep_sentence_detector': '',
        'train.sentence_detector': '',  # deep sentence detector alias
        'train.symmetric_spell': '',
        'train.context_spell': '',
        'train.spell': '',  ## context spell alias
        'train.norvig_spell': '',
        'train.unlabeled_dependency_parser': '',
        'train.labeled_dependency_parser': '',
        'train.classifier_dl': '',
        'train.classifier': '',  # classifier DL alias
        'train.named_entity_recognizer_dl': '',
        'train.ner': '',  # ner DL alias
        'train.vivekn_sentiment': '',
        'train.sentiment_dl': '',
        'train.sentiment': '',  # sent DL alias
        'train.pos': '',
        'train.multi_classifier': '',
        'train.generic_classifier': '',
        'train.resolve_chunks': '',
        'train.resolve_sentence': '',
        'train.resolve': '',

    }

    # Reference to all datasets for which we have pretrained models
    datasets = []
    chunk_embeddings = ['embed_sentence']
    # The vocabulary of the nlu Namespace. Any of this references give you a model
    # keys inside a language dict are NLU references and value is the name in SparkNLP

    component_alias_references = {
        # references for SparkNLPAnnotators without pretrained models.
        #  These are names for NLU components that can be created withouth a language prefix

        # multi lang pipes
        'lang': ('detect_language_375', 'pipe'),  # multi lang alias
        'lang.7': ('detect_language_7', 'pipe'),  # multi lang detector alias
        'lang.20': ('detect_language_20', 'pipe'),  # multi lang detector alias
        'lang.21': ('detect_language_21', 'pipe'),
        'lang.43': ('detect_language_43', 'pipe'),
        'lang.95': ('detect_language_95', 'pipe'),
        'lang.99': ('detect_language_99', 'pipe'),
        'lang.220': ('detect_language_220', 'pipe'),
        'lang.231': ('detect_language_231', 'pipe'),

        # Aliases
        'classify.lang': ('detect_language_375', 'pipe'),  # multi lang detector default
        'classify.lang.7': ('detect_language_7', 'pipe'),  # multi lang detector alias
        'classify.lang.20': ('detect_language_20', 'pipe'),  # multi lang detector alias
        'classify.lang.21': ('detect_language_21', 'pipe'),
        'classify.lang.43': ('detect_language_43', 'pipe'),
        'classify.lang.95': ('detect_language_95', 'pipe'),
        'classify.lang.99': ('detect_language_99', 'pipe'),
        'classify.lang.220': ('detect_language_220', 'pipe'),
        'classify.lang.231': ('detect_language_231', 'pipe'),

        # eng pipes
        'classify': ('analyze_sentiment', 'pipe'),  # default classifier
        'explain': ('explain_document_ml', 'pipe'),  # default explain
        'explain.ml': ('explain_document_ml', 'pipe'),
        'explain.dl': ('explain_document_dl', 'pipe'),
        'ner.conll': ('recognize_entities_dl', 'pipe'),  # default ner
        'ner.dl': ('recognize_entities_dl', 'pipe'),
        'ner.bert': ('recognize_entities_bert', 'pipe'),
        'ner': ('onto_recognize_entities_sm', 'pipe'),  # default  ner.onto
        'ner.onto': ('onto_recognize_entities_sm', 'pipe'),  # default  ner.onto
        'ner.onto.sm': ('onto_recognize_entities_sm', 'pipe'),
        'ner.onto.lg': ('onto_recognize_entities_lg', 'pipe'),
        'match.datetime': ('match_datetime', 'pipe'),

        'match.text': ('text_matcher', 'model'),
        'match.regex': ('regex_matcher', 'model'),
        'match.date': ('date_matcher', 'model'),
        'match.context': ('context_parser', 'model'), #  TODOLicensed!!
        # 'context_parser': ('context_parser', 'model'),

        'match.pattern': ('match_pattern', 'pipe'),
        'match.chunks': ('match_chunks', 'pipe'),
        'match.phrases': ('match_phrases', 'pipe'),
        'clean.stop': ('clean_stop', 'pipe'),
        'clean.pattern': ('clean_pattern', 'pipe'),
        'clean.slang': ('clean_slang', 'pipe'),
        # 'spell': ('check_spelling','pipe'),  # bad spell_checker,
        'spell': ('spellcheck_dl', 'model'),  # default spell
        'sentiment': ('sentimentdl_glove_imdb', 'model'),
        'emotion': ('classifierdl_use_emotion', 'model'),  # default emotion model

        'sentiment.imdb': ('analyze_sentimentdl_use_imdb', 'pipe'),
        'sentiment.imdb.use': ('analyze_sentimentdl_use_imdb', 'pipe'),
        'sentiment.twitter.use': ('analyze_sentimentdl_use_twitter', 'pipe'),
        'sentiment.twitter': ('analyze_sentimentdl_use_twitter', 'pipe'),
        'dependency': ('dependency_parse', 'pipe'),

        'tokenize': ('spark_nlp_tokenizer', 'model'),  # tokenizer rule based model
        'stem': ('stemmer', 'model'),  # stem rule based model
        'norm': ('normalizer', 'model'),  # rule based model
        'norm_document': ('normalizer', 'model'),  # rule based model

        'chunk': ('default_chunker', 'model'),  # rule based model
        'embed_chunk': ('chunk_embeddings', 'model'),  # rule based model
        'ngram': ('ngram', 'model'),  # rule based model

        'lemma': ('lemma_antbnc', 'model'),  # lemma default en
        'lemma.antbnc': ('lemma_antbnc', 'model'),
        'pos': ('pos_anc', 'model'),  # pos default en
        'pos.anc': ('pos_anc', 'model'),
        'pos.ud_ewt': ('pos_ud_ewt', 'model'),
        # 'ner.crf' :'ner_crf', # crf not supported in NLU
        'ner.dl.glove.6B_100d': ('ner_dl', 'model'),
        'ner.dl.bert': ('ner_dl_bert', 'model'),  # points ner bert
        'ner.onto.glove.6B_100d': ('onto_100', 'model'),
        'ner.onto.glove.6B_300d': ('onto_300', 'model'),  # this uses multi lang embeds!
        'sentence_detector': ('sentence_detector_dl', 'model'),
        'sentence_detector.deep': ('sentence_detector_dl', 'model'),  # ALIAS

        'sentence_detector.pragmatic': ('pragmatic_sentence_detector', 'model'),  # todo

        'spell.symmetric': ('spellcheck_sd', 'model'), # TODO erronous
        'spell.norivg': ('spellcheck_norvig', 'model'),
        'sentiment.vivekn': ('sentiment_vivekn', 'model'),
        'dep.untyped.conllu': ('dependency_conllu', 'model'),
        'dep.untyped': ('dependency_conllu.untyped', 'model'),  # default untyped dependency
        'dep': ('dependency_typed_conllu', 'model'),  # default typed dependency
        'dep.typed': ('dependency_typed_conllu', 'model'),  # default typed dependency dataset
        'dep.typed.conllu': ('dependency_typed_conllu', 'model'),
        'stopwords': ('stopwords_en', 'model'),

        # embeddings models
        'embed': ('glove_100d', 'model'),  # default overall embed
        'glove': ('glove_100d', 'model'),  # default glove
        'embed.glove': ('glove_100d', 'model'),  # default glove en
        'embed.glove.100d': ('glove_100d', 'model'),
        'bert': ('small_bert_L2_128', 'model'),  # default bert
        'covidbert': ('covidbert_large_uncased', 'model'),

        'embed.bert': ('bert_base_uncased', 'model'),  # default bert
        'embed.bert_base_uncased': ('bert_base_u`ncased', 'model'),
        'embed.bert_base_cased': ('bert_base_cased', 'model'),
        'embed.bert_large_uncased': ('bert_large_uncased', 'model'),
        'embed.bert_large_cased': ('bert_large_cased', 'model'),
        'biobert': ('biobert_pubmed_base_cased', 'model'),  # alias
        'embed.biobert': ('biobert_pubmed_base_cased', 'model'),  # default bio bert
        'embed.biobert_pubmed_base_cased': ('biobert_pubmed_base_cased', 'model'),
        'embed.biobert_pubmed_large_cased': ('biobert_pubmed_large_cased', 'model'),
        'embed.biobert_pmc_base_cased': ('biobert_pmc_base_cased', 'model'),
        'embed.biobert_pubmed_pmc_base_cased': ('biobert_pubmed_pmc_base_cased', 'model'),
        'embed.biobert_clinical_base_cased': ('biobert_clinical_base_cased', 'model'),
        'embed.biobert_discharge_base_cased': ('biobert_discharge_base_cased', 'model'),
        'elmo': ('elmo', 'model'),

        'embed.electra': ('electra_small_uncased', 'model'),
        'electra': ('electra_small_uncased', 'model'),
        'e2e': ('multiclassifierdl_use_e2e', 'model'),

        'embed.elmo': ('elmo', 'model'),
        'embed_sentence': ('tfhub_use', 'model'),  # default use
        'embed_sentence.small_bert_L2_128': ('sent_small_bert_L2_128', 'model'),
        'embed_sentence.bert': ('sent_small_bert_L2_128', 'model'),
        'embed_sentence.electra': ('sent_electra_small_uncased', 'model'),

        'embed_sentence.use': ('tfhub_use', 'model'),  # default use
        'use': ('tfhub_use', 'model'),  # alias
        'embed_sentence.tfhub_use': ('tfhub_use', 'model'),
        'embed_sentence.use_lg': ('tfhub_use_lg', 'model'),  # alias
        'embed_sentence.tfhub_use_lg': ('tfhub_use_lg', 'model'),
        'albert': ('albert_base_uncased', 'model'),  # albert alias en
        'embed.albert_base_uncased': ('albert_base_uncased', 'model'),
        'embed.albert_large_uncased': ('albert_large_uncased', 'model'),
        'embed.albert_xlarge_uncased': ('albert_xlarge_uncased', 'model'),
        'embed.albert_xxlarge_uncased': ('albert_xxlarge_uncased', 'model'),
        'embed.xlnet': ('xlnet_base_cased', 'model'),  # xlnet default en
        'xlnet': ('xlnet_base_cased', 'model'),  # xlnet alias
        'embed.xlnet_base_cased': ('xlnet_base_cased', 'model'),
        'embed.xlnet_large_cased': ('xlnet_large_cased', 'model'),

        # classifiers and sentiment models
        'classify.trec6.use': ('classifierdl_use_trec6', 'model'),
        'classify.trec50.use': ('classifierdl_use_trec50', 'model'),
        'classify.questions': ('classifierdl_use_trec50', 'model'),
        'questions': ('classifierdl_use_trec50', 'model'),

        'classify.spam.use': ('classifierdl_use_spam', 'model'),
        'classify.fakenews.use': ('classifierdl_use_fakenews', 'model'),
        'classify.emotion.use': ('classifierdl_use_emotion', 'model'),
        'classify.cyberbullying.use': ('classifierdl_use_cyberbullying', 'model'),
        'classify.sarcasm.use': ('classifierdl_use_sarcasm', 'model'),
        'sentiment.imdb.glove': ('sentimentdl_glove_imdb', 'model'),
        'classify.trec6': ('classifierdl_use_trec6', 'model'),  # Alias withouth embedding
        'classify.trec50': ('classifierdl_use_trec50', 'model'),  # Alias withouth embedding
        'classify.spam': ('classifierdl_use_spam', 'model'),  # Alias withouth embedding
        'spam': ('classifierdl_use_spam', 'model'),  # Alias withouth embedding
        'toxic': ('multiclassifierdl_use_toxic', 'model'),

        'classify.fakenews': ('classifierdl_use_fakenews', 'model'),  # Alias withouth embedding
        'classify.emotion': ('classifierdl_use_emotion', 'model'),  # Alias withouth embedding
        'classify.cyberbullying': ('classifierdl_use_cyberbullying', 'model'),  # Alias withouth embedding
        'cyberbullying': ('classifierdl_use_cyberbullying', 'model'),  # Alias withouth embedding

        'classify.sarcasm': ('classifierdl_use_sarcasm', 'model'),  # Alias withouth embedding
        'sarcasm': ('classifierdl_use_sarcasm', 'model'),  # Alias withouth embedding

        'embed.glove.840B_300': ('glove_840B_300', 'model'),
        'embed.glove.6B_300': ('glove_6B_300', 'model'),
        'embed.bert_multi_cased': ('bert_multi_cased', 'model'),
        'classify.wiki_7': ('ld_wiki_7', 'model'),
        'classify.wiki_20': ('ld_wiki_20', 'model'),
        'yake': ('yake', 'model'),

        # 2.7.0 new aliases
        't5.summarize': ('t5_base', 'model'),
        't5.classify.grammar_correctness': ('t5_base', 'model'),
        't5.classify.sentiment': ('t5_base', 'model'),
        't5.answer_question': ('t5_base', 'model'),

        # 2.7.0 new aliases
        't5': ('t5_base', 'model'),
        'summarize': ('t5_base', 'model', 'summarize', 't5'),
        'grammar_correctness': ('t5_base', 'model', 'grammar_correctness', 't5'),
        'answer_question': ('t5_base', 'model', 'answer_question', 't5'),
        # 'classify.sentiment': ('t5_base','model'),

    }
    # multi lang models
    pretrained_pipe_references = {

        'da': {
            'da.explain': 'explain_document_sm',
            'da.explain.sm': 'explain_document_sm',
            'da.explain.md': 'explain_document_md',
            'da.explain.lg': 'explain_document_lg',
            'da.ner': 'entity_recognizer_sm',
            'da.ner.sm': 'entity_recognizer_sm',
            'da.ner.md': 'entity_recognizer_md',
            'da.ner.lg': 'entity_recognizer_lg'},

        'nl': {
            'nl.explain': 'explain_document_sm',  # default
            'nl.explain.sm': 'explain_document_sm',
            'nl.explain.md': 'explain_document_md',
            'nl.explain.lg': 'explain_document_lg',
            'nl.ner': 'entity_recognizer_sm',
            # default,calling it nl.ner this makes creating actual NER object impossible!
            'nl.ner.sm': 'entity_recognizer_sm',
            'nl.ner.md': 'entity_recognizer_md',
            'nl.ner.lg': 'entity_recognizer_lg',
        },
        'en': {

            'en.classify': 'analyze_sentiment',  # default classifier
            'en.explain': 'explain_document_ml',  # default explain
            'en.explain.ml': 'explain_document_ml',
            'en.explain.dl': 'explain_document_dl',
            'en.ner': 'recognize_entities_dl',  # default ner
            'en.ner.conll': 'recognize_entities_dl',  # default ner

            'en.ner.dl': 'recognize_entities_dl',
            'en.ner.bert': 'recognize_entities_bert',
            # 'en.ner.onto': 'onto_recognize_entities_sm',  # default  ner.onto
            'en.ner.onto.sm': 'onto_recognize_entities_sm',
            'en.ner.onto.lg': 'onto_recognize_entities_lg',
            'en.match.datetime': 'match_datetime',
            'en.match.pattern': 'match_pattern',
            'en.match.chunks': 'match_chunks',
            'en.match.phrases': 'match_phrases',
            'en.clean.stop': 'clean_stop',
            'en.clean.pattern': 'clean_pattern',
            'en.clean.slang': 'clean_slang',
            'en.spell': 'check_spelling_dl',  # dfault spell

            'en.spell.dl': 'check_spelling_dl',
            'en.spell.context': 'check_spelling_dl',
            'en.sentiment': 'analyze_sentiment',
            'en.classify.sentiment': 'analyze_sentiment',

            'en.sentiment.imdb': 'analyze_sentimentdl_use_imdb',
            'en.sentiment.imdb.use': 'analyze_sentimentdl_use_imdb',
            # 'en.sentiment.twitter.use': 'analyze_sentimentdl_use_twitter',
            'en.sentiment.twitter': 'analyze_sentimentdl_use_twitter',
            'en.dependency': 'dependency_parse',

            # 2.7
            'en.ner.onto.bert.base': 'onto_recognize_entities_bert_base',
            'en.ner.onto.bert.large': 'onto_recognize_entities_bert_large',
            'en.ner.onto.bert.medium': 'onto_recognize_entities_bert_medium',
            'en.ner.onto.bert.mini': 'onto_recognize_entities_bert_mini',
            'en.ner.onto.bert.small': 'onto_recognize_entities_bert_small',
            'en.ner.onto.bert.tiny': 'onto_recognize_entities_bert_tiny',
            'en.ner.onto.electra.base': 'onto_recognize_entities_electra_base',
            'en.ner.onto.electra.small': 'onto_recognize_entities_electra_small',

            # 2.7.1 and 2.7.2
            "en.sentiment.glove": "analyze_sentimentdl_glove_imdb",
            "en.sentiment.glove.imdb": "analyze_sentimentdl_glove_imdb",
            "en.classify.sentiment.glove.imdb": "analyze_sentimentdl_glove_imdb",
            "en.classify.sentiment.glove": "analyze_sentimentdl_glove_imdb",
            "en.classify.trec50.pipe": "classifierdl_use_trec50_pipeline",
            "en.ner.onto.large": "onto_recognize_entities_electra_large",

        },
        'fa':{
            'fa.ner.dl' : '	recognize_entities_dl',
        },
        'he':{
            'he.explain_document' : '	explain_document_lg',
            'he.explain_document.lg' : '	explain_document_lg',
        },
        'ko':{
            'ko.explain_document' : '	explain_document_lg',
            'ko.explain_document.lg' : '	explain_document_lg',

        },
        'sv': {
            'sv.explain': 'explain_document_sm',
            'sv.explain.sm': 'explain_document_sm',
            'sv.explain.md': 'explain_document_md',
            'sv.explain.lg': 'explain_document_lg',
            'sv.ner': 'entity_recognizer_sm',
            'sv.ner.sm': 'entity_recognizer_sm',
            'sv.ner.md': 'entity_recognizer_md',
            'sv.ner.lg': 'entity_recognizer_lg'},

        'fi': {
            'fi.explain': 'explain_document_sm',
            'fi.explain.sm': 'explain_document_sm',
            'fi.explain.md': 'explain_document_md',
            'fi.explain.lg': 'explain_document_lg',
            'fi.ner': 'entity_recognizer_sm',
            'fi.ner.sm': 'entity_recognizer_sm',
            'fi.ner.md': 'entity_recognizer_md',
            'fi.ner.lg': 'entity_recognizer_lg'},

        'fr': {
            'fr.explain': 'explain_document_lg',  # default fr explain
            'fr.explain.lg': 'explain_document_lg',
            'fr.explain.md': 'explain_document_md',
            'fr.ner': 'entity_recognizer_lg',  # default fr ner pipe
            'fr.ner.lg': 'entity_recognizer_lg',
            'fr.ner.md': 'entity_recognizer_md',
        },
        'de': {
            'de.explain.document': 'explain_document_md',  # default de explain
            'de.explain.document.md': 'explain_document_md',
            'de.explain.document.lg': 'explain_document_lg',
            'de.ner.recognizer': 'entity_recognizer_md',  # default de ner
            'de.ner.recognizer.md': 'entity_recognizer_md',
            'de.ner.recognizer.lg': 'entity_recognizer_lg',
        },
        'it': {
            'it.explain.document': 'explain_document_md',  # it default explain
            'it.explain.document.md': 'explain_document_md',
            'it.explain.document.lg': 'explain_document_lg',
            'it.ner': 'entity_recognizer_md',  # it default ner
            'it.ner.md': 'entity_recognizer_md',
            'it.ner.lg': 'entity_recognizer_lg',
        },
        'no': {
            'no.explain': 'explain_document_sm',  # default no explain
            'no.explain.sm': 'explain_document_sm',
            'no.explain.md': 'explain_document_md',
            'no.explain.lg': 'explain_document_lg',
            'no.ner': 'entity_recognizer_sm',  # default no ner
            'no.ner.sm': 'entity_recognizer_sm',
            'no.ner.md': 'entity_recognizer_md',
            'no.ner.lg': 'entity_recognizer_lg',
        },
        'pl': {
            'pl.explain': 'explain_document_sm',  # defaul pl explain
            'pl.explain.sm': 'explain_document_sm',
            'pl.explain.md': 'explain_document_md',
            'pl.explain.lg': 'explain_document_lg',
            'pl.ner': 'entity_recognizer_sm',  # default pl ner
            'pl.ner.sm': 'entity_recognizer_sm',
            'pl.ner.md': 'entity_recognizer_md',
            'pl.ner.lg': 'entity_recognizer_lg',
        },
        'pt': {
            'pt.explain': 'explain_document_sm',  # default explain pt
            'pt.explain.sm': 'explain_document_sm',
            'pt.explain.md': 'explain_document_md',
            'pt.explain.lg': 'explain_document_lg',
            'pt.ner': 'entity_recognizer_sm',  # default ner pt
            'pt.ner.sm': 'entity_recognizer_sm',
            'pt.ner.md': 'entity_recognizer_md',
            'pt.ner.lg': 'entity_recognizer_lg',

        },
        'ru': {
            'ru.explain': 'explain_document_sm',  # default ru explain
            'ru.explain.sm': 'explain_document_sm',
            'ru.explain.md': 'explain_document_md',
            'ru.explain.lg': 'explain_document_lg',
            'ru.ner': 'entity_recognizer_sm',  # default ru ner
            'ru.ner.sm': 'entity_recognizer_sm',
            'ru.ner.md': 'entity_recognizer_md',
            'ru.ner.lg': 'entity_recognizer_lg',
        },
        'es': {
            'es.explain': 'explain_document_sm',  # es expplain deflaut
            'es.explain.sm': 'explain_document_sm',
            'es.explain.md': 'explain_document_md',
            'es.explain.lg': 'explain_document_lg',
            'es.ner': 'entity_recognizer_sm',  # es ner default
            'es.ner.sm': 'entity_recognizer_sm',
            'es.ner.md': 'entity_recognizer_md',
            'es.ner.lg': 'entity_recognizer_lg',
        },
        'xx': {
            'lang.': 'detect_language_375',  # default lang classifer
            'lang.7': 'detect_language_7',  # multi lang detector alias
            'lang.20': 'detect_language_20',  # multi lang detector alias
            'xx.classify.lang': 'detect_language_20',  # multi lang detector default
            'xx.classify.lang.20': 'detect_language_20',  # multi lang detector default
            'xx.classify.lang.7': 'detect_language_7',

            # 2.7 lang classifiers

            'xx.classify.lang': 'detect_language_375',  # default lang classifer
            'xx.classify.lang.21': 'detect_language_21',
            'xx.classify.lang.43': 'detect_language_43',
            'xx.classify.lang.95': 'detect_language_95',
            'xx.classify.lang.99': 'detect_language_99',
            'xx.classify.lang.220': 'detect_language_220',
            'xx.classify.lang.231': 'detect_language_231',
            'xx.classify.lang.bigru': 'detect_language_bigru_21',
            'lang.21': 'detect_language_21',
            'lang.43': 'detect_language_43',
            'lang.95': 'detect_language_95',
            'lang.99': 'detect_language_99',
            'lang.220': 'detect_language_220',
            'lang.231': 'detect_language_231',
            'lang.bigru': 'detect_language_bigru_21',

            # 2.7 marian translate pipe references
            "xx.zlw.translate_to.en": "translate_zlw_en",
            "xx.en.translate_to.ti": "translate_en_ti",
            "xx.bem.translate_to.en": "translate_bem_en",
            "xx.ny.translate_to.en": "translate_ny_en",
            "xx.en.translate_to.lu": "translate_en_lu",
            "xx.taw.translate_to.en": "translate_taw_en",
            "xx.en.translate_to.ga": "translate_en_ga",
            "xx.en.translate_to.sw": "translate_en_sw",
            "xx.war.translate_to.en": "translate_war_en",
            "xx.en.translate_to.hu": "translate_en_hu",
            "xx.pqe.translate_to.en": "translate_pqe_en",
            "xx.en.translate_to.bem": "translate_en_bem",
            "xx.en.translate_to.tiv": "translate_en_tiv",
            "xx.en.translate_to.tll": "translate_en_tll",
            "xx.en.translate_to.cpp": "translate_en_cpp",
            "xx.efi.translate_to.en": "translate_efi_en",
            "xx.en.translate_to.itc": "translate_en_itc",
            "xx.uk.translate_to.en": "translate_uk_en",
            "xx.ee.translate_to.en": "translate_ee_en",
            "xx.nso.translate_to.en": "translate_nso_en",
            "xx.urj.translate_to.en": "translate_urj_en",
            "xx.sv.translate_to.en": "translate_sv_en",
            "xx.en.translate_to.rn": "translate_en_rn",
            "xx.nic.translate_to.en": "translate_nic_en",
            "xx.en.translate_to.bcl": "translate_en_bcl",
            "xx.en.translate_to.lg": "translate_en_lg",
            "xx.kwy.translate_to.en": "translate_kwy_en",
            "xx.en.translate_to.gmq": "translate_en_gmq",
            "xx.en.translate_to.ts": "translate_en_ts",
            "xx.bnt.translate_to.en": "translate_bnt_en",
            "xx.en.translate_to.pis": "translate_en_pis",
            "xx.kwn.translate_to.en": "translate_kwn_en",
            "xx.fi.translate_to.en": "translate_fi_en",
            "xx.en.translate_to.gaa": "translate_en_gaa",
            "xx.afa.translate_to.en": "translate_afa_en",
            "xx.itc.translate_to.en": "translate_itc_en",
            "xx.mh.translate_to.en": "translate_mh_en",
            "xx.en.translate_to.ln": "translate_en_ln",
            "xx.en.translate_to.zls": "translate_en_zls",
            "xx.en.translate_to.cy": "translate_en_cy",
            "xx.et.translate_to.en": "translate_et_en",
            "xx.en.translate_to.dra": "translate_en_dra",
            "xx.en.translate_to.sn": "translate_en_sn",
            "xx.lua.translate_to.en": "translate_lua_en",
            "xx.ln.translate_to.en": "translate_ln_en",
            "xx.ja.translate_to.en": "translate_ja_en",
            "xx.loz.translate_to.en": "translate_loz_en",
            "xx.en.translate_to.bi": "translate_en_bi",
            "xx.mg.translate_to.en": "translate_mg_en",
            "xx.vi.translate_to.en": "translate_vi_en",
            "xx.en.translate_to.vi": "translate_en_vi",
            "xx.hy.translate_to.en": "translate_hy_en",
            "xx.en.translate_to.mt": "translate_en_mt",
            "xx.ng.translate_to.en": "translate_ng_en",
            "xx.mkh.translate_to.en": "translate_mkh_en",
            "xx.en.translate_to.cpf": "translate_en_cpf",
            "xx.wal.translate_to.en": "translate_wal_en",
            "xx.en.translate_to.crs": "translate_en_crs",
            "xx.en.translate_to.zle": "translate_en_zle",
            "xx.en.translate_to.phi": "translate_en_phi",
            "xx.ine.translate_to.en": "translate_ine_en",
            "xx.en.translate_to.pap": "translate_en_pap",
            "xx.en.translate_to.sit": "translate_en_sit",
            "xx.bg.translate_to.en": "translate_bg_en",
            "xx.en.translate_to.ml": "translate_en_ml",
            "xx.en.translate_to.ss": "translate_en_ss",
            "xx.en.translate_to.tw": "translate_en_tw",
            "xx.en.translate_to.gv": "translate_en_gv",
            "xx.ca.translate_to.en": "translate_ca_en",
            "xx.umb.translate_to.en": "translate_umb_en",
            "xx.alv.translate_to.en": "translate_alv_en",
            "xx.gem.translate_to.en": "translate_gem_en",
            "xx.chk.translate_to.en": "translate_chk_en",
            "xx.kqn.translate_to.en": "translate_kqn_en",
            "xx.en.translate_to.afa": "translate_en_afa",
            "xx.gl.translate_to.en": "translate_gl_en",
            "xx.en.translate_to.ber": "translate_en_ber",
            "xx.en.translate_to.ig": "translate_en_ig",
            "xx.ase.translate_to.en": "translate_ase_en",
            "xx.en.translate_to.cs": "translate_en_cs",
            "xx.en.translate_to.pag": "translate_en_pag",
            "xx.en.translate_to.nic": "translate_en_nic",
            "xx.en.translate_to.hil": "translate_en_hil",
            "xx.en.translate_to.cel": "translate_en_cel",
            "xx.nl.translate_to.en": "translate_nl_en",
            "xx.en.translate_to.ho": "translate_en_ho",
            "xx.en.translate_to.inc": "translate_en_inc",
            "xx.ts.translate_to.en": "translate_ts_en",
            "xx.en.translate_to.tl": "translate_en_tl",
            "xx.ve.translate_to.en": "translate_ve_en",
            "xx.ceb.translate_to.en": "translate_ceb_en",
            "xx.en.translate_to.iir": "translate_en_iir",
            "xx.en.translate_to.aav": "translate_en_aav",
            "xx.en.translate_to.bat": "translate_en_bat",
            "xx.en.translate_to.alv": "translate_en_alv",
            "xx.ar.translate_to.en": "translate_ar_en",
            "xx.fiu.translate_to.en": "translate_fiu_en",
            "xx.en.translate_to.eu": "translate_en_eu",
            "xx.is.translate_to.en": "translate_is_en",
            "xx.wa.translate_to.en": "translate_wa_en",
            "xx.en.translate_to.tn": "translate_en_tn",
            "xx.ig.translate_to.en": "translate_ig_en",
            "xx.luo.translate_to.en": "translate_luo_en",
            "xx.en.translate_to.kwn": "translate_en_kwn",
            "xx.niu.translate_to.en": "translate_niu_en",
            "xx.en.translate_to.gl": "translate_en_gl",
            "xx.en.translate_to.ilo": "translate_en_ilo",
            "xx.en.translate_to.ur": "translate_en_ur",
            "xx.cus.translate_to.en": "translate_cus_en",
            "xx.phi.translate_to.en": "translate_phi_en",
            "xx.en.translate_to.loz": "translate_en_loz",
            "xx.tiv.translate_to.en": "translate_tiv_en",
            "xx.en.translate_to.id": "translate_en_id",
            "xx.zle.translate_to.en": "translate_zle_en",
            "xx.en.translate_to.mfe": "translate_en_mfe",
            "xx.id.translate_to.en": "translate_id_en",
            "xx.lv.translate_to.en": "translate_lv_en",
            "xx.en.translate_to.pon": "translate_en_pon",
            "xx.en.translate_to.sq": "translate_en_sq",
            "xx.tum.translate_to.en": "translate_tum_en",
            "xx.pl.translate_to.en": "translate_pl_en",
            "xx.xh.translate_to.en": "translate_xh_en",
            "xx.kab.translate_to.en": "translate_kab_en",
            "xx.tvl.translate_to.en": "translate_tvl_en",
            "xx.pa.translate_to.en": "translate_pa_en",
            "xx.iso.translate_to.en": "translate_iso_en",
            "xx.ho.translate_to.en": "translate_ho_en",
            "xx.cel.translate_to.en": "translate_cel_en",
            "xx.en.translate_to.om": "translate_en_om",
            "xx.kg.translate_to.en": "translate_kg_en",
            "xx.en.translate_to.lus": "translate_en_lus",
            "xx.om.translate_to.en": "translate_om_en",
            "xx.lun.translate_to.en": "translate_lun_en",
            "xx.crs.translate_to.en": "translate_crs_en",
            "xx.cy.translate_to.en": "translate_cy_en",
            "xx.tll.translate_to.en": "translate_tll_en",
            "xx.gil.translate_to.en": "translate_gil_en",
            "xx.en.translate_to.mkh": "translate_en_mkh",
            "xx.en.translate_to.euq": "translate_en_euq",
            "xx.en.translate_to.sem": "translate_en_sem",
            "xx.cs.translate_to.en": "translate_cs_en",
            "xx.en.translate_to.sk": "translate_en_sk",
            "xx.en.translate_to.bzs": "translate_en_bzs",
            "xx.en.translate_to.trk": "translate_en_trk",
            "xx.cpf.translate_to.en": "translate_cpf_en",
            "xx.bi.translate_to.en": "translate_bi_en",
            "xx.en.translate_to.mul": "translate_en_mul",
            "xx.en.translate_to.gmw": "translate_en_gmw",
            "xx.en.translate_to.fi": "translate_en_fi",
            "xx.en.translate_to.zlw": "translate_en_zlw",
            "xx.lg.translate_to.en": "translate_lg_en",
            "xx.en.translate_to.pqe": "translate_en_pqe",
            "xx.en.translate_to.xh": "translate_en_xh",
            "xx.en.translate_to.hi": "translate_en_hi",
            "xx.en.translate_to.nyk": "translate_en_nyk",
            "xx.th.translate_to.en": "translate_th_en",
            "xx.en.translate_to.umb": "translate_en_umb",
            "xx.en.translate_to.af": "translate_en_af",
            "xx.tpi.translate_to.en": "translate_tpi_en",
            "xx.ti.translate_to.en": "translate_ti_en",
            "xx.en.translate_to.chk": "translate_en_chk",
            "xx.mos.translate_to.en": "translate_mos_en",
            "xx.en.translate_to.sm": "translate_en_sm",
            "xx.pon.translate_to.en": "translate_pon_en",
            "xx.en.translate_to.bg": "translate_en_bg",
            "xx.en.translate_to.ny": "translate_en_ny",
            "xx.kl.translate_to.en": "translate_kl_en",
            "xx.en.translate_to.hy": "translate_en_hy",
            "xx.nyk.translate_to.en": "translate_nyk_en",
            "xx.it.translate_to.en": "translate_it_en",
            "xx.mt.translate_to.en": "translate_mt_en",
            "xx.pap.translate_to.en": "translate_pap_en",
            "xx.srn.translate_to.en": "translate_srn_en",
            "xx.da.translate_to.en": "translate_da_en",
            "xx.en.translate_to.lue": "translate_en_lue",
            "xx.rn.translate_to.en": "translate_rn_en",
            "xx.en.translate_to.tut": "translate_en_tut",
            "xx.lu.translate_to.en": "translate_lu_en",
            "xx.ru.translate_to.en": "translate_ru_en",
            "xx.en.translate_to.toi": "translate_en_toi",
            "xx.ccs.translate_to.en": "translate_ccs_en",
            "xx.aav.translate_to.en": "translate_aav_en",
            "xx.en.translate_to.ha": "translate_en_ha",
            "xx.rnd.translate_to.en": "translate_rnd_en",
            "xx.de.translate_to.en": "translate_de_en",
            "xx.en.translate_to.luo": "translate_en_luo",
            "xx.fr.translate_to.en": "translate_fr_en",
            "xx.bcl.translate_to.en": "translate_bcl_en",
            "xx.ilo.translate_to.en": "translate_ilo_en",
            "xx.en.translate_to.jap": "translate_en_jap",
            "xx.en.translate_to.fj": "translate_en_fj",
            "xx.sk.translate_to.en": "translate_sk_en",
            "xx.bzs.translate_to.en": "translate_bzs_en",
            "xx.ka.translate_to.en": "translate_ka_en",
            "xx.ko.translate_to.en": "translate_ko_en",
            "xx.sq.translate_to.en": "translate_sq_en",
            "xx.mul.translate_to.en": "translate_mul_en",
            "xx.en.translate_to.run": "translate_en_run",
            "xx.sn.translate_to.en": "translate_sn_en",
            "xx.en.translate_to.pqw": "translate_en_pqw",
            "xx.ss.translate_to.en": "translate_ss_en",
            "xx.sm.translate_to.en": "translate_sm_en",
            "xx.en.translate_to.kwy": "translate_en_kwy",
            "xx.jap.translate_to.en": "translate_jap_en",
            "xx.en.translate_to.kqn": "translate_en_kqn",
            "xx.mk.translate_to.en": "translate_mk_en",
            "xx.hu.translate_to.en": "translate_hu_en",
            "xx.en.translate_to.map": "translate_en_map",
            "xx.yo.translate_to.en": "translate_yo_en",
            "xx.hi.translate_to.en": "translate_hi_en",
            "xx.iir.translate_to.en": "translate_iir_en",
            "xx.en.translate_to.guw": "translate_en_guw",
            "xx.en.translate_to.es": "translate_en_es",
            "xx.en.translate_to.gem": "translate_en_gem",
            "xx.en.translate_to.ht": "translate_en_ht",
            "xx.zls.translate_to.en": "translate_zls_en",
            "xx.sg.translate_to.en": "translate_sg_en",
            "xx.en.translate_to.ty": "translate_en_ty",
            "xx.en.translate_to.lun": "translate_en_lun",
            "xx.guw.translate_to.en": "translate_guw_en",
            "xx.trk.translate_to.en": "translate_trk_en",
            "xx.mfe.translate_to.en": "translate_mfe_en",
            "xx.en.translate_to.nl": "translate_en_nl",
            "xx.en.translate_to.sv": "translate_en_sv",
            "xx.ber.translate_to.en": "translate_ber_en",
            "xx.to.translate_to.en": "translate_to_en",
            "xx.en.translate_to.da": "translate_en_da",
            "xx.en.translate_to.urj": "translate_en_urj",
            "xx.inc.translate_to.en": "translate_inc_en",
            "xx.wls.translate_to.en": "translate_wls_en",
            "xx.pis.translate_to.en": "translate_pis_en",
            "xx.en.translate_to.mh": "translate_en_mh",
            "xx.en.translate_to.iso": "translate_en_iso",
            "xx.en.translate_to.ru": "translate_en_ru",
            "xx.swc.translate_to.en": "translate_swc_en",
            "xx.en.translate_to.rnd": "translate_en_rnd",
            "xx.en.translate_to.nso": "translate_en_nso",
            "xx.en.translate_to.swc": "translate_en_swc",
            "xx.ur.translate_to.en": "translate_ur_en",
            "xx.en.translate_to.ro": "translate_en_ro",
            "xx.ml.translate_to.en": "translate_ml_en",
            "xx.grk.translate_to.en": "translate_grk_en",
            "xx.rw.translate_to.en": "translate_rw_en",
            "xx.tr.translate_to.en": "translate_tr_en",
            "xx.gmq.translate_to.en": "translate_gmq_en",
            "xx.euq.translate_to.en": "translate_euq_en",
            "xx.en.translate_to.tdt": "translate_en_tdt",
            "xx.eo.translate_to.en": "translate_eo_en",
            "xx.cau.translate_to.en": "translate_cau_en",
            "xx.en.translate_to.mk": "translate_en_mk",
            "xx.en.translate_to.mr": "translate_en_mr",
            "xx.af.translate_to.en": "translate_af_en",
            "xx.run.translate_to.en": "translate_run_en",
            "xx.en.translate_to.ng": "translate_en_ng",
            "xx.en.translate_to.mg": "translate_en_mg",
            "xx.en.translate_to.bnt": "translate_en_bnt",
            "xx.en.translate_to.kj": "translate_en_kj",
            "xx.en.translate_to.he": "translate_en_he",
            "xx.en.translate_to.sla": "translate_en_sla",
            "xx.en.translate_to.el": "translate_en_el",
            "xx.ht.translate_to.en": "translate_ht_en",
            "xx.en.translate_to.et": "translate_en_et",
            "xx.en.translate_to.poz": "translate_en_poz",
            "xx.roa.translate_to.en": "translate_roa_en",
            "xx.en.translate_to.de": "translate_en_de",
            "xx.fj.translate_to.en": "translate_fj_en",
            "xx.en.translate_to.lua": "translate_en_lua",
            "xx.en.translate_to.kg": "translate_en_kg",
            "xx.en.translate_to.fiu": "translate_en_fiu",
            "xx.gv.translate_to.en": "translate_gv_en",
            "xx.cpp.translate_to.en": "translate_cpp_en",
            "xx.en.translate_to.tpi": "translate_en_tpi",
            "xx.en.translate_to.grk": "translate_en_grk",
            "xx.en.translate_to.sal": "translate_en_sal",
            "xx.en.translate_to.niu": "translate_en_niu",
            "xx.en.translate_to.ca": "translate_en_ca",
            "xx.en.translate_to.roa": "translate_en_roa",
            "xx.sal.translate_to.en": "translate_sal_en",
            "xx.ha.translate_to.en": "translate_ha_en",
            "xx.sem.translate_to.en": "translate_sem_en",
            "xx.tn.translate_to.en": "translate_tn_en",
            "xx.gaa.translate_to.en": "translate_gaa_en",
            "xx.en.translate_to.to": "translate_en_to",
            "xx.en.translate_to.ee": "translate_en_ee",
            "xx.toi.translate_to.en": "translate_toi_en",
            "xx.lue.translate_to.en": "translate_lue_en",
            "xx.en.translate_to.rw": "translate_en_rw",
            "xx.st.translate_to.en": "translate_st_en",
            "xx.dra.translate_to.en": "translate_dra_en",
            "xx.en.translate_to.mos": "translate_en_mos",
            "xx.eu.translate_to.en": "translate_eu_en",
            "xx.lus.translate_to.en": "translate_lus_en",
            "xx.sla.translate_to.en": "translate_sla_en",
            "xx.en.translate_to.ceb": "translate_en_ceb",
            "xx.art.translate_to.en": "translate_art_en",
            "xx.bat.translate_to.en": "translate_bat_en",
            "xx.az.translate_to.en": "translate_az_en",
            "xx.en.translate_to.ine": "translate_en_ine",
            "xx.pag.translate_to.en": "translate_pag_en",
            "xx.yap.translate_to.en": "translate_yap_en",
            "xx.en.translate_to.eo": "translate_en_eo",
            "xx.en.translate_to.tvl": "translate_en_tvl",
            "xx.kj.translate_to.en": "translate_kj_en",
            "xx.en.translate_to.st": "translate_en_st",
            "xx.gmw.translate_to.en": "translate_gmw_en",
            "xx.mr.translate_to.en": "translate_mr_en",
            "xx.es.translate_to.en": "translate_es_en",
            "xx.en.translate_to.sg": "translate_en_sg",
            "xx.en.translate_to.cus": "translate_en_cus",
            "xx.en.translate_to.it": "translate_en_it",
            "xx.ga.translate_to.en": "translate_ga_en",
            "xx.bn.translate_to.en": "translate_bn_en",
            "xx.en.translate_to.efi": "translate_en_efi",
            "xx.en.translate_to.az": "translate_en_az",
            "xx.en.translate_to.zh": "translate_en_zh",
            "xx.en.translate_to.is": "translate_en_is",
            "xx.zh.translate_to.en": "translate_zh_en",
            "xx.hil.translate_to.en": "translate_hil_en",
            "xx.en.translate_to.ar": "translate_en_ar",
            "xx.tl.translate_to.en": "translate_tl_en",
            "xx.en.translate_to.gil": "translate_en_gil",
            "xx.en.translate_to.uk": "translate_en_uk",
            "xx.en.translate_to.fr": "translate_en_fr",
            # 3.1 Translator Pipe references

            "xx.es.translate_to.af":"translate_af_es",
            "xx.nl.translate_to.af":"translate_af_nl",
            "xx.eo.translate_to.af":"translate_af_eo",
            "xx.afa.translate_to.afa":"translate_afa_afa",
            "xx.sv.translate_to.af":"translate_af_sv",
            "xx.es.translate_to.aed":"translate_aed_es",
            "xx.fr.translate_to.af":"translate_af_fr",
            "xx.fi.translate_to.af":"translate_af_fi",
            "xx.de.translate_to.af":"translate_af_de",
            "xx.ru.translate_to.af":"translate_af_ru",
            "xx.es.translate_to.az":"translate_az_es",
            "xx.de.translate_to.bcl":"translate_bcl_de",
            "xx.sv.translate_to.bem":"translate_bem_sv",
            "xx.tr.translate_to.az":"translate_az_tr",
            "xx.sv.translate_to.bcl":"translate_bcl_sv",
            "xx.es.translate_to.ar":"translate_ar_es",
            "xx.es.translate_to.bem":"translate_bem_es",
            "xx.ru.translate_to.ar":"translate_ar_ru",
            "xx.es.translate_to.be":"translate_be_es",
            "xx.fr.translate_to.bem":"translate_bem_fr",
            "xx.he.translate_to.ar":"translate_ar_he",
            "xx.es.translate_to.bcl":"translate_bcl_es",
            "xx.es.translate_to.ase":"translate_ase_es",
            "xx.de.translate_to.ar":"translate_ar_de",
            "xx.pl.translate_to.ar":"translate_ar_pl",
            "xx.tr.translate_to.ar":"translate_ar_tr",
            "xx.sv.translate_to.ase":"translate_ase_sv",
            "xx.fi.translate_to.bcl":"translate_bcl_fi",
            "xx.el.translate_to.ar":"translate_ar_el",
            "xx.fr.translate_to.bcl":"translate_bcl_fr",
            "xx.fi.translate_to.bem":"translate_bem_fi",
            "xx.fr.translate_to.ase":"translate_ase_fr",
            "xx.fr.translate_to.ar":"translate_ar_fr",
            "xx.eo.translate_to.ar":"translate_ar_eo",
            "xx.it.translate_to.ar":"translate_ar_it",
            "xx.sv.translate_to.am":"translate_am_sv",
            "xx.de.translate_to.ase":"translate_ase_de",
            "xx.uk.translate_to.bg":"translate_bg_uk",
            "xx.it.translate_to.bg":"translate_bg_it",
            "xx.sv.translate_to.bzs":"translate_bzs_sv",
            "xx.pt.translate_to.ca":"translate_ca_pt",
            "xx.es.translate_to.ber":"translate_ber_es",
            "xx.it.translate_to.ca":"translate_ca_it",
            "xx.eo.translate_to.bg":"translate_bg_eo",
            "xx.sv.translate_to.ceb":"translate_ceb_sv",
            "xx.fr.translate_to.bi":"translate_bi_fr",
            "xx.sv.translate_to.bg":"translate_bg_sv",
            "xx.fr.translate_to.ca":"translate_ca_fr",
            "xx.tr.translate_to.bg":"translate_bg_tr",
            "xx.es.translate_to.ceb":"translate_ceb_es",
            "xx.de.translate_to.ca":"translate_ca_de",
            "xx.fi.translate_to.ceb":"translate_ceb_fi",
            "xx.es.translate_to.ca":"translate_ca_es",
            "xx.es.translate_to.bg":"translate_bg_es",
            "xx.uk.translate_to.ca":"translate_ca_uk",
            "xx.sv.translate_to.bi":"translate_bi_sv",
            "xx.sv.translate_to.chk":"translate_chk_sv",
            "xx.fr.translate_to.ceb":"translate_ceb_fr",
            "xx.es.translate_to.bzs":"translate_bzs_es",
            "xx.de.translate_to.crs":"translate_crs_de",
            "xx.nl.translate_to.ca":"translate_ca_nl",
            "xx.es.translate_to.chk":"translate_chk_es",
            "xx.fr.translate_to.ber":"translate_ber_fr",
            "xx.fi.translate_to.bzs":"translate_bzs_fi",
            "xx.es.translate_to.crs":"translate_crs_es",
            "xx.fi.translate_to.bg":"translate_bg_fi",
            "xx.cpp.translate_to.cpp":"translate_cpp_cpp",
            "xx.de.translate_to.bg":"translate_bg_de",
            "xx.es.translate_to.bi":"translate_bi_es",
            "xx.fr.translate_to.bzs":"translate_bzs_fr",
            "xx.fr.translate_to.bg":"translate_bg_fr",
            "xx.fr.translate_to.chk":"translate_chk_fr",
            "xx.ru.translate_to.bg":"translate_bg_ru",
            "xx.fi.translate_to.cs":"translate_cs_fi",
            "xx.ha.translate_to.de":"translate_de_ha",
            "xx.ee.translate_to.de":"translate_de_ee",
            "xx.eo.translate_to.de":"translate_de_eo",
            "xx.gil.translate_to.de":"translate_de_gil",
            "xx.fj.translate_to.de":"translate_de_fj",
            "xx.fr.translate_to.de":"translate_de_fr",
            "xx.sv.translate_to.cs":"translate_cs_sv",
            "xx.es.translate_to.csn":"translate_csn_es",
            "xx.ru.translate_to.da":"translate_da_ru",
            "xx.no.translate_to.da":"translate_da_no",
            "xx.iso.translate_to.de":"translate_de_iso",
            "xx.eu.translate_to.de":"translate_de_eu",
            "xx.nl.translate_to.de":"translate_de_nl",
            "xx.ilo.translate_to.de":"translate_de_ilo",
            "xx.hr.translate_to.de":"translate_de_hr",
            "xx.mt.translate_to.de":"translate_de_mt",
            "xx.es.translate_to.da":"translate_da_es",
            "xx.ar.translate_to.de":"translate_de_ar",
            "xx.is.translate_to.de":"translate_de_is",
            "xx.sv.translate_to.crs":"translate_crs_sv",
            "xx.fr.translate_to.da":"translate_da_fr",
            "xx.gaa.translate_to.de":"translate_de_gaa",
            "xx.niu.translate_to.de":"translate_de_niu",
            "xx.da.translate_to.de":"translate_de_da",
            "xx.de.translate_to.da":"translate_da_de",
            "xx.ase.translate_to.de":"translate_de_ase",
            "xx.ig.translate_to.de":"translate_de_ig",
            "xx.lua.translate_to.de":"translate_de_lua",
            "xx.de.translate_to.de":"translate_de_de",
            "xx.bi.translate_to.de":"translate_de_bi",
            "xx.fr.translate_to.cs":"translate_cs_fr",
            "xx.ms.translate_to.de":"translate_de_ms",
            "xx.fi.translate_to.crs":"translate_crs_fi",
            "xx.eo.translate_to.da":"translate_da_eo",
            "xx.af.translate_to.de":"translate_de_af",
            "xx.uk.translate_to.cs":"translate_cs_uk",
            "xx.bg.translate_to.de":"translate_de_bg",
            "xx.no.translate_to.de":"translate_de_no",
            "xx.de.translate_to.cs":"translate_cs_de",
            "xx.it.translate_to.de":"translate_de_it",
            "xx.ho.translate_to.de":"translate_de_ho",
            "xx.ln.translate_to.de":"translate_de_ln",
            "xx.guw.translate_to.de":"translate_de_guw",
            "xx.efi.translate_to.de":"translate_de_efi",
            "xx.hil.translate_to.de":"translate_de_hil",
            "xx.cs.translate_to.de":"translate_de_cs",
            "xx.es.translate_to.csg":"translate_csg_es",
            "xx.es.translate_to.de":"translate_de_es",
            "xx.bcl.translate_to.de":"translate_de_bcl",
            "xx.ht.translate_to.de":"translate_de_ht",
            "xx.loz.translate_to.de":"translate_de_loz",
            "xx.kg.translate_to.de":"translate_de_kg",
            "xx.eo.translate_to.cs":"translate_cs_eo",
            "xx.el.translate_to.de":"translate_de_el",
            "xx.fi.translate_to.de":"translate_de_fi",
            "xx.he.translate_to.de":"translate_de_he",
            "xx.bzs.translate_to.de":"translate_de_bzs",
            "xx.fr.translate_to.crs":"translate_crs_fr",
            "xx.crs.translate_to.de":"translate_de_crs",
            "xx.fi.translate_to.da":"translate_da_fi",
            "xx.hu.translate_to.de":"translate_de_hu",
            "xx.et.translate_to.de":"translate_de_et",
            "xx.lt.translate_to.de":"translate_de_lt",
            "xx.ca.translate_to.de":"translate_de_ca",
            "xx.pl.translate_to.de":"translate_de_pl",
            "xx.sv.translate_to.el":"translate_el_sv",
            "xx.de.translate_to.ee":"translate_ee_de",
            "xx.pag.translate_to.de":"translate_de_pag",
            "xx.ar.translate_to.el":"translate_el_ar",
            "xx.nso.translate_to.de":"translate_de_nso",
            "xx.pon.translate_to.de":"translate_de_pon",
            "xx.pap.translate_to.de":"translate_de_pap",
            "xx.fr.translate_to.efi":"translate_efi_fr",
            "xx.pis.translate_to.de":"translate_de_pis",
            "xx.de.translate_to.efi":"translate_efi_de",
            "xx.eo.translate_to.el":"translate_el_eo",
            "xx.fi.translate_to.ee":"translate_ee_fi",
            "xx.es.translate_to.ee":"translate_ee_es",
            "xx.fr.translate_to.ee":"translate_ee_fr",
            "xx.fi.translate_to.efi":"translate_efi_fi",
            "xx.fr.translate_to.el":"translate_el_fr",
            "xx.tl.translate_to.de":"translate_de_tl",
            "xx.ny.translate_to.de":"translate_de_ny",
            "xx.uk.translate_to.de":"translate_de_uk",
            "xx.sv.translate_to.efi":"translate_efi_sv",
            "xx.sv.translate_to.ee":"translate_ee_sv",
            "xx.vi.translate_to.de":"translate_de_vi",
            "xx.fi.translate_to.el":"translate_el_fi",
            "xx.cs.translate_to.eo":"translate_eo_cs",
            "xx.bzs.translate_to.es":"translate_es_bzs",
            "xx.he.translate_to.eo":"translate_eo_he",
            "xx.hu.translate_to.eo":"translate_eo_hu",
            "xx.ro.translate_to.eo":"translate_eo_ro",
            "xx.ber.translate_to.es":"translate_es_ber",
            "xx.ca.translate_to.es":"translate_es_ca",
            "xx.bcl.translate_to.es":"translate_es_bcl",
            "xx.ceb.translate_to.es":"translate_es_ceb",
            "xx.da.translate_to.eo":"translate_eo_da",
            "xx.bi.translate_to.es":"translate_es_bi",
            "xx.ee.translate_to.es":"translate_es_ee",
            "xx.ru.translate_to.eo":"translate_eo_ru",
            "xx.csg.translate_to.es":"translate_es_csg",
            "xx.fi.translate_to.eo":"translate_eo_fi",
            "xx.it.translate_to.eo":"translate_eo_it",
            "xx.nl.translate_to.eo":"translate_eo_nl",
            "xx.et.translate_to.es":"translate_es_et",
            "xx.bg.translate_to.es":"translate_es_bg",
            "xx.de.translate_to.eo":"translate_eo_de",
            "xx.ar.translate_to.es":"translate_es_ar",
            "xx.cs.translate_to.es":"translate_es_cs",
            "xx.aed.translate_to.es":"translate_es_aed",
            "xx.ase.translate_to.es":"translate_es_ase",
            "xx.el.translate_to.es":"translate_es_el",
            "xx.eo.translate_to.es":"translate_es_eo",
            "xx.af.translate_to.eo":"translate_eo_af",
            "xx.af.translate_to.es":"translate_es_af",
            "xx.pl.translate_to.eo":"translate_eo_pl",
            "xx.de.translate_to.es":"translate_es_de",
            "xx.es.translate_to.eo":"translate_eo_es",
            "xx.da.translate_to.es":"translate_es_da",
            "xx.crs.translate_to.es":"translate_es_crs",
            "xx.pt.translate_to.eo":"translate_eo_pt",
            "xx.eu.translate_to.es":"translate_es_eu",
            "xx.es.translate_to.es":"translate_es_es",
            "xx.csn.translate_to.es":"translate_es_csn",
            "xx.sv.translate_to.eo":"translate_eo_sv",
            "xx.efi.translate_to.es":"translate_es_efi",
            "xx.sh.translate_to.eo":"translate_eo_sh",
            "xx.bg.translate_to.eo":"translate_eo_bg",
            "xx.fr.translate_to.eo":"translate_eo_fr",
            "xx.el.translate_to.eo":"translate_eo_el",
            "xx.pl.translate_to.es":"translate_es_pl",
            "xx.ro.translate_to.es":"translate_es_ro",
            "xx.is.translate_to.es":"translate_es_is",
            "xx.ln.translate_to.es":"translate_es_ln",
            "xx.to.translate_to.es":"translate_es_to",
            "xx.no.translate_to.es":"translate_es_no",
            "xx.nl.translate_to.es":"translate_es_nl",
            "xx.pag.translate_to.es":"translate_es_pag",
            "xx.tvl.translate_to.es":"translate_es_tvl",
            "xx.fr.translate_to.es":"translate_es_fr",
            "xx.he.translate_to.es":"translate_es_he",
            "xx.lus.translate_to.es":"translate_es_lus",
            "xx.hil.translate_to.es":"translate_es_hil",
            "xx.ny.translate_to.es":"translate_es_ny",
            "xx.pap.translate_to.es":"translate_es_pap",
            "xx.id.translate_to.es":"translate_es_id",
            "xx.wls.translate_to.es":"translate_es_wls",
            "xx.gaa.translate_to.es":"translate_es_gaa",
            "xx.nso.translate_to.es":"translate_es_nso",
            "xx.mk.translate_to.es":"translate_es_mk",
            "xx.mt.translate_to.es":"translate_es_mt",
            "xx.pis.translate_to.es":"translate_es_pis",
            "xx.gl.translate_to.es":"translate_es_gl",
            "xx.sn.translate_to.es":"translate_es_sn",
            "xx.hr.translate_to.es":"translate_es_hr",
            "xx.swc.translate_to.es":"translate_es_swc",
            "xx.lua.translate_to.es":"translate_es_lua",
            "xx.it.translate_to.es":"translate_es_it",
            "xx.fj.translate_to.es":"translate_es_fj",
            "xx.gil.translate_to.es":"translate_es_gil",
            "xx.sm.translate_to.es":"translate_es_sm",
            "xx.guw.translate_to.es":"translate_es_guw",
            "xx.kg.translate_to.es":"translate_es_kg",
            "xx.tl.translate_to.es":"translate_es_tl",
            "xx.rn.translate_to.es":"translate_es_rn",
            "xx.mfs.translate_to.es":"translate_es_mfs",
            "xx.iso.translate_to.es":"translate_es_iso",
            "xx.loz.translate_to.es":"translate_es_loz",
            "xx.tpi.translate_to.es":"translate_es_tpi",
            "xx.ha.translate_to.es":"translate_es_ha",
            "xx.ht.translate_to.es":"translate_es_ht",
            "xx.uk.translate_to.es":"translate_es_uk",
            "xx.tw.translate_to.es":"translate_es_tw",
            "xx.st.translate_to.es":"translate_es_st",
            "xx.sg.translate_to.es":"translate_es_sg",
            "xx.ilo.translate_to.es":"translate_es_ilo",
            "xx.ru.translate_to.es":"translate_es_ru",
            "xx.yo.translate_to.es":"translate_es_yo",
            "xx.pon.translate_to.es":"translate_es_pon",
            "xx.niu.translate_to.es":"translate_es_niu",
            "xx.lt.translate_to.es":"translate_es_lt",
            "xx.ty.translate_to.es":"translate_es_ty",
            "xx.ig.translate_to.es":"translate_es_ig",
            "xx.tzo.translate_to.es":"translate_es_tzo",
            "xx.rw.translate_to.es":"translate_es_rw",
            "xx.war.translate_to.es":"translate_es_war",
            "xx.tll.translate_to.es":"translate_es_tll",
            "xx.prl.translate_to.es":"translate_es_prl",
            "xx.xh.translate_to.es":"translate_es_xh",
            "xx.yua.translate_to.es":"translate_es_yua",
            "xx.ho.translate_to.es":"translate_es_ho",
            "xx.ve.translate_to.es":"translate_es_ve",
            "xx.sl.translate_to.es":"translate_es_sl",
            "xx.tn.translate_to.es":"translate_es_tn",
            "xx.vi.translate_to.es":"translate_es_vi",
            "xx.srn.translate_to.es":"translate_es_srn",
            "xx.fi.translate_to.es":"translate_es_fi",
            "xx.lua.translate_to.fi":"translate_fi_lua",
            "xx.ny.translate_to.fi":"translate_fi_ny",
            "xx.pon.translate_to.fi":"translate_fi_pon",
            "xx.crs.translate_to.fi":"translate_fi_crs",
            "xx.nso.translate_to.fi":"translate_fi_nso",
            "xx.iso.translate_to.fi":"translate_fi_iso",
            "xx.kqn.translate_to.fi":"translate_fi_kqn",
            "xx.gaa.translate_to.fi":"translate_fi_gaa",
            "xx.ru.translate_to.eu":"translate_eu_ru",
            "xx.eo.translate_to.fi":"translate_fi_eo",
            "xx.ig.translate_to.fi":"translate_fi_ig",
            "xx.bem.translate_to.fi":"translate_fi_bem",
            "xx.es.translate_to.et":"translate_et_es",
            "xx.fj.translate_to.fi":"translate_fi_fj",
            "xx.et.translate_to.fi":"translate_fi_et",
            "xx.bcl.translate_to.fi":"translate_fi_bcl",
            "xx.fi.translate_to.fi":"translate_fi_fi",
            "xx.el.translate_to.fi":"translate_fi_el",
            "xx.efi.translate_to.fi":"translate_fi_efi",
            "xx.ht.translate_to.fi":"translate_fi_ht",
            "xx.ceb.translate_to.fi":"translate_fi_ceb",
            "xx.lg.translate_to.fi":"translate_fi_lg",
            "xx.pap.translate_to.fi":"translate_fi_pap",
            "xx.kg.translate_to.fi":"translate_fi_kg",
            "xx.ee.translate_to.fi":"translate_fi_ee",
            "xx.lv.translate_to.fi":"translate_fi_lv",
            "xx.fr.translate_to.et":"translate_et_fr",
            "xx.de.translate_to.et":"translate_et_de",
            "xx.bzs.translate_to.fi":"translate_fi_bzs",
            "xx.mos.translate_to.fi":"translate_fi_mos",
            "xx.zh.translate_to.es":"translate_es_zh",
            "xx.id.translate_to.fi":"translate_fi_id",
            "xx.gil.translate_to.fi":"translate_fi_gil",
            "xx.pis.translate_to.fi":"translate_fi_pis",
            "xx.no.translate_to.fi":"translate_fi_no",
            "xx.it.translate_to.fi":"translate_fi_it",
            "xx.es.translate_to.fi":"translate_fi_es",
            "xx.ha.translate_to.fi":"translate_fi_ha",
            "xx.fr.translate_to.fi":"translate_fi_fr",
            "xx.de.translate_to.fi":"translate_fi_de",
            "xx.bg.translate_to.fi":"translate_fi_bg",
            "xx.zai.translate_to.es":"translate_es_zai",
            "xx.hil.translate_to.fi":"translate_fi_hil",
            "xx.cs.translate_to.fi":"translate_fi_cs",
            "xx.es.translate_to.eu":"translate_eu_es",
            "xx.ilo.translate_to.fi":"translate_fi_ilo",
            "xx.pag.translate_to.fi":"translate_fi_pag",
            "xx.ln.translate_to.fi":"translate_fi_ln",
            "xx.sv.translate_to.et":"translate_et_sv",
            "xx.niu.translate_to.fi":"translate_fi_niu",
            "xx.hr.translate_to.fi":"translate_fi_hr",
            "xx.de.translate_to.eu":"translate_eu_de",
            "xx.lus.translate_to.fi":"translate_fi_lus",
            "xx.ru.translate_to.et":"translate_et_ru",
            "xx.af.translate_to.fi":"translate_fi_af",
            "xx.mh.translate_to.fi":"translate_fi_mh",
            "xx.guw.translate_to.fi":"translate_fi_guw",
            "xx.mfe.translate_to.fi":"translate_fi_mfe",
            "xx.ho.translate_to.fi":"translate_fi_ho",
            "xx.fse.translate_to.fi":"translate_fi_fse",
            "xx.lu.translate_to.fi":"translate_fi_lu",
            "xx.hu.translate_to.fi":"translate_fi_hu",
            "xx.mk.translate_to.fi":"translate_fi_mk",
            "xx.nl.translate_to.fi":"translate_fi_nl",
            "xx.mg.translate_to.fi":"translate_fi_mg",
            "xx.mt.translate_to.fi":"translate_fi_mt",
            "xx.he.translate_to.fi":"translate_fi_he",
            "xx.fi.translate_to.et":"translate_et_fi",
            "xx.is.translate_to.fi":"translate_fi_is",
            "xx.lue.translate_to.fi":"translate_fi_lue",
            "xx.guw.translate_to.fr":"translate_fr_guw",
            "xx.ber.translate_to.fr":"translate_fr_ber",
            "xx.uk.translate_to.fi":"translate_fi_uk",
            "xx.efi.translate_to.fr":"translate_fr_efi",
            "xx.tr.translate_to.fi":"translate_fi_tr",
            "xx.tn.translate_to.fi":"translate_fi_tn",
            "xx.es.translate_to.fr":"translate_fr_es",
            "xx.srn.translate_to.fi":"translate_fi_srn",
            "xx.bcl.translate_to.fr":"translate_fr_bcl",
            "xx.sl.translate_to.fi":"translate_fi_sl",
            "xx.ht.translate_to.fr":"translate_fr_ht",
            "xx.zne.translate_to.fi":"translate_fi_zne",
            "xx.de.translate_to.fr":"translate_fr_de",
            "xx.war.translate_to.fi":"translate_fi_war",
            "xx.tpi.translate_to.fi":"translate_fi_tpi",
            "xx.ca.translate_to.fr":"translate_fr_ca",
            "xx.yap.translate_to.fi":"translate_fi_yap",
            "xx.sn.translate_to.fi":"translate_fi_sn",
            "xx.hr.translate_to.fr":"translate_fr_hr",
            "xx.gil.translate_to.fr":"translate_fr_gil",
            "xx.id.translate_to.fr":"translate_fr_id",
            "xx.sv.translate_to.fi":"translate_fi_sv",
            "xx.toi.translate_to.fi":"translate_fi_toi",
            "xx.sk.translate_to.fi":"translate_fi_sk",
            "xx.he.translate_to.fr":"translate_fr_he",
            "xx.sq.translate_to.fi":"translate_fi_sq",
            "xx.ve.translate_to.fi":"translate_fi_ve",
            "xx.tw.translate_to.fi":"translate_fi_tw",
            "xx.tvl.translate_to.fi":"translate_fi_tvl",
            "xx.hil.translate_to.fr":"translate_fr_hil",
            "xx.sw.translate_to.fi":"translate_fi_sw",
            "xx.eo.translate_to.fr":"translate_fr_eo",
            "xx.xh.translate_to.fi":"translate_fi_xh",
            "xx.bi.translate_to.fr":"translate_fr_bi",
            "xx.ru.translate_to.fi":"translate_fi_ru",
            "xx.ceb.translate_to.fr":"translate_fr_ceb",
            "xx.ig.translate_to.fr":"translate_fr_ig",
            "xx.el.translate_to.fr":"translate_fr_el",
            "xx.sm.translate_to.fi":"translate_fi_sm",
            "xx.to.translate_to.fi":"translate_fi_to",
            "xx.ase.translate_to.fr":"translate_fr_ase",
            "xx.yo.translate_to.fi":"translate_fi_yo",
            "xx.sg.translate_to.fi":"translate_fi_sg",
            "xx.rw.translate_to.fi":"translate_fi_rw",
            "xx.ts.translate_to.fi":"translate_fi_ts",
            "xx.wls.translate_to.fi":"translate_fi_wls",
            "xx.ho.translate_to.fr":"translate_fr_ho",
            "xx.tll.translate_to.fi":"translate_fi_tll",
            "xx.st.translate_to.fi":"translate_fi_st",
            "xx.fiu.translate_to.fiu":"translate_fiu_fiu",
            "xx.ro.translate_to.fi":"translate_fi_ro",
            "xx.tiv.translate_to.fi":"translate_fi_tiv",
            "xx.ha.translate_to.fr":"translate_fr_ha",
            "xx.ee.translate_to.fr":"translate_fr_ee",
            "xx.gaa.translate_to.fr":"translate_fr_gaa",
            "xx.hu.translate_to.fr":"translate_fr_hu",
            "xx.ty.translate_to.fi":"translate_fi_ty",
            "xx.fr.translate_to.fj":"translate_fj_fr",
            "xx.run.translate_to.fi":"translate_fi_run",
            "xx.bem.translate_to.fr":"translate_fr_bem",
            "xx.bzs.translate_to.fr":"translate_fr_bzs",
            "xx.fj.translate_to.fr":"translate_fr_fj",
            "xx.ar.translate_to.fr":"translate_fr_ar",
            "xx.swc.translate_to.fi":"translate_fi_swc",
            "xx.crs.translate_to.fr":"translate_fr_crs",
            "xx.bg.translate_to.fr":"translate_fr_bg",
            "xx.af.translate_to.fr":"translate_fr_af",
            "xx.loz.translate_to.fr":"translate_fr_loz",
            "xx.st.translate_to.fr":"translate_fr_st",
            "xx.tn.translate_to.fr":"translate_fr_tn",
            "xx.srn.translate_to.fr":"translate_fr_srn",
            "xx.to.translate_to.fr":"translate_fr_to",
            "xx.sk.translate_to.fr":"translate_fr_sk",
            "xx.tum.translate_to.fr":"translate_fr_tum",
            "xx.ts.translate_to.fr":"translate_fr_ts",
            "xx.iso.translate_to.fr":"translate_fr_iso",
            "xx.sv.translate_to.fr":"translate_fr_sv",
            "xx.mt.translate_to.fr":"translate_fr_mt",
            "xx.pap.translate_to.fr":"translate_fr_pap",
            "xx.wls.translate_to.fr":"translate_fr_wls",
            "xx.lua.translate_to.fr":"translate_fr_lua",
            "xx.ro.translate_to.fr":"translate_fr_ro",
            "xx.tll.translate_to.fr":"translate_fr_tll",
            "xx.ilo.translate_to.fr":"translate_fr_ilo",
            "xx.ve.translate_to.fr":"translate_fr_ve",
            "xx.ny.translate_to.fr":"translate_fr_ny",
            "xx.tpi.translate_to.fr":"translate_fr_tpi",
            "xx.uk.translate_to.fr":"translate_fr_uk",
            "xx.ln.translate_to.fr":"translate_fr_ln",
            "xx.mfe.translate_to.fr":"translate_fr_mfe",
            "xx.lue.translate_to.fr":"translate_fr_lue",
            "xx.mos.translate_to.fr":"translate_fr_mos",
            "xx.pon.translate_to.fr":"translate_fr_pon",
            "xx.tvl.translate_to.fr":"translate_fr_tvl",
            "xx.run.translate_to.fr":"translate_fr_run",
            "xx.pag.translate_to.fr":"translate_fr_pag",
            "xx.sg.translate_to.fr":"translate_fr_sg",
            "xx.no.translate_to.fr":"translate_fr_no",
            "xx.ty.translate_to.fr":"translate_fr_ty",
            "xx.tl.translate_to.fr":"translate_fr_tl",
            "xx.sl.translate_to.fr":"translate_fr_sl",
            "xx.tiv.translate_to.fr":"translate_fr_tiv",
            "xx.rw.translate_to.fr":"translate_fr_rw",
            "xx.lus.translate_to.fr":"translate_fr_lus",
            "xx.swc.translate_to.fr":"translate_fr_swc",
            "xx.sm.translate_to.fr":"translate_fr_sm",
            "xx.pl.translate_to.fr":"translate_fr_pl",
            "xx.kg.translate_to.fr":"translate_fr_kg",
            "xx.niu.translate_to.fr":"translate_fr_niu",
            "xx.lg.translate_to.fr":"translate_fr_lg",
            "xx.ms.translate_to.fr":"translate_fr_ms",
            "xx.nso.translate_to.fr":"translate_fr_nso",
            "xx.war.translate_to.fr":"translate_fr_war",
            "xx.xh.translate_to.fr":"translate_fr_xh",
            "xx.pis.translate_to.fr":"translate_fr_pis",
            "xx.tw.translate_to.fr":"translate_fr_tw",
            "xx.kwy.translate_to.fr":"translate_fr_kwy",
            "xx.rnd.translate_to.fr":"translate_fr_rnd",
            "xx.vi.translate_to.fr":"translate_fr_vi",
            "xx.lu.translate_to.fr":"translate_fr_lu",
            "xx.mh.translate_to.fr":"translate_fr_mh",
            "xx.ru.translate_to.fr":"translate_fr_ru",
            "xx.sn.translate_to.fr":"translate_fr_sn",
            "xx.kqn.translate_to.fr":"translate_fr_kqn",
            "xx.ar.translate_to.he":"translate_he_ar",
            "xx.de.translate_to.he":"translate_he_de",
            "xx.es.translate_to.gil":"translate_gil_es",
            "xx.de.translate_to.gaa":"translate_gaa_de",
            "xx.fr.translate_to.hu":"translate_hu_fr",
            "xx.fr.translate_to.gil":"translate_gil_fr",
            "xx.de.translate_to.guw":"translate_guw_de",
            "xx.fr.translate_to.ht":"translate_ht_fr",
            "xx.uk.translate_to.he":"translate_he_uk",
            "xx.fi.translate_to.hu":"translate_hu_fi",
            "xx.uk.translate_to.hu":"translate_hu_uk",
            "xx.zne.translate_to.fr":"translate_fr_zne",
            "xx.sv.translate_to.gaa":"translate_gaa_sv",
            "xx.es.translate_to.guw":"translate_guw_es",
            "xx.gmq.translate_to.gmq":"translate_gmq_gmq",
            "xx.fi.translate_to.hil":"translate_hil_fi",
            "xx.fi.translate_to.guw":"translate_guw_fi",
            "xx.es.translate_to.he":"translate_he_es",
            "xx.ur.translate_to.hi":"translate_hi_ur",
            "xx.de.translate_to.hil":"translate_hil_de",
            "xx.gmw.translate_to.gmw":"translate_gmw_gmw",
            "xx.fi.translate_to.gaa":"translate_gaa_fi",
            "xx.fi.translate_to.he":"translate_he_fi",
            "xx.eo.translate_to.hu":"translate_hu_eo",
            "xx.fi.translate_to.ht":"translate_ht_fi",
            "xx.yo.translate_to.fr":"translate_fr_yo",
            "xx.sv.translate_to.hr":"translate_hr_sv",
            "xx.fr.translate_to.ha":"translate_ha_fr",
            "xx.fi.translate_to.ha":"translate_ha_fi",
            "xx.sv.translate_to.ha":"translate_ha_sv",
            "xx.pt.translate_to.gl":"translate_gl_pt",
            "xx.fr.translate_to.guw":"translate_guw_fr",
            "xx.es.translate_to.ht":"translate_ht_es",
            "xx.de.translate_to.hu":"translate_hu_de",
            "xx.sv.translate_to.ht":"translate_ht_sv",
            "xx.es.translate_to.hr":"translate_hr_es",
            "xx.fr.translate_to.gaa":"translate_gaa_fr",
            "xx.ru.translate_to.he":"translate_he_ru",
            "xx.es.translate_to.gl":"translate_gl_es",
            "xx.ru.translate_to.hy":"translate_hy_ru",
            "xx.fi.translate_to.gil":"translate_gil_fi",
            "xx.sv.translate_to.hu":"translate_hu_sv",
            "xx.sv.translate_to.gil":"translate_gil_sv",
            "xx.fi.translate_to.fse":"translate_fse_fi",
            "xx.gem.translate_to.gem":"translate_gem_gem",
            "xx.es.translate_to.ha":"translate_ha_es",
            "xx.it.translate_to.he":"translate_he_it",
            "xx.sv.translate_to.guw":"translate_guw_sv",
            "xx.sv.translate_to.he":"translate_he_sv",
            "xx.yap.translate_to.fr":"translate_fr_yap",
            "xx.fr.translate_to.hr":"translate_hr_fr",
            "xx.eo.translate_to.he":"translate_he_eo",
            "xx.es.translate_to.gaa":"translate_gaa_es",
            "xx.fi.translate_to.hr":"translate_hr_fi",
            "xx.fr.translate_to.he":"translate_he_fr",
            "xx.fi.translate_to.ilo":"translate_ilo_fi",
            "xx.sv.translate_to.iso":"translate_iso_sv",
            "xx.he.translate_to.ja":"translate_ja_he",
            "xx.fi.translate_to.id":"translate_id_fi",
            "xx.de.translate_to.ja":"translate_ja_de",
            "xx.he.translate_to.it":"translate_it_he",
            "xx.it.translate_to.ja":"translate_ja_it",
            "xx.is.translate_to.it":"translate_it_is",
            "xx.bg.translate_to.ja":"translate_ja_bg",
            "xx.de.translate_to.ig":"translate_ig_de",
            "xx.bg.translate_to.it":"translate_it_bg",
            "xx.es.translate_to.id":"translate_id_es",
            "xx.fr.translate_to.id":"translate_id_fr",
            "xx.es.translate_to.ja":"translate_ja_es",
            "xx.sv.translate_to.ja":"translate_ja_sv",
            "xx.es.translate_to.iso":"translate_iso_es",
            "xx.es.translate_to.ilo":"translate_ilo_es",
            "xx.it.translate_to.is":"translate_is_it",
            "xx.sv.translate_to.it":"translate_it_sv",
            "xx.sv.translate_to.is":"translate_is_sv",
            "xx.ru.translate_to.ja":"translate_ja_ru",
            "xx.es.translate_to.kg":"translate_kg_es",
            "xx.fi.translate_to.ig":"translate_ig_fi",
            "xx.fr.translate_to.iso":"translate_iso_fr",
            "xx.de.translate_to.ko":"translate_ko_de",
            "xx.sv.translate_to.ilo":"translate_ilo_sv",
            "xx.es.translate_to.is":"translate_is_es",
            "xx.da.translate_to.ja":"translate_ja_da",
            "xx.nl.translate_to.ja":"translate_ja_nl",
            "xx.inc.translate_to.inc":"translate_inc_inc",
            "xx.de.translate_to.is":"translate_is_de",
            "xx.fr.translate_to.is":"translate_is_fr",
            "xx.lt.translate_to.it":"translate_it_lt",
            "xx.sv.translate_to.ig":"translate_ig_sv",
            "xx.de.translate_to.ilo":"translate_ilo_de",
            "xx.ar.translate_to.it":"translate_it_ar",
            "xx.fr.translate_to.kg":"translate_kg_fr",
            "xx.vi.translate_to.ja":"translate_ja_vi",
            "xx.ru.translate_to.ka":"translate_ka_ru",
            "xx.uk.translate_to.it":"translate_it_uk",
            "xx.vi.translate_to.it":"translate_it_vi",
            "xx.ms.translate_to.it":"translate_it_ms",
            "xx.ar.translate_to.ja":"translate_ja_ar",
            "xx.eo.translate_to.is":"translate_is_eo",
            "xx.ca.translate_to.it":"translate_it_ca",
            "xx.sh.translate_to.ja":"translate_ja_sh",
            "xx.fi.translate_to.ja":"translate_ja_fi",
            "xx.iir.translate_to.iir":"translate_iir_iir",
            "xx.itc.translate_to.itc":"translate_itc_itc",
            "xx.ms.translate_to.ja":"translate_ja_ms",
            "xx.fr.translate_to.it":"translate_it_fr",
            "xx.fr.translate_to.ja":"translate_ja_fr",
            "xx.pt.translate_to.ja":"translate_ja_pt",
            "xx.eo.translate_to.it":"translate_it_eo",
            "xx.fi.translate_to.iso":"translate_iso_fi",
            "xx.pl.translate_to.ja":"translate_ja_pl",
            "xx.tr.translate_to.ja":"translate_ja_tr",
            "xx.es.translate_to.ig":"translate_ig_es",
            "xx.fr.translate_to.ig":"translate_ig_fr",
            "xx.sv.translate_to.id":"translate_id_sv",
            "xx.hu.translate_to.ja":"translate_ja_hu",
            "xx.sv.translate_to.kg":"translate_kg_sv",
            "xx.es.translate_to.it":"translate_it_es",
            "xx.ine.translate_to.ine":"translate_ine_ine",
            "xx.de.translate_to.it":"translate_it_de",
            "xx.fi.translate_to.is":"translate_is_fi",
            "xx.es.translate_to.mk":"translate_mk_es",
            "xx.es.translate_to.lue":"translate_lue_es",
            "xx.es.translate_to.lv":"translate_lv_es",
            "xx.fi.translate_to.lue":"translate_lue_fi",
            "xx.es.translate_to.ln":"translate_ln_es",
            "xx.fr.translate_to.loz":"translate_loz_fr",
            "xx.sv.translate_to.kwy":"translate_kwy_sv",
            "xx.es.translate_to.lus":"translate_lus_es",
            "xx.fr.translate_to.lv":"translate_lv_fr",
            "xx.fr.translate_to.lu":"translate_lu_fr",
            "xx.de.translate_to.lt":"translate_lt_de",
            "xx.tr.translate_to.lt":"translate_lt_tr",
            "xx.fr.translate_to.lus":"translate_lus_fr",
            "xx.es.translate_to.mg":"translate_mg_es",
            "xx.sv.translate_to.lua":"translate_lua_sv",
            "xx.fr.translate_to.lg":"translate_lg_fr",
            "xx.fr.translate_to.kwy":"translate_kwy_fr",
            "xx.es.translate_to.lt":"translate_lt_es",
            "xx.sv.translate_to.ko":"translate_ko_sv",
            "xx.es.translate_to.kqn":"translate_kqn_es",
            "xx.fr.translate_to.ko":"translate_ko_fr",
            "xx.sv.translate_to.kqn":"translate_kqn_sv",
            "xx.fi.translate_to.ko":"translate_ko_fi",
            "xx.es.translate_to.mh":"translate_mh_es",
            "xx.fr.translate_to.lua":"translate_lua_fr",
            "xx.it.translate_to.lt":"translate_lt_it",
            "xx.sv.translate_to.lt":"translate_lt_sv",
            "xx.es.translate_to.lu":"translate_lu_es",
            "xx.fi.translate_to.lua":"translate_lua_fi",
            "xx.fr.translate_to.kqn":"translate_kqn_fr",
            "xx.de.translate_to.loz":"translate_loz_de",
            "xx.fr.translate_to.ms":"translate_ms_fr",
            "xx.fr.translate_to.lt":"translate_lt_fr",
            "xx.ru.translate_to.lv":"translate_lv_ru",
            "xx.ms.translate_to.ms":"translate_ms_ms",
            "xx.sv.translate_to.lus":"translate_lus_sv",
            "xx.fr.translate_to.lue":"translate_lue_fr",
            "xx.fi.translate_to.lu":"translate_lu_fi",
            "xx.eo.translate_to.lt":"translate_lt_eo",
            "xx.fi.translate_to.mk":"translate_mk_fi",
            "xx.es.translate_to.ko":"translate_ko_es",
            "xx.sv.translate_to.lue":"translate_lue_sv",
            "xx.pl.translate_to.lt":"translate_lt_pl",
            "xx.es.translate_to.mfe":"translate_mfe_es",
            "xx.fi.translate_to.loz":"translate_loz_fi",
            "xx.sv.translate_to.loz":"translate_loz_sv",
            "xx.ru.translate_to.ko":"translate_ko_ru",
            "xx.fi.translate_to.lg":"translate_lg_fi",
            "xx.fi.translate_to.mh":"translate_mh_fi",
            "xx.sv.translate_to.lv":"translate_lv_sv",
            "xx.hu.translate_to.ko":"translate_ko_hu",
            "xx.es.translate_to.lua":"translate_lua_es",
            "xx.fi.translate_to.lv":"translate_lv_fi",
            "xx.ru.translate_to.lt":"translate_lt_ru",
            "xx.de.translate_to.ms":"translate_ms_de",
            "xx.fi.translate_to.lus":"translate_lus_fi",
            "xx.es.translate_to.lg":"translate_lg_es",
            "xx.de.translate_to.ln":"translate_ln_de",
            "xx.es.translate_to.mfs":"translate_mfs_es",
            "xx.fr.translate_to.mk":"translate_mk_fr",
            "xx.fr.translate_to.ln":"translate_ln_fr",
            "xx.es.translate_to.loz":"translate_loz_es",
            "xx.sv.translate_to.lu":"translate_lu_sv",
            "xx.it.translate_to.ms":"translate_ms_it",
            "xx.sv.translate_to.lg":"translate_lg_sv",
            "xx.ar.translate_to.pl":"translate_pl_ar",
            "xx.fr.translate_to.ro":"translate_ro_fr",
            "xx.sv.translate_to.niu":"translate_niu_sv",
            "xx.eo.translate_to.pl":"translate_pl_eo",
            "xx.nl.translate_to.no":"translate_no_nl",
            "xx.es.translate_to.no":"translate_no_es",
            "xx.es.translate_to.pag":"translate_pag_es",
            "xx.ru.translate_to.rn":"translate_rn_ru",
            "xx.sv.translate_to.pag":"translate_pag_sv",
            "xx.uk.translate_to.pt":"translate_pt_uk",
            "xx.uk.translate_to.pl":"translate_pl_uk",
            "xx.de.translate_to.pl":"translate_pl_de",
            "xx.sv.translate_to.nl":"translate_nl_sv",
            "xx.fr.translate_to.no":"translate_no_fr",
            "xx.es.translate_to.niu":"translate_niu_es",
            "xx.uk.translate_to.no":"translate_no_uk",
            "xx.lt.translate_to.pl":"translate_pl_lt",
            "xx.tl.translate_to.pt":"translate_pt_tl",
            "xx.gl.translate_to.pt":"translate_pt_gl",
            "xx.da.translate_to.ru":"translate_ru_da",
            "xx.da.translate_to.no":"translate_no_da",
            "xx.uk.translate_to.nl":"translate_nl_uk",
            "xx.sv.translate_to.pon":"translate_pon_sv",
            "xx.fr.translate_to.pis":"translate_pis_fr",
            "xx.fr.translate_to.niu":"translate_niu_fr",
            "xx.af.translate_to.nl":"translate_nl_af",
            "xx.fi.translate_to.nso":"translate_nso_fi",
            "xx.fi.translate_to.pon":"translate_pon_fi",
            "xx.de.translate_to.pap":"translate_pap_de",
            "xx.de.translate_to.rn":"translate_rn_de",
            "xx.es.translate_to.pon":"translate_pon_es",
            "xx.es.translate_to.pis":"translate_pis_es",
            "xx.ca.translate_to.pt":"translate_pt_ca",
            "xx.sv.translate_to.rnd":"translate_rnd_sv",
            "xx.sv.translate_to.pl":"translate_pl_sv",
            "xx.ru.translate_to.no":"translate_no_ru",
            "xx.fi.translate_to.niu":"translate_niu_fi",
            "xx.de.translate_to.pag":"translate_pag_de",
            "xx.fr.translate_to.pl":"translate_pl_fr",
            "xx.fi.translate_to.no":"translate_no_fi",
            "xx.pl.translate_to.no":"translate_no_pl",
            "xx.de.translate_to.nso":"translate_nso_de",
            "xx.fr.translate_to.rn":"translate_rn_fr",
            "xx.sv.translate_to.nso":"translate_nso_sv",
            "xx.sv.translate_to.ro":"translate_ro_sv",
            "xx.no.translate_to.pl":"translate_pl_no",
            "xx.fr.translate_to.nl":"translate_nl_fr",
            "xx.es.translate_to.nso":"translate_nso_es",
            "xx.no.translate_to.nl":"translate_nl_no",
            "xx.fi.translate_to.pis":"translate_pis_fi",
            "xx.ca.translate_to.nl":"translate_nl_ca",
            "xx.es.translate_to.nl":"translate_nl_es",
            "xx.es.translate_to.ny":"translate_ny_es",
            "xx.fr.translate_to.pap":"translate_pap_fr",
            "xx.fi.translate_to.nl":"translate_nl_fi",
            "xx.sv.translate_to.no":"translate_no_sv",
            "xx.fr.translate_to.pon":"translate_pon_fr",
            "xx.fr.translate_to.rnd":"translate_rnd_fr",
            "xx.es.translate_to.pap":"translate_pap_es",
            "xx.es.translate_to.prl":"translate_prl_es",
            "xx.eo.translate_to.ro":"translate_ro_eo",
            "xx.sv.translate_to.pis":"translate_pis_sv",
            "xx.af.translate_to.ru":"translate_ru_af",
            "xx.fr.translate_to.nso":"translate_nso_fr",
            "xx.eo.translate_to.pt":"translate_pt_eo",
            "xx.ar.translate_to.ru":"translate_ru_ar",
            "xx.fr.translate_to.mt":"translate_mt_fr",
            "xx.es.translate_to.rn":"translate_rn_es",
            "xx.sv.translate_to.mt":"translate_mt_sv",
            "xx.de.translate_to.niu":"translate_niu_de",
            "xx.es.translate_to.mt":"translate_mt_es",
            "xx.es.translate_to.pl":"translate_pl_es",
            "xx.fi.translate_to.pag":"translate_pag_fi",
            "xx.de.translate_to.no":"translate_no_de",
            "xx.de.translate_to.ny":"translate_ny_de",
            "xx.fi.translate_to.mt":"translate_mt_fi",
            "xx.no.translate_to.no":"translate_no_no",
            "xx.eo.translate_to.nl":"translate_nl_eo",
            "xx.bg.translate_to.ru":"translate_ru_bg",
            "xx.fi.translate_to.pap":"translate_pap_fi",
            "xx.fi.translate_to.ro":"translate_ro_fi",
            "xx.sv.translate_to.st":"translate_st_sv",
            "xx.kg.translate_to.sv":"translate_sv_kg",
            "xx.sv.translate_to.sq":"translate_sq_sv",
            "xx.ee.translate_to.sv":"translate_sv_ee",
            "xx.es.translate_to.srn":"translate_srn_es",
            "xx.lv.translate_to.ru":"translate_ru_lv",
            "xx.cs.translate_to.sv":"translate_sv_cs",
            "xx.ha.translate_to.sv":"translate_sv_ha",
            "xx.kqn.translate_to.sv":"translate_sv_kqn",
            "xx.fr.translate_to.rw":"translate_rw_fr",
            "xx.fr.translate_to.sn":"translate_sn_fr",
            "xx.eu.translate_to.ru":"translate_ru_eu",
            "xx.fi.translate_to.st":"translate_st_fi",
            "xx.efi.translate_to.sv":"translate_sv_efi",
            "xx.ho.translate_to.sv":"translate_sv_ho",
            "xx.id.translate_to.sv":"translate_sv_id",
            "xx.eo.translate_to.sv":"translate_sv_eo",
            "xx.guw.translate_to.sv":"translate_sv_guw",
            "xx.sv.translate_to.sk":"translate_sk_sv",
            "xx.fr.translate_to.srn":"translate_srn_fr",
            "xx.ceb.translate_to.sv":"translate_sv_ceb",
            "xx.es.translate_to.sq":"translate_sq_es",
            "xx.sv.translate_to.rw":"translate_rw_sv",
            "xx.is.translate_to.sv":"translate_sv_is",
            "xx.es.translate_to.sm":"translate_sm_es",
            "xx.bcl.translate_to.sv":"translate_sv_bcl",
            "xx.kwy.translate_to.sv":"translate_sv_kwy",
            "xx.es.translate_to.run":"translate_run_es",
            "xx.el.translate_to.sv":"translate_sv_el",
            "xx.es.translate_to.sk":"translate_sk_es",
            "xx.iso.translate_to.sv":"translate_sv_iso",
            "xx.lu.translate_to.sv":"translate_sv_lu",
            "xx.af.translate_to.sv":"translate_sv_af",
            "xx.bg.translate_to.sv":"translate_sv_bg",
            "xx.fr.translate_to.sm":"translate_sm_fr",
            "xx.hr.translate_to.sv":"translate_sv_hr",
            "xx.sv.translate_to.sn":"translate_sn_sv",
            "xx.no.translate_to.ru":"translate_ru_no",
            "xx.fr.translate_to.sg":"translate_sg_fr",
            "xx.es.translate_to.sl":"translate_sl_es",
            "xx.bzs.translate_to.sv":"translate_sv_bzs",
            "xx.fr.translate_to.st":"translate_st_fr",
            "xx.hu.translate_to.sv":"translate_sv_hu",
            "xx.sv.translate_to.sg":"translate_sg_sv",
            "xx.sem.translate_to.sem":"translate_sem_sem",
            "xx.uk.translate_to.sh":"translate_sh_uk",
            "xx.ln.translate_to.sv":"translate_sv_ln",
            "xx.fi.translate_to.sk":"translate_sk_fi",
            "xx.ht.translate_to.sv":"translate_sv_ht",
            "xx.es.translate_to.st":"translate_st_es",
            "xx.fr.translate_to.ru":"translate_ru_fr",
            "xx.chk.translate_to.sv":"translate_sv_chk",
            "xx.fr.translate_to.sk":"translate_sk_fr",
            "xx.lg.translate_to.sv":"translate_sv_lg",
            "xx.sv.translate_to.srn":"translate_srn_sv",
            "xx.crs.translate_to.sv":"translate_sv_crs",
            "xx.uk.translate_to.ru":"translate_ru_uk",
            "xx.et.translate_to.ru":"translate_ru_et",
            "xx.et.translate_to.sv":"translate_sv_et",
            "xx.es.translate_to.rw":"translate_rw_es",
            "xx.sla.translate_to.sla":"translate_sla_sla",
            "xx.ru.translate_to.sl":"translate_sl_ru",
            "xx.fj.translate_to.sv":"translate_sv_fj",
            "xx.es.translate_to.sn":"translate_sn_es",
            "xx.lua.translate_to.sv":"translate_sv_lua",
            "xx.hil.translate_to.sv":"translate_sv_hil",
            "xx.es.translate_to.ru":"translate_ru_es",
            "xx.lue.translate_to.sv":"translate_sv_lue",
            "xx.gaa.translate_to.sv":"translate_sv_gaa",
            "xx.hy.translate_to.ru":"translate_ru_hy",
            "xx.bem.translate_to.sv":"translate_sv_bem",
            "xx.sv.translate_to.run":"translate_run_sv",
            "xx.gil.translate_to.sv":"translate_sv_gil",
            "xx.lus.translate_to.sv":"translate_sv_lus",
            "xx.he.translate_to.ru":"translate_ru_he",
            "xx.vi.translate_to.ru":"translate_ru_vi",
            "xx.he.translate_to.sv":"translate_sv_he",
            "xx.sv.translate_to.ru":"translate_ru_sv",
            "xx.fi.translate_to.ru":"translate_ru_fi",
            "xx.es.translate_to.sv":"translate_sv_es",
            "xx.es.translate_to.sg":"translate_sg_es",
            "xx.eo.translate_to.ru":"translate_ru_eo",
            "xx.lv.translate_to.sv":"translate_sv_lv",
            "xx.fi.translate_to.sg":"translate_sg_fi",
            "xx.es.translate_to.ssp":"translate_ssp_es",
            "xx.ilo.translate_to.sv":"translate_sv_ilo",
            "xx.fi.translate_to.sv":"translate_sv_fi",
            "xx.lt.translate_to.ru":"translate_ru_lt",
            "xx.bi.translate_to.sv":"translate_sv_bi",
            "xx.sv.translate_to.sl":"translate_sl_sv",
            "xx.fr.translate_to.sv":"translate_sv_fr",
            "xx.uk.translate_to.sl":"translate_sl_uk",
            "xx.fi.translate_to.sl":"translate_sl_fi",
            "xx.sl.translate_to.ru":"translate_ru_sl",
            "xx.ig.translate_to.sv":"translate_sv_ig",
            "xx.ase.translate_to.sv":"translate_sv_ase",
            "xx.eo.translate_to.sh":"translate_sh_eo",
            "xx.fr.translate_to.sl":"translate_sl_fr",
            "xx.es.translate_to.tl":"translate_tl_es",
            "xx.sv.translate_to.tw":"translate_tw_sv",
            "xx.lt.translate_to.tr":"translate_tr_lt",
            "xx.fi.translate_to.tll":"translate_tll_fi",
            "xx.sn.translate_to.sv":"translate_sv_sn",
            "xx.tn.translate_to.sv":"translate_sv_tn",
            "xx.sv.translate_to.toi":"translate_toi_sv",
            "xx.uk.translate_to.sv":"translate_sv_uk",
            "xx.tiv.translate_to.sv":"translate_sv_tiv",
            "xx.sk.translate_to.sv":"translate_sv_sk",
            "xx.ty.translate_to.sv":"translate_sv_ty",
            "xx.es.translate_to.toi":"translate_toi_es",
            "xx.rw.translate_to.sv":"translate_sv_rw",
            "xx.ny.translate_to.sv":"translate_sv_ny",
            "xx.rnd.translate_to.sv":"translate_sv_rnd",
            "xx.es.translate_to.tn":"translate_tn_es",
            "xx.sv.translate_to.tn":"translate_tn_sv",
            "xx.es.translate_to.tvl":"translate_tvl_es",
            "xx.pon.translate_to.sv":"translate_sv_pon",
            "xx.ve.translate_to.sv":"translate_sv_ve",
            "xx.fr.translate_to.tvl":"translate_tvl_fr",
            "xx.es.translate_to.tum":"translate_tum_es",
            "xx.run.translate_to.sv":"translate_sv_run",
            "xx.de.translate_to.tl":"translate_tl_de",
            "xx.fi.translate_to.tw":"translate_tw_fi",
            "xx.es.translate_to.ty":"translate_ty_es",
            "xx.fr.translate_to.toi":"translate_toi_fr",
            "xx.sv.translate_to.tll":"translate_tll_sv",
            "xx.sg.translate_to.sv":"translate_sv_sg",
            "xx.az.translate_to.tr":"translate_tr_az",
            "xx.es.translate_to.ts":"translate_ts_es",
            "xx.fr.translate_to.ts":"translate_ts_fr",
            "xx.fr.translate_to.th":"translate_th_fr",
            "xx.zne.translate_to.sv":"translate_sv_zne",
            "xx.tw.translate_to.sv":"translate_sv_tw",
            "xx.mh.translate_to.sv":"translate_sv_mh",
            "xx.pag.translate_to.sv":"translate_sv_pag",
            "xx.fr.translate_to.tum":"translate_tum_fr",
            "xx.no.translate_to.sv":"translate_sv_no",
            "xx.ts.translate_to.sv":"translate_sv_ts",
            "xx.mt.translate_to.sv":"translate_sv_mt",
            "xx.yo.translate_to.sv":"translate_sv_yo",
            "xx.fr.translate_to.to":"translate_to_fr",
            "xx.sv.translate_to.sv":"translate_sv_sv",
            "xx.fi.translate_to.toi":"translate_toi_fi",
            "xx.ro.translate_to.sv":"translate_sv_ro",
            "xx.es.translate_to.tw":"translate_tw_es",
            "xx.niu.translate_to.sv":"translate_sv_niu",
            "xx.uk.translate_to.tr":"translate_tr_uk",
            "xx.to.translate_to.sv":"translate_sv_to",
            "xx.fi.translate_to.ts":"translate_ts_fi",
            "xx.tll.translate_to.sv":"translate_sv_tll",
            "xx.fr.translate_to.tll":"translate_tll_fr",
            "xx.pt.translate_to.tl":"translate_tl_pt",
            "xx.nso.translate_to.sv":"translate_sv_nso",
            "xx.sq.translate_to.sv":"translate_sv_sq",
            "xx.sv.translate_to.tpi":"translate_tpi_sv",
            "xx.yap.translate_to.sv":"translate_sv_yap",
            "xx.sv.translate_to.tr":"translate_tr_sv",
            "xx.fr.translate_to.swc":"translate_swc_fr",
            "xx.nl.translate_to.sv":"translate_sv_nl",
            "xx.fi.translate_to.ty":"translate_ty_fi",
            "xx.fr.translate_to.tr":"translate_tr_fr",
            "xx.sv.translate_to.tum":"translate_tum_sv",
            "xx.swc.translate_to.sv":"translate_sv_swc",
            "xx.fi.translate_to.swc":"translate_swc_fi",
            "xx.eo.translate_to.tr":"translate_tr_eo",
            "xx.xh.translate_to.sv":"translate_sv_xh",
            "xx.sv.translate_to.tvl":"translate_tvl_sv",
            "xx.sl.translate_to.sv":"translate_sv_sl",
            "xx.tum.translate_to.sv":"translate_sv_tum",
            "xx.es.translate_to.to":"translate_to_es",
            "xx.fr.translate_to.tn":"translate_tn_fr",
            "xx.sv.translate_to.ty":"translate_ty_sv",
            "xx.sv.translate_to.swc":"translate_swc_sv",
            "xx.mos.translate_to.sv":"translate_sv_mos",
            "xx.ar.translate_to.tr":"translate_tr_ar",
            "xx.ru.translate_to.sv":"translate_sv_ru",
            "xx.srn.translate_to.sv":"translate_sv_srn",
            "xx.pis.translate_to.sv":"translate_sv_pis",
            "xx.pap.translate_to.sv":"translate_sv_pap",
            "xx.tvl.translate_to.sv":"translate_sv_tvl",
            "xx.sv.translate_to.to":"translate_to_sv",
            "xx.th.translate_to.sv":"translate_sv_th",
            "xx.war.translate_to.sv":"translate_sv_war",
            "xx.sv.translate_to.ts":"translate_ts_sv",
            "xx.fr.translate_to.tw":"translate_tw_fr",
            "xx.st.translate_to.sv":"translate_sv_st",
            "xx.fr.translate_to.tiv":"translate_tiv_fr",
            "xx.tpi.translate_to.sv":"translate_sv_tpi",
            "xx.fi.translate_to.tvl":"translate_tvl_fi",
            "xx.fr.translate_to.ty":"translate_ty_fr",
            "xx.sm.translate_to.sv":"translate_sv_sm",
            "xx.es.translate_to.swc":"translate_swc_es",
            "xx.sv.translate_to.tiv":"translate_tiv_sv",
            "xx.toi.translate_to.sv":"translate_sv_toi",
            "xx.mfe.translate_to.sv":"translate_sv_mfe",
            "xx.wls.translate_to.sv":"translate_sv_wls",
            "xx.umb.translate_to.sv":"translate_sv_umb",
            "xx.es.translate_to.tr":"translate_tr_es",
            "xx.es.translate_to.tll":"translate_tll_es",
            "xx.pt.translate_to.uk":"translate_uk_pt",
            "xx.it.translate_to.zh":"translate_zh_it",
            "xx.no.translate_to.uk":"translate_uk_no",
            "xx.sh.translate_to.uk":"translate_uk_sh",
            "xx.sv.translate_to.wls":"translate_wls_sv",
            "xx.pl.translate_to.uk":"translate_uk_pl",
            "xx.es.translate_to.yo":"translate_yo_es",
            "xx.es.translate_to.war":"translate_war_es",
            "xx.sv.translate_to.zh":"translate_zh_sv",
            "xx.tr.translate_to.uk":"translate_uk_tr",
            "xx.fi.translate_to.war":"translate_war_fi",
            "xx.de.translate_to.zh":"translate_zh_de",
            "xx.uk.translate_to.zh":"translate_zh_uk",
            "xx.eo.translate_to.vi":"translate_vi_eo",
            "xx.bg.translate_to.zh":"translate_zh_bg",
            "xx.es.translate_to.zne":"translate_zne_es",
            "xx.fr.translate_to.uk":"translate_uk_fr",
            "xx.zls.translate_to.zls":"translate_zls_zls",
            "xx.fr.translate_to.yo":"translate_yo_fr",
            "xx.bg.translate_to.uk":"translate_uk_bg",
            "xx.fr.translate_to.xh":"translate_xh_fr",
            "xx.ca.translate_to.uk":"translate_uk_ca",
            "xx.fi.translate_to.zh":"translate_zh_fi",
            "xx.es.translate_to.zai":"translate_zai_es",
            "xx.es.translate_to.uk":"translate_uk_es",
            "xx.nl.translate_to.uk":"translate_uk_nl",
            "xx.sv.translate_to.yap":"translate_yap_sv",
            "xx.he.translate_to.uk":"translate_uk_he",
            "xx.sl.translate_to.uk":"translate_uk_sl",
            "xx.es.translate_to.ve":"translate_ve_es",
            "xx.zlw.translate_to.zlw":"translate_zlw_zlw",
            "xx.es.translate_to.tzo":"translate_tzo_es",
            "xx.hu.translate_to.uk":"translate_uk_hu",
            "xx.de.translate_to.vi":"translate_vi_de",
            "xx.fi.translate_to.yo":"translate_yo_fi",
            "xx.ru.translate_to.uk":"translate_uk_ru",
            "xx.ms.translate_to.zh":"translate_zh_ms",
            "xx.urj.translate_to.urj":"translate_urj_urj",
            "xx.it.translate_to.uk":"translate_uk_it",
            "xx.sv.translate_to.war":"translate_war_sv",
            "xx.fr.translate_to.wls":"translate_wls_fr",
            "xx.zle.translate_to.zle":"translate_zle_zle",
            "xx.vi.translate_to.zh":"translate_zh_vi",
            "xx.es.translate_to.vsl":"translate_vsl_es",
            "xx.fi.translate_to.zne":"translate_zne_fi",
            "xx.fi.translate_to.uk":"translate_uk_fi",
            "xx.ru.translate_to.vi":"translate_vi_ru",
            "xx.nl.translate_to.zh":"translate_zh_nl",
            "xx.sv.translate_to.xh":"translate_xh_sv",
            "xx.es.translate_to.xh":"translate_xh_es",
            "xx.he.translate_to.zh":"translate_zh_he",
            "xx.fr.translate_to.war":"translate_war_fr",
            "xx.fr.translate_to.zne":"translate_zne_fr",
            "xx.sv.translate_to.yo":"translate_yo_sv",
            "xx.fr.translate_to.vi":"translate_vi_fr",
            "xx.it.translate_to.vi":"translate_vi_it",
            "xx.sv.translate_to.zne":"translate_zne_sv",
            "xx.fr.translate_to.yap":"translate_yap_fr",
            "xx.cs.translate_to.uk":"translate_uk_cs",
            "xx.es.translate_to.vi":"translate_vi_es",
            "xx.de.translate_to.uk":"translate_uk_de",
            "xx.sv.translate_to.uk":"translate_uk_sv",

        },

    }
    pretrained_models_references = {
        'vi' : {
                'vi.lemma':'lemma',
                },
        'mt' : {
            'mt.lemma':'lemma',
        },

        'ta' : {
            'ta.lemma':'lemma',
        },

        'cy' : {
            'cy.lemma':'lemma',
        },


        'nl': {
            'nl.lemma': 'lemma',  # default lemma, dataset unknown
            'nl.pos': 'pos_ud_alpino',  # default pos nl
            'nl.pos.ud_alpino': 'pos_ud_alpino',
            'nl.ner': 'wikiner_6B_100',  # default ner nl
            'nl.ner.wikiner': 'wikiner_6B_100',  # default ner nl with embeds
            'nl.ner.wikiner.glove.6B_100': 'wikiner_6B_100',
            'nl.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'nl.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'nl.embed.bert': 'bert_base_dutch_cased',

        },
        'en': {
            # models
            'en.stem': 'stemmer',  # stem  default en
            'en.tokenize': 'spark_nlp_tokenizer',  # token default en
            'en.norm': 'norm',  # norm default en
            'en.chunk': 'default_chunker',  # default chunker  en
            'en.ngram': 'ngram',  # default chunker  en
            'en.embed_chunk': 'chunk_embeddings',  # default chunker  en

            'en.lemma': 'lemma_antbnc',  # lemma default en
            'en.lemma.antbnc': 'lemma_antbnc',
            'en.pos': 'pos_anc',  # pos default en
            'en.pos.anc': 'pos_anc',
            'en.pos.ud_ewt': 'pos_ud_ewt',
            # 'en.ner.crf' :'ner_crf', # crf not supported in NLU
            'en.ner': 'ner_dl',  # ner default en
            'en.ner.dl': 'ner_dl',  # ner embeds  default  en
            'en.ner.dl.glove.6B_100d': 'ner_dl',
            'en.ner.dl.bert': 'ner_dl_bert',  # points ner bert
            'en.ner.onto': 'onto_100',  # ner  onto default embeds en
            'en.ner.onto.glove.6B_100d': 'onto_100',
            'en.ner.onto.glove.840B_300d': 'onto_300',  # this uses multi lang embeds!

            # 2.7
            'en.ner.onto.bert.cased_base': 'onto_bert_base_cased',
            'en.ner.onto.bert.cased_large': 'onto_bert_large_cased',
            'en.ner.onto.electra.uncased_large': 'onto_electra_large_uncased',
            'en.ner.onto.bert.small_l2_128': 'onto_small_bert_L2_128',
            'en.ner.onto.bert.small_l4_256': 'onto_small_bert_L4_256',
            'en.ner.onto.bert.small_l4_512': 'onto_small_bert_L4_512',
            'en.ner.onto.bert.small_l8_512': 'onto_small_bert_L8_512',
            'en.ner.onto.electra.uncased_small': 'onto_electra_small_uncased',
            'en.ner.onto.electra.uncased_base': 'onto_electra_base_uncased',
            'en.ner.bert_base_cased': 'ner_dl_bert_base_cased',

            'en.ner.ade': 'ade_ner_100d',
            'en.ner.aspect_sentiment': 'ner_aspect_based_sentiment',

            'en.ner.glove.100d': 'ner_dl_sentence',
            # 'en.spell.symmetric': 'spellcheck_sd',
            'en.spell.norvig': 'spellcheck_norvig',
            'en.sentiment.vivekn': 'sentiment_vivekn',
            'en.dep.untyped.conllu': 'dependency_conllu',
            'en.dep.untyped': 'dependency_conllu',  # default untyped dependency
            'en.dep': 'dependency_typed_conllu',  # default typed dependency
            'en.dep.typed': 'dependency_typed_conllu',  # default typed dependency dataset
            'en.dep.typed.conllu': 'dependency_typed_conllu',
            'en.stopwords': 'stopwords_en',

            # embeddings
            'en.glove': 'glove_100d',  # default embed
            'en.embed': 'glove_100d',  # default glove en
            'en.embed.glove': 'glove_100d',  # default glove en
            'en.embed.glove.100d': 'glove_100d',
            'en.bert': 'bert_base_uncased',  # default bert
            'en.embed.bert': 'bert_base_uncased',  # default bert
            'en.embed.bert.base_uncased': 'bert_base_uncased',
            'en.embed.bert.base_cased': 'bert_base_cased',
            'en.embed.bert.large_uncased': 'bert_large_uncased',
            'en.embed.bert.large_cased': 'bert_large_cased',
            'biobert': 'biobert_pubmed_base_cased',  # alias
            'en.embed.biobert': 'biobert_pubmed_base_cased',  # default bio bert
            'en.embed.biobert.pubmed_base_cased': 'biobert_pubmed_base_cased',
            # TODO NO SUCH PARAM POOLING LAYER EXISTS!
            'en.embed.biobert.pubmed_large_cased': 'biobert_pubmed_large_cased',
            'en.embed.biobert.pmc_base_cased': 'biobert_pmc_base_cased',
            'en.embed.biobert.pubmed_pmc_base_cased': 'biobert_pubmed_pmc_base_cased',
            'en.embed.biobert.clinical_base_cased': 'biobert_clinical_base_cased',
            'en.embed.biobert.discharge_base_cased': 'biobert_discharge_base_cased',
            'en.embed.elmo': 'elmo',
            'en.embed_sentence': 'tfhub_use',  # default sentence

            'en.embed_sentence.use': 'tfhub_use',  # default use
            'en.use': 'tfhub_use',  # alias
            'en.embed_sentence.tfhub_use': 'tfhub_use',
            'en.embed_sentence.use.lg': 'tfhub_use_lg',  # alias
            'en.embed_sentence.tfhub_use.lg': 'tfhub_use_lg',

            'en.embed_sentence.albert': 'albert_base_uncased',  # albert default en

            'en.albert': 'albert_base_uncased',  # albert alias en
            'en.embed.albert': 'albert_base_uncased',  # albert alias en
            'en.embed.albert.base_uncased': 'albert_base_uncased',
            'en.embed.albert.large_uncased': 'albert_large_uncased',
            'en.embed.albert.xlarge_uncased': 'albert_xlarge_uncased',
            'en.embed.albert.xxlarge_uncased': 'albert_xxlarge_uncased',
            'en.embed.xlnet': 'xlnet_base_cased',  # xlnet default en
            'en.xlnet': 'xlnet_base_cased',  # xlnet alias
            'en.embed.xlnet_base_cased': 'xlnet_base_cased',
            'en.embed.xlnet_large_cased': 'xlnet_large_cased',

            # classifiers and sentiment

            'en.classify.trec6.use': 'classifierdl_use_trec6',
            'en.classify.trec50.use': 'classifierdl_use_trec50',
            'en.classify.question': 'classifierdl_use_trec50',
            'en.classify.questions': 'classifierdl_use_trec50',

            'en.classify.spam.use': 'classifierdl_use_spam',
            'en.classify.fakenews.use': 'classifierdl_use_fakenews',
            'en.classify.emotion.use': 'classifierdl_use_emotion',
            'en.classify.cyberbullying.use': 'classifierdl_use_cyberbullying',
            'en.classify.sarcasm.use': 'classifierdl_use_sarcasm',
            'en.sentiment.imdb.use': 'sentimentdl_use_imdb',
            'en.sentiment.twitter.use': 'sentimentdl_use_twitter',
            'en.sentiment.imdb.glove': 'sentimentdl_glove_imdb',
            'en.classify.trec6': 'classifierdl_use_trec6',  # Alias withouth embedding
            'en.classify.trec50': 'classifierdl_use_trec50',  # Alias withouth embedding
            'en.classify.spam': 'classifierdl_use_spam',  # Alias withouth embedding
            'en.classify.fakenews': 'classifierdl_use_fakenews',  # Alias withouth embedding
            'en.classify.emotion': 'classifierdl_use_emotion',  # Alias withouth embedding
            'en.classify.cyberbullying': 'classifierdl_use_cyberbullying',  # Alias withouth embedding
            'en.classify.sarcasm': 'classifierdl_use_sarcasm',  # Alias withouth embedding
            'en.sentiment.twitter': 'sentimentdl_use_twitter',  # Alias withouth embedding

            # 2.6 Release models
            'en.yake': 'yake',

            # 2.6  embeds
            'en.embed.electra': 'electra_small_uncased',
            'en.embed.electra.small_uncased': 'electra_small_uncased',
            'en.embed.electra.base_uncased': 'electra_base_uncased',
            'en.embed.electra.large_uncased': 'electra_large_uncased',

            'en.embed.covidbert': 'covidbert_large_uncased',
            'en.embed.covidbert.large_uncased': 'covidbert_large_uncased',
            'en.embed.bert.small_L2_128': 'small_bert_L2_128',
            'en.embed.bert.small_L4_128': 'small_bert_L4_128',
            'en.embed.bert.small_L6_128': 'small_bert_L6_128',
            'en.embed.bert.small_L8_128': 'small_bert_L8_128',
            'en.embed.bert.small_L10_128': 'small_bert_L10_128',
            'en.embed.bert.small_L12_128': 'small_bert_L12_128',
            'en.embed.bert.small_L2_256': 'small_bert_L2_256',
            'en.embed.bert.small_L4_256': 'small_bert_L4_256',
            'en.embed.bert.small_L6_256': 'small_bert_L6_256',
            'en.embed.bert.small_L8_256': 'small_bert_L8_256',
            'en.embed.bert.small_L10_256': 'small_bert_L10_256',
            'en.embed.bert.small_L12_256': 'small_bert_L12_256',
            'en.embed.bert.small_L2_512': 'small_bert_L2_512',
            'en.embed.bert.small_L4_512': 'small_bert_L4_512',
            'en.embed.bert.small_L6_512': 'small_bert_L6_512',
            'en.embed.bert.small_L8_512': 'small_bert_L8_512',
            'en.embed.bert.small_L10_512': 'small_bert_L10_512',
            'en.embed.bert.small_L12_512': 'small_bert_L12_512',
            'en.embed.bert.small_L2_768': 'small_bert_L2_768',
            'en.embed.bert.small_L4_768': 'small_bert_L4_768',
            'en.embed.bert.small_L6_768': 'small_bert_L6_768',
            'en.embed.bert.small_L8_768': 'small_bert_L8_768',
            'en.embed.bert.small_L10_768': 'small_bert_L10_768',
            'en.embed.bert.small_L12_768': 'small_bert_L12_768',

            # 2.6 sent embeddings
            'en.embed_sentence.electra': 'sent_electra_small_uncased',

            'en.embed_sentence.electra_small_uncased': 'sent_electra_small_uncased',
            'en.embed_sentence.electra_base_uncased': 'sent_electra_base_uncased',
            'en.embed_sentence.electra_large_uncased': 'sent_electra_large_uncased',
            'en.embed_sentence.bert': 'sent_bert_base_uncased',

            'en.embed_sentence.bert_base_uncased': 'sent_bert_base_uncased',
            'en.embed_sentence.bert_base_cased': 'sent_bert_base_cased',
            'en.embed_sentence.bert_large_uncased': 'sent_bert_large_uncased',
            'en.embed_sentence.bert_large_cased': 'sent_bert_large_cased',
            'en.embed_sentence.biobert.pubmed_base_cased': 'sent_biobert_pubmed_base_cased',
            'en.embed_sentence.biobert.pubmed_large_cased': 'sent_biobert_pubmed_large_cased',
            'en.embed_sentence.biobert.pmc_base_cased': 'sent_biobert_pmc_base_cased',
            'en.embed_sentence.biobert.pubmed_pmc_base_cased': 'sent_biobert_pubmed_pmc_base_cased',
            'en.embed_sentence.biobert.clinical_base_cased': 'sent_biobert_clinical_base_cased',
            'en.embed_sentence.biobert.discharge_base_cased': 'sent_biobert_discharge_base_cased',
            'en.embed_sentence.covidbert.large_uncased': 'sent_covidbert_large_uncased',
            'en.embed_sentence.small_bert_L2_128': 'sent_small_bert_L2_128',
            'en.embed_sentence.small_bert_L4_128': 'sent_small_bert_L4_128',
            'en.embed_sentence.small_bert_L6_128': 'sent_small_bert_L6_128',
            'en.embed_sentence.small_bert_L8_128': 'sent_small_bert_L8_128',
            'en.embed_sentence.small_bert_L10_128': 'sent_small_bert_L10_128',
            'en.embed_sentence.small_bert_L12_128': 'sent_small_bert_L12_128',
            'en.embed_sentence.small_bert_L2_256': 'sent_small_bert_L2_256',
            'en.embed_sentence.small_bert_L4_256': 'sent_small_bert_L4_256',
            'en.embed_sentence.small_bert_L6_256': 'sent_small_bert_L6_256',
            'en.embed_sentence.small_bert_L8_256': 'sent_small_bert_L8_256',
            'en.embed_sentence.small_bert_L10_256': 'sent_small_bert_L10_256',
            'en.embed_sentence.small_bert_L12_256': 'sent_small_bert_L12_256',
            'en.embed_sentence.small_bert_L2_512': 'sent_small_bert_L2_512',
            'en.embed_sentence.small_bert_L4_512': 'sent_small_bert_L4_512',
            'en.embed_sentence.small_bert_L6_512': 'sent_small_bert_L6_512',
            'en.embed_sentence.small_bert_L8_512': 'sent_small_bert_L8_512',
            'en.embed_sentence.small_bert_L10_512': 'sent_small_bert_L10_512',
            'en.embed_sentence.small_bert_L12_512': 'sent_small_bert_L12_512',
            'en.embed_sentence.small_bert_L2_768': 'sent_small_bert_L2_768',
            'en.embed_sentence.small_bert_L4_768': 'sent_small_bert_L4_768',
            'en.embed_sentence.small_bert_L6_768': 'sent_small_bert_L6_768',
            'en.embed_sentence.small_bert_L8_768': 'sent_small_bert_L8_768',
            'en.embed_sentence.small_bert_L10_768': 'sent_small_bert_L10_768',
            'en.embed_sentence.small_bert_L12_768': 'sent_small_bert_L12_768',

            # 2.6 classifiers
            'en.classify.toxic': 'multiclassifierdl_use_toxic',
            'en.toxic': 'multiclassifierdl_use_toxic',

            'en.e2e': 'multiclassifierdl_use_e2e',

            'en.classify.toxic.sm': 'multiclassifierdl_use_toxic_sm',
            'en.classify.e2e': 'multiclassifierdl_use_e2e',

            # 2.7 seq2seq
            'en.t5': 'google_t5_small_ssm_nq',
            'en.t5.small': 't5_small',
            'en.t5.base': 't5_base',
            # 2.7.0 new aliases
            'en.t5.summarize': 't5_base',
            'en.t5.classify.grammar_correctness': 't5_base',
            'en.t5.classify.sentiment': 't5_base',
            'en.t5.answer_question': 't5_base',

            # 2.7,1 and 2.7.2 ATIS classifier and ALIASES
            "en.classify.questions.atis": "classifierdl_use_atis",
            "en.classify.questions.airline": "classifierdl_use_atis",
            "en.classify.intent.atis": "classifierdl_use_atis",
            "en.classify.intent.airline": "classifierdl_use_atis",

            # 2.7,1 and 2.7.2 ATIS NER and ALIASES
            "en.ner.atis": "nerdl_atis_840b_300d",
            "en.ner.airline": "nerdl_atis_840b_300d",
            "en.ner.aspect.airline": "nerdl_atis_840b_300d",
            "en.ner.aspect.atis": "nerdl_atis_840b_300d",
            # 2.7.3 snips
            'en.classify.snips': 'nerdl_snips_100d',
            'en.ner.snips': 'classifierdl_use_snips',

            # 3.1
            "en.embed.distilbert"  :'distilbert_base_cased',
            "en.embed.distilbert.base"  :'distilbert_base_cased',
            "en.embed.distilbert.base.uncased"  :'distilbert_base_uncased',
            "en.embed.distilroberta"  :'distilroberta_base',
            'roberta': 'distilroberta_base',
            "en.embed.roberta"  :'roberta_base',
            "en.embed.roberta.base"  :'roberta_base',
            "en.embed.roberta.large"  :'roberta_large',


        },
        'fr': {
            'fr.lemma': 'lemma',
            'fr.pos': 'pos_ud_gsd',  # default pos fr
            'fr.pos.ud_gsd': 'pos_ud_gsd',
            'fr.ner': 'wikiner_840B_300',  # default ner fr
            'fr.ner.wikiner': 'wikiner_840B_300',  # default nr embeds fr
            'fr.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'fr.stopwords': 'stopwords_fr',
            'fr.ner.wikiner.glove.6B_300': 'wikiner_6B_300',

        },
        'de': {
            'de.lemma': 'lemma',
            'de.pos.ud_hdt': 'pos_ud_hdt',
            'de.pos': 'pos_ud_hdt',  # default pos de
            'de.ner': 'wikiner_840B_300',  # default ner de
            'de.ner.wikiner': 'wikiner_840B_300',  # default ner embeds de
            'de.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'de.stopwords': 'stopwords_de',
            'de.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'de.embed.bert' : 'bert_base_german_cased',
           'de.embed.bert.uncased' : '	bert_base_german_uncased'
        },
        'it': {
            'it.lemma': 'lemma_dxc',  # default lemma it
            'it.lemma.dxc': 'lemma_dxc',
            'it.sentiment.dxc': 'sentiment_dxc',
            'it.sentiment': 'sentiment_dxc',  # defauult sentiment it
            'it.pos': 'pos_ud_isdt',  # default pos it
            'it.pos.ud_isdt': 'pos_ud_isdt',
            'it.ner': 'wikiner_840B_300',  # default ner it
            'it.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'it.stopwords': 'stopwords_it',
            'it.embed.bert': 'bert_base_italian_cased',
            'it.embed.bert.uncased': 'bert_base_italian_uncased',



        },
        'nb': {
            'nb.lemma': 'lemma',
            'nb.pos.ud_bokmaal': 'pos_ud_bokmaal',

        },
        'no': {
            'no.ner': 'norne_6B_100',  # ner default no
            'no.ner.norne': 'norne_6B_100',  # ner default no embeds
            'no.ner.norne.glove.6B_100': 'norne_6B_100',
            'no.ner.norne.glove.6B_300': 'norne_6B_300',
            'no.ner.norne.glove.840B_300': 'norne_840B_300',

        },
        'nn': {
            'nn.pos': 'pos_ud_nynorsk',  # nn default pos
            'nn.pos.ud_nynorsk': 'pos_ud_nynorsk',

        },
        'pl': {
            'pl.lemma': 'lemma',
            'pl.pos': 'pos_ud_lfg',  # pls default pos
            'pl.pos.ud_lfg': 'pos_ud_lfg',
            'pl.ner': 'wikiner_6B_100',  # pl default ner
            'pl.ner.wikiner': 'wikiner_6B_100',  # pls default ner embeds
            'pl.ner.wikiner.glove.6B_100': 'wikiner_6B_100',
            'pl.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'pl.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'pl.stopwords': 'stopwords_pl'
        },
        'pt': {
            'pt.lemma': 'lemma',
            'pt.pos.ud_bosque': 'pos_ud_bosque',
            'pt.pos': 'pos_ud_bosque',  # pt default pos
            'pt.ner': 'wikiner_6B_100',  # pt default ner
            'pt.ner.wikiner.glove.6B_100': 'wikiner_6B_100',  # pt default embeds ner
            'pt.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'pt.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'pt.stopwords': 'stopwords_pt',
            'pt.bert': 'bert_portuguese_base_cased',
            'pt.bert.cased': 'bert_portuguese_base_cased',
            'pt.bert.cased.large': 'bert_portuguese_large_cased',

        },
        'ru': {
            'ru.lemma': 'lemma',
            'ru.pos.ud_gsd': 'pos_ud_gsd',
            'ru.pos': 'pos_ud_gsd',  # pos default ru
            'ru.ner': 'wikiner_6B_100',  # ner default ru
            'ru.ner.wikiner': 'wikiner_6B_100',  # ner embeds default ru
            'ru.ner.wikiner.glove.6B_100': 'wikiner_6B_100',
            'ru.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'ru.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'ru.stopwords': 'stopwords_ru',

        },
        'es': {
            'es.lemma': 'lemma',
            'es.pos': 'pos_ud_gsd',  # pos default es
            'es.pos.ud_gsd': 'pos_ud_gsd',
            'es.ner': 'wikiner_6B_100',  # ner default es
            'es.ner.wikiner': 'wikiner_6B_100',  # ner default embeds es
            'es.ner.wikiner.glove.6B_100': 'wikiner_6B_100',
            'es.ner.wikiner.glove.6B_300': 'wikiner_6B_300',
            'es.ner.wikiner.glove.840B_300': 'wikiner_840B_300',
            'es.stopwords_es': 'stopwords_es',
        },
        'af': {
            'af.stopwords': 'stopwords_af',
            'af.lemma':'lemma',
            'af.pos':'pos_afribooms',


        },
        'ar': {
            'ar.stopwords': 'stopwords_ar',
            'ar.lemma': 'lemma',
            'ar.pos': 'pos_ud_padt',
            'ar.embed': 'arabic_w2v_cc_300d',
            'ar.embed.cbow': 'arabic_w2v_cc_300d',
            'ar.embed.cbow.300d': 'arabic_w2v_cc_300d',
            "ar.embed.aner": "arabic_w2v_cc_300d",
            "ar.embed.aner.300d": "arabic_w2v_cc_300d",
            "ar.embed.glove": "arabic_w2v_cc_300d",

            "ar.ner": "aner_cc_300d",
            "ar.ner.aner": "aner_cc_300d",

        },
        'hy': {
            'hy.stopwords': 'stopwords_hy',
            'hy.lemma': 'lemma',
            'hy.pos': 'pos_ud_armtdp',

        },
        'eu': {
            'eu.stopwords': 'stopwords_eu',
            'eu.lemma': 'lemma',
            'eu.pos': 'pos_ud_bdt',

        },
        'bn': {
            'bn.stopwords': 'stopwords_bn',
            "bn.lemma": "lemma",
            "bn.pos": "pos_msri",
            'bn.ner': 'ner_jifs_glove_840B_300d',
            'bn.ner.glove': 'ner_jifs_glove_840B_300d',
            'bn.embed.glove': 'bengaliner_cc_300d',
            'bn.embed': 'bengaliner_cc_300d',
            'bn.ner.cc': 'bengali_cc_300d',
            'bn.ner.cc_300d': 'bengali_cc_300d',

        },
        'br': {
            'br.stopwords': 'stopwords_br',
            'br.lemma': 'lemma',
            'br.pos': 'pos_ud_keb',

        },
        'bg': {
            'bg.lemma': 'lemma',
            'bg.pos': 'pos_ud_btb',  # default bg pos
            'bg.pos.ud_btb': 'pos_ud_btb',
            'bg.stopwords': 'stopwords_bg',

        },
        'ca': {
            'ca.stopwords': 'stopwords_ca',
            'ca.lemma': 'lemma',
            'ca.pos': 'pos_ud_ancora',

        },
        'cs': {
            'cs.lemma': 'lemma',
            'cs.pos': 'pos_ud_pdt',  # default cs pos
            'cs.pos.ud_pdt': 'pos_ud_pdt',
            'cs.stopwords': 'stopwords_cs',
        },
        'eo': {
            'eo.stopwords': 'stopwords_eo'

        },
        'fi': {
            'fi.lemma': 'lemma',
            'fi.pos.ud_tdt': 'pos_ud_tdt',
            'fi.pos': 'pos_ud_tdt',  # default pos fi
            'fi.stopwords': 'stopwords_fi',
            'fi.ner': 'wikiner_6B_100',
            'fi.ner.6B_100': 'wikiner_6B_100',
            'fi.ner.6B_300': 'wikiner_6B_300',
            'fi.ner.840B_300': 'wikiner_840B_300',
            'fi.embed.bert.': 'bert_finnish_cased',
            'fi.embed.bert.cased.': 'bert_finnish_cased',
            'fi.embed.bert.uncased.': 'bert_finnish_uncased',
            'fi.embed_sentence': 'sent_bert_finnish_cased',
            'fi.embed_sentence.bert.cased': 'sent_bert_finnish_cased',
            'fi.embed_sentence.bert.uncased': 'sent_bert_finnish_uncased',
            'fi.ner.6B_100d': 'finnish_ner_6B_100',
            'fi.ner.6B_300d': 'finnish_ner_6B_300',
            'fi.ner.840B_300d': 'finnish_ner_840B_300',

        },
        'gl': {
            'gl.stopwords': 'stopwords_gl',
            'gl.lemma': 'lemma',
            'gl.pos': 'pos_ud_treegal',

        },
        'el': {
            'el.lemma': 'lemma',
            'el.pos': 'pos_ud_gdt',  # default POS  el
            'el.pos.ud_gdt': 'pos_ud_gdt',
            'el.stopwords': 'stopwords_el',
        },
        'ha': {
            'ha.stopwords': 'stopwords_ha'

        },
        'he': {
            'he.stopwords': 'stopwords_he',
            'he.embed': 'hebrew_cc_300d',  # default he embeddings
            'he.embed.glove': 'hebrew_cc_300d',  # default he cbow embeddings
            'he.embed.cbow_300d': 'hebrew_cc_300d',  # default he embeddings
            'he.ner': 'hebrewner_cc_300d',  # default he ner
            'he.ner.cc_300d': 'hebrewner_cc_300d',
            'he.pos': 'pos_ud_htb',  # defauklt he pos
            'he.pos.ud_htb': 'pos_ud_htb',  #
            'he.lemma': 'lemma',

        },
        'hi': {
            'hi.stopwords': 'stopwords_hi',
            'hi.lemma': 'lemma',
            'hi.pos': 'pos_ud_hdtb',
            'hi.embed': 'hindi_cc_300d'

        },
        'hu': {
            'hu.lemma': 'lemma',
            'hu.pos': 'pos_ud_szeged',  # hu default pos
            'hu.pos.ud_szeged': 'pos_ud_szeged',
            'hu.stopwords': 'stopwords_hu',

        },
        'id': {
            'id.stopwords': 'stopwords_id',
            'id.lemma': 'lemma',
            'id.pos': 'pos_ud_gsd',

        },
        'ga': {
            'ga.stopwords': 'stopwords_ga',
            'ga.lemma': 'lemma',
            'ga.pos': 'pos_ud_idt',

        },
        'da': {
            'da.lemma': 'lemma',
            'da.pos': 'pos_ud_ddt',
            'da.ner': 'dane_ner_6B_100',
            'da.ner.6B_100D': 'dane_ner_6B_100',
            'da.ner.6B_300D': 'dane_ner_6B_300',
            'da.ner.840B_300D': 'dane_ner_840B_300'

        },
        'ja': {
            'ja.stopwords': 'stopwords_ja',
            'ja.segment_words': 'wordseg_gsd_ud',
            'ja.ner': 'ner_ud_gsd_glove_840B_300d',  # default ja ner
            'ja.pos': 'pos_ud_gsd',  # default pos ner
            'ja.ner.ud_gsd': 'ner_ud_gsd_glove_840B_300d',  # default ner ud_gsd
            'ja.ner.ud_gsd.glove_840B_300D': 'ner_ud_gsd_glove_840B_300d',
            'ja.pos.ud_gsd': 'pos_ud_gsd',
            "ja.lemma": "lemma",

        },
        'la': {
            'la.stopwords': 'stopwords_la',
            'la.lemma': 'lemma',
            'la.pos': 'pos_ud_llct',

        },
        'lv': {
            'lv.stopwords': 'stopwords_lv',
            'lv.lemma': 'lemma',
            'lv.pos': 'pos_ud_lvtb',

        },
        'mr': {
            'mr.stopwords': 'stopwords_mr',
            'mr.lemma': 'lemma',
            'mr.pos': 'pos_ud_ufal',
        },
        'fa': {
            'fa.stopwords': 'stopwords_fa',
            'fa.lemma': 'lemma',
            'fa.pos': 'pos_ud_perdt',
            'fa.ner': 'personer_cc_300d',  # default fa pos
            'fa.ner.person': 'personer_cc_300d',  # default fa ner person
            'fa.ner.person.cc_300d': 'personer_cc_300d',
            'fa.embed': 'persian_w2v_cc_300d',  # default fa embeds
            'fa.embed.word2vec': 'persian_w2v_cc_300d',  # default fa word2vec embeds
            'fa.embed.word2vec.300d': 'persian_w2v_cc_300d',

        },
        'ro': {
            'ro.lemma': 'lemma',
            'ro.pos': 'pos_ud_rrt',
            'ro.pos.ud_rrt': 'pos_ud_rrt',
            'ro.stopwords': 'stopwords_ro',
        },
        'sk': {
            'sk.lemma': 'lemma',
            'sk.pos': 'pos_ud_snk',  # default sk pos
            'sk.pos.ud_snk': 'pos_ud_snk',
            'sk.stopwords': 'stopwords_sk',
        },
        'sl': {
            'sl.stopwords': 'stopwords_sl',
            'sl.lemma': 'lemma',
            'sl.pos': 'pos_ud_ssj',

        },
        'so': {
            'so.stopwords': 'stopwords_so'

        },
        'st': {
            'st.stopwords': 'stopwords_st'
        },
        'sw': {
            'sw.stopwords': 'stopwords_sw'
        },
        'sv': {
            'sv.lemma': 'lemma',
            'sv.pos': 'pos_ud_tal',  # default sv pos
            'sv.pos.ud_tal': 'pos_ud_tal',
            'sv.stopwords': 'stopwords_sv',
            'sv.ner': 'swedish_ner_6B_100',
            'sv.ner.6B_100': 'swedish_ner_6B_100',
            'sv.ner.6B_300': 'swedish_ner_6B_300',
            'sv.ner.840B_300': 'swedish_ner_840B_300'
        },
        'th': {
            'th.stopwords': 'stopwords_th',
            'th.ner.lst20.glove_840B_300D': 'ner_lst20_glove_840B_300d',
            "th.segment_words": "wordseg_best",
            "th.pos": "pos_lst20",
            "th.sentiment": "sentiment_jager_use",
            "th.classify.sentiment": "sentiment_jager_use",

        },
        'tr': {
            'tr.lemma': 'lemma',
            'tr.pos': 'pos_ud_imst',  # pos tr default
            'tr.pos.ud_imst': 'pos_ud_imst',
            'tr.stopwords': 'stopwords_tr',
            'tr.ner': 'turkish_ner_840B_300',  # ner tr default
            'tr.ner.bert': 'turkish_ner_bert' , # ner tr default
            'tr.classify.news'  : 'classifierdl_bert_news',
            'tr.embed.bert'  : 'bert_base_turkish_cased',
            'tr.embed.bert.uncased'  : '	bert_base_turkish_uncased',
        },
        'uk': {
            'uk.lemma': 'lemma',  # default uk lemma
            'uk.pos': 'pos_ud_iu',  # default uk pos
            'uk.pos.ud_iu': 'pos_ud_iu',
        },
        'yo': {
            'yo.stopwords': 'stopwords_yo',
            'yo.lemma': 'lemma',
            'yo.pos': 'pos_ud_ytb'

        },
        'zu': {
            'zu.stopwords': 'stopwords_zu'
        },
        'zh': {

            'zh.segment_words': 'wordseg_weibo',  # defaul zh wordseg,
            'zh.tokenize': 'wordseg_weibo',  # defaul tokenize alias

            'zh.segment_words.weibo': 'wordseg_weibo',
            'zh.segment_words.pku': 'wordseg_pku',
            'zh.segment_words.msra': 'wordseg_msra',
            'zh.segment_words.large': 'wordseg_large',
            'zh.segment_words.ctb9': 'wordseg_ctb9',
            "zh.segment_words.gsd": "wordseg_gsd_ud_trad",

            'zh.pos': 'pos_ud_gsd',  # default zh pos,
            'zh.pos.ud_gsd': 'pos_ud_gsd',
            'zh.pos.ctb9': 'pos_ctb9',
            "zh.pos.ud_gsd_trad": "pos_ud_gsd_trad",

            'zh.ner': 'ner_msra_bert_768d',  # default zh ner,
            'zh.ner.bert': 'ner_msra_bert_768d',  # default zh bert nert,
            'zh.ner.msra.bert_768D': 'ner_msra_bert_768d',  # default zh bert nert,
            'zh.ner.weibo.bert_768d': 'ner_weibo_bert_768d',
            'zh.lemma': 'lemma',
            'zh.embed': 'bert_base_chinese',
            'zh.embed.bert': 'bert_base_chinese',  # default zh embeds
            'zh.embed.bert.wwm': 'chinese_bert_wwm',  # default zh embeds

        }
        ,

        'et': {
            'et.lemma': 'lemma',
            'et.pos': 'pos_ud_edt',
        },
        'ur': {
            'ur.lemma': 'lemma',
            'ur.pos': 'pos_ud_udtb',  # default ur pos
            'ur.pos.ud_udtb': 'pos_ud_udtb',

            'ur.sentiment': 'sentimentdl_urduvec_imdb',
            'ur.embed': 'urduvec_140M_300d',  # default ur embeds
            'ur.embed.glove.300d': 'urduvec_140M_300d',  # default ur embeds
            'ur.embed.urdu_vec_140M_300d': 'urduvec_140M_300d',
            'ur.ner': 'uner_mk_140M_300d',
            'ur.ner.mk_140M_300d': 'uner_mk_140M_300d',

        },

        'ko': {

            'ko.segment_words': 'wordseg_kaist_ud',
            'ko.pos': 'pos_ud_kaist',  # default ko pos
            'ko.ner': 'ner_kmou_glove_840B_300d',  # default ko ner
            'ko.pos.ud_kaist': 'pos_ud_kaist',
            'ko.ner.kmou': 'ner_kmou_glove_840B_300d',  # default ner kmou
            'ko.ner.kmou.glove_840B_300d': 'ner_kmou_glove_840B_300d',
            "ko.lemma": "lemma",

        },

        'bh': {
            "bh.pos": "pos_ud_bhtb",
            "bh.lemma": "lemma",
        },
        'am': {
            "am.pos": "pos_ud_att",
            "am.lemma": "lemma",
        },

        'xx': {
            'xx.embed': 'glove_840B_300',

            'xx.embed.glove.840B_300': 'glove_840B_300',

            # 'xx.embed.glove.840B_300': 'glove_840B_300',
            'xx.embed.glove.6B_300': 'glove_6B_300',
            'xx.embed.bert_multi_cased': 'bert_multi_cased',
            'xx.embed.bert': 'bert_multi_cased',

            'xx.classify.wiki_7': 'ld_wiki_7',
            'xx.classify.wiki_20': 'ld_wiki_20',
            'xx.classify.wiki_21': 'ld_wiki_tatoeba_cnn_21',
            'xx.classify.wiki_21.bigru': 'ld_tatoeba_bigru_21',
            'xx.classify.wiki_99': 'ld_tatoeba_cnn_99',
            'xx.classify.wiki_231': 'ld_wiki_cnn_231',
            'xx.classify.wiki_43': 'ld_wiki_tatoeba_cnn_43',
            'xx.classify.wiki_95': 'ld_wiki_tatoeba_cnn_95',
            'xx.classify.wiki_220': 'ld_wiki_tatoeba_cnn_220',
            'xx.classify.wiki_375': 'ld_wiki_tatoeba_cnn_375',

            'xx.embed_sentence': 'sent_bert_multi_cased',
            'xx.embed_sentence.bert': 'sent_bert_multi_cased',
            'xx.embed_sentence.bert.cased': 'sent_bert_multi_cased',
            'xx.embed_sentence.labse': 'labse',
            'xx.sentence_detector': 'sentence_detector_dl',
            'xx.marian': 'opus_mt_en_fr',

            # 3.1
            "xx.embed.distilbert"  :'distilbert_base_multilingual_cased',
            "xx.embed.xlm"  :'xlm_roberta_base',
            "xx.embed.xlm.base"  :'xlm_roberta_base',
            "xx.embed.xlm.twitter"  :'twitter_xlm_roberta_base',
            # 2.7
            'xx.use.multi': 'tfhub_use_multi',
            'xx.use.multi_lg': 'tfhub_use_multi_lg',
            'xx.use.xling_en_de': 'tfhub_use_xling_en_de',
            'xx.use.xling_en_es': 'tfhub_use_xling_en_es',
            'xx.use.xling_en_fr': 'tfhub_use_xling_en_fr',
            'xx.use.xling_many': 'tfhub_use_xling_many',
            'xx.use.multi'

            # 2.7.0 marian translate model references
            "xx.swc.marian.translate_to.en": "opus_mt_swc_en",
            "xx.en.marian.translate_to.umb": "opus_mt_en_umb",
            "xx.en.marian.translate_to.bem": "opus_mt_en_bem",
            "xx.kwy.marian.translate_to.en": "opus_mt_kwy_en",
            "xx.en.marian.translate_to.ti": "opus_mt_en_ti",
            "xx.efi.marian.translate_to.en": "opus_mt_efi_en",
            "xx.taw.marian.translate_to.en": "opus_mt_taw_en",
            "xx.bem.marian.translate_to.en": "opus_mt_bem_en",
            "xx.en.marian.translate_to.sw": "opus_mt_en_sw",
            "xx.en.marian.translate_to.sn": "opus_mt_en_sn",
            "xx.pqe.marian.translate_to.en": "opus_mt_pqe_en",
            "xx.ny.marian.translate_to.en": "opus_mt_ny_en",
            "xx.urj.marian.translate_to.en": "opus_mt_urj_en",
            "xx.war.marian.translate_to.en": "opus_mt_war_en",
            "xx.nso.marian.translate_to.en": "opus_mt_nso_en",
            "xx.en.marian.translate_to.hu": "opus_mt_en_hu",
            "xx.en.marian.translate_to.cpp": "opus_mt_en_cpp",
            "xx.ja.marian.translate_to.en": "opus_mt_ja_en",
            "xx.en.marian.translate_to.rn": "opus_mt_en_rn",
            "xx.en.marian.translate_to.bcl": "opus_mt_en_bcl",
            "xx.en.marian.translate_to.bi": "opus_mt_en_bi",
            "xx.vi.marian.translate_to.en": "opus_mt_vi_en",
            "xx.ln.marian.translate_to.en": "opus_mt_ln_en",
            "xx.en.marian.translate_to.itc": "opus_mt_en_itc",
            "xx.itc.marian.translate_to.en": "opus_mt_itc_en",
            "xx.uk.marian.translate_to.en": "opus_mt_uk_en",
            "xx.en.marian.translate_to.gmq": "opus_mt_en_gmq",
            "xx.loz.marian.translate_to.en": "opus_mt_loz_en",
            "xx.mg.marian.translate_to.en": "opus_mt_mg_en",
            "xx.bnt.marian.translate_to.en": "opus_mt_bnt_en",
            "xx.en.marian.translate_to.zls": "opus_mt_en_zls",
            "xx.mkh.marian.translate_to.en": "opus_mt_mkh_en",
            "xx.en.marian.translate_to.lg": "opus_mt_en_lg",
            "xx.et.marian.translate_to.en": "opus_mt_et_en",
            "xx.fi.marian.translate_to.en": "opus_mt_fi_en",
            "xx.en.marian.translate_to.vi": "opus_mt_en_vi",
            "xx.en.marian.translate_to.ga": "opus_mt_en_ga",
            "xx.nic.marian.translate_to.en": "opus_mt_nic_en",
            "xx.lua.marian.translate_to.en": "opus_mt_lua_en",
            "xx.afa.marian.translate_to.en": "opus_mt_afa_en",
            "xx.en.marian.translate_to.pis": "opus_mt_en_pis",
            "xx.en.marian.translate_to.ts": "opus_mt_en_ts",
            "xx.sv.marian.translate_to.en": "opus_mt_sv_en",
            "xx.en.marian.translate_to.dra": "opus_mt_en_dra",
            "xx.en.marian.translate_to.pag": "opus_mt_en_pag",
            "xx.en.marian.translate_to.ln": "opus_mt_en_ln",
            "xx.alv.marian.translate_to.en": "opus_mt_alv_en",
            "xx.ee.marian.translate_to.en": "opus_mt_ee_en",
            "xx.bg.marian.translate_to.en": "opus_mt_bg_en",
            "xx.en.marian.translate_to.tw": "opus_mt_en_tw",
            "xx.en.marian.translate_to.gaa": "opus_mt_en_gaa",
            "xx.en.marian.translate_to.tll": "opus_mt_en_tll",
            "xx.en.marian.translate_to.phi": "opus_mt_en_phi",
            "xx.en.marian.translate_to.tiv": "opus_mt_en_tiv",
            "xx.en.marian.translate_to.ss": "opus_mt_en_ss",
            "xx.en.marian.translate_to.cs": "opus_mt_en_cs",
            "xx.kwn.marian.translate_to.en": "opus_mt_kwn_en",
            "xx.mh.marian.translate_to.en": "opus_mt_mh_en",
            "xx.en.marian.translate_to.cy": "opus_mt_en_cy",
            "xx.en.marian.translate_to.mt": "opus_mt_en_mt",
            "xx.en.marian.translate_to.ber": "opus_mt_en_ber",
            "xx.ine.marian.translate_to.en": "opus_mt_ine_en",
            "xx.ng.marian.translate_to.en": "opus_mt_ng_en",
            "xx.ase.marian.translate_to.en": "opus_mt_ase_en",
            "xx.en.marian.translate_to.afa": "opus_mt_en_afa",
            "xx.en.marian.translate_to.ml": "opus_mt_en_ml",
            "xx.en.marian.translate_to.zle": "opus_mt_en_zle",
            "xx.wal.marian.translate_to.en": "opus_mt_wal_en",
            "xx.en.marian.translate_to.sit": "opus_mt_en_sit",
            "xx.hy.marian.translate_to.en": "opus_mt_hy_en",
            "xx.umb.marian.translate_to.en": "opus_mt_umb_en",
            "xx.en.marian.translate_to.cpf": "opus_mt_en_cpf",
            "xx.en.marian.translate_to.gv": "opus_mt_en_gv",
            "xx.en.marian.translate_to.pap": "opus_mt_en_pap",
            "xx.gl.marian.translate_to.en": "opus_mt_gl_en",
            "xx.kqn.marian.translate_to.en": "opus_mt_kqn_en",
            "xx.ca.marian.translate_to.en": "opus_mt_ca_en",
            "xx.gem.marian.translate_to.en": "opus_mt_gem_en",
            "xx.en.marian.translate_to.crs": "opus_mt_en_crs",
            "xx.en.marian.translate_to.rw": "opus_mt_en_rw",
            "xx.en.marian.translate_to.ig": "opus_mt_en_ig",
            "xx.en.marian.translate_to.aav": "opus_mt_en_aav",
            "xx.en.marian.translate_to.tl": "opus_mt_en_tl",
            "xx.sm.marian.translate_to.en": "opus_mt_sm_en",
            "xx.en.marian.translate_to.hi": "opus_mt_en_hi",
            "xx.chk.marian.translate_to.en": "opus_mt_chk_en",
            "xx.en.marian.translate_to.kwy": "opus_mt_en_kwy",
            "xx.en.marian.translate_to.ho": "opus_mt_en_ho",
            "xx.ve.marian.translate_to.en": "opus_mt_ve_en",
            "xx.ceb.marian.translate_to.en": "opus_mt_ceb_en",
            "xx.aav.marian.translate_to.en": "opus_mt_aav_en",
            "xx.st.marian.translate_to.en": "opus_mt_st_en",
            "xx.en.marian.translate_to.cus": "opus_mt_en_cus",
            "xx.en.marian.translate_to.bnt": "opus_mt_en_bnt",
            "xx.iso.marian.translate_to.en": "opus_mt_iso_en",
            "xx.tr.marian.translate_to.en": "opus_mt_tr_en",
            "xx.om.marian.translate_to.en": "opus_mt_om_en",
            "xx.fj.marian.translate_to.en": "opus_mt_fj_en",
            "xx.ml.marian.translate_to.en": "opus_mt_ml_en",
            "xx.en.marian.translate_to.ro": "opus_mt_en_ro",
            "xx.en.marian.translate_to.ny": "opus_mt_en_ny",
            "xx.en.marian.translate_to.ty": "opus_mt_en_ty",
            "xx.cel.marian.translate_to.en": "opus_mt_cel_en",
            "xx.ccs.marian.translate_to.en": "opus_mt_ccs_en",
            "xx.hu.marian.translate_to.en": "opus_mt_hu_en",
            "xx.art.marian.translate_to.en": "opus_mt_art_en",
            "xx.en.marian.translate_to.ar": "opus_mt_en_ar",
            "xx.en.marian.translate_to.mfe": "opus_mt_en_mfe",
            "xx.yap.marian.translate_to.en": "opus_mt_yap_en",
            "xx.ha.marian.translate_to.en": "opus_mt_ha_en",
            "xx.cpf.marian.translate_to.en": "opus_mt_cpf_en",
            "xx.en.marian.translate_to.hy": "opus_mt_en_hy",
            "xx.en.marian.translate_to.roa": "opus_mt_en_roa",
            "xx.crs.marian.translate_to.en": "opus_mt_crs_en",
            "xx.en.marian.translate_to.lun": "opus_mt_en_lun",
            "xx.zls.marian.translate_to.en": "opus_mt_zls_en",
            "xx.en.marian.translate_to.mk": "opus_mt_en_mk",
            "xx.en.marian.translate_to.fiu": "opus_mt_en_fiu",
            "xx.en.marian.translate_to.sv": "opus_mt_en_sv",
            "xx.gmw.marian.translate_to.en": "opus_mt_gmw_en",
            "xx.en.marian.translate_to.st": "opus_mt_en_st",
            "xx.en.marian.translate_to.om": "opus_mt_en_om",
            "xx.en.marian.translate_to.pqw": "opus_mt_en_pqw",
            "xx.en.marian.translate_to.hil": "opus_mt_en_hil",
            "xx.sk.marian.translate_to.en": "opus_mt_sk_en",
            "xx.en.marian.translate_to.mr": "opus_mt_en_mr",
            "xx.tll.marian.translate_to.en": "opus_mt_tll_en",
            "xx.en.marian.translate_to.jap": "opus_mt_en_jap",
            "xx.en.marian.translate_to.chk": "opus_mt_en_chk",
            "xx.tum.marian.translate_to.en": "opus_mt_tum_en",
            "xx.dra.marian.translate_to.en": "opus_mt_dra_en",
            "xx.en.marian.translate_to.kqn": "opus_mt_en_kqn",
            "xx.en.marian.translate_to.tdt": "opus_mt_en_tdt",
            "xx.en.marian.translate_to.tvl": "opus_mt_en_tvl",
            "xx.en.marian.translate_to.lue": "opus_mt_en_lue",
            "xx.en.marian.translate_to.ilo": "opus_mt_en_ilo",
            "xx.en.marian.translate_to.poz": "opus_mt_en_poz",
            "xx.pap.marian.translate_to.en": "opus_mt_pap_en",
            "xx.af.marian.translate_to.en": "opus_mt_af_en",
            "xx.en.marian.translate_to.bzs": "opus_mt_en_bzs",
            "xx.toi.marian.translate_to.en": "opus_mt_toi_en",
            "xx.en.marian.translate_to.mg": "opus_mt_en_mg",
            "xx.ber.marian.translate_to.en": "opus_mt_ber_en",
            "xx.kj.marian.translate_to.en": "opus_mt_kj_en",
            "xx.ko.marian.translate_to.en": "opus_mt_ko_en",
            "xx.inc.marian.translate_to.en": "opus_mt_inc_en",
            "xx.en.marian.translate_to.is": "opus_mt_en_is",
            "xx.mr.marian.translate_to.en": "opus_mt_mr_en",
            "xx.ka.marian.translate_to.en": "opus_mt_ka_en",
            "xx.en.marian.translate_to.nic": "opus_mt_en_nic",
            "xx.en.marian.translate_to.eu": "opus_mt_en_eu",
            "xx.pl.marian.translate_to.en": "opus_mt_pl_en",
            "xx.hil.marian.translate_to.en": "opus_mt_hil_en",
            "xx.en.marian.translate_to.luo": "opus_mt_en_luo",
            "xx.en.marian.translate_to.zh": "opus_mt_en_zh",
            "xx.en.marian.translate_to.fi": "opus_mt_en_fi",
            "xx.en.marian.translate_to.kg": "opus_mt_en_kg",
            "xx.bi.marian.translate_to.en": "opus_mt_bi_en",
            "xx.sg.marian.translate_to.en": "opus_mt_sg_en",
            "xx.en.marian.translate_to.ng": "opus_mt_en_ng",
            "xx.en.marian.translate_to.inc": "opus_mt_en_inc",
            "xx.en.marian.translate_to.uk": "opus_mt_en_uk",
            "xx.en.marian.translate_to.es": "opus_mt_en_es",
            "xx.en.marian.translate_to.swc": "opus_mt_en_swc",
            "xx.sq.marian.translate_to.en": "opus_mt_sq_en",
            "xx.en.marian.translate_to.niu": "opus_mt_en_niu",
            "xx.trk.marian.translate_to.en": "opus_mt_trk_en",
            "xx.en.marian.translate_to.mh": "opus_mt_en_mh",
            "xx.luo.marian.translate_to.en": "opus_mt_luo_en",
            "xx.mt.marian.translate_to.en": "opus_mt_mt_en",
            "xx.to.marian.translate_to.en": "opus_mt_to_en",
            "xx.tiv.marian.translate_to.en": "opus_mt_tiv_en",
            "xx.en.marian.translate_to.ca": "opus_mt_en_ca",
            "xx.en.marian.translate_to.iso": "opus_mt_en_iso",
            "xx.gil.marian.translate_to.en": "opus_mt_gil_en",
            "xx.en.marian.translate_to.trk": "opus_mt_en_trk",
            "xx.ga.marian.translate_to.en": "opus_mt_ga_en",
            "xx.en.marian.translate_to.sem": "opus_mt_en_sem",
            "xx.da.marian.translate_to.en": "opus_mt_da_en",
            "xx.is.marian.translate_to.en": "opus_mt_is_en",
            "xx.en.marian.translate_to.mul": "opus_mt_en_mul",
            "xx.en.marian.translate_to.nyk": "opus_mt_en_nyk",
            "xx.de.marian.translate_to.en": "opus_mt_de_en",
            "xx.rn.marian.translate_to.en": "opus_mt_rn_en",
            "xx.yo.marian.translate_to.en": "opus_mt_yo_en",
            "xx.sn.marian.translate_to.en": "opus_mt_sn_en",
            "xx.lun.marian.translate_to.en": "opus_mt_lun_en",
            "xx.en.marian.translate_to.iir": "opus_mt_en_iir",
            "xx.en.marian.translate_to.toi": "opus_mt_en_toi",
            "xx.pag.marian.translate_to.en": "opus_mt_pag_en",
            "xx.en.marian.translate_to.ee": "opus_mt_en_ee",
            "xx.grk.marian.translate_to.en": "opus_mt_grk_en",
            "xx.zle.marian.translate_to.en": "opus_mt_zle_en",
            "xx.zh.marian.translate_to.en": "opus_mt_zh_en",
            "xx.en.marian.translate_to.tn": "opus_mt_en_tn",
            "xx.en.marian.translate_to.az": "opus_mt_en_az",
            "xx.en.marian.translate_to.bat": "opus_mt_en_bat",
            "xx.en.marian.translate_to.tut": "opus_mt_en_tut",
            "xx.eu.marian.translate_to.en": "opus_mt_eu_en",
            "xx.kab.marian.translate_to.en": "opus_mt_kab_en",
            "xx.en.marian.translate_to.fr": "opus_mt_en_fr",
            "xx.rnd.marian.translate_to.en": "opus_mt_rnd_en",
            "xx.ur.marian.translate_to.en": "opus_mt_ur_en",
            "xx.ss.marian.translate_to.en": "opus_mt_ss_en",
            "xx.cau.marian.translate_to.en": "opus_mt_cau_en",
            "xx.cs.marian.translate_to.en": "opus_mt_cs_en",
            "xx.en.marian.translate_to.de": "opus_mt_en_de",
            "xx.en.marian.translate_to.sq": "opus_mt_en_sq",
            "xx.roa.marian.translate_to.en": "opus_mt_roa_en",
            "xx.eo.marian.translate_to.en": "opus_mt_eo_en",
            "xx.wa.marian.translate_to.en": "opus_mt_wa_en",
            "xx.zlw.marian.translate_to.en": "opus_mt_zlw_en",
            "xx.lg.marian.translate_to.en": "opus_mt_lg_en",
            "xx.en.marian.translate_to.gmw": "opus_mt_en_gmw",
            "xx.fr.marian.translate_to.en": "opus_mt_fr_en",
            "xx.en.marian.translate_to.it": "opus_mt_en_it",
            "xx.tpi.marian.translate_to.en": "opus_mt_tpi_en",
            "xx.bcl.marian.translate_to.en": "opus_mt_bcl_en",
            "xx.id.marian.translate_to.en": "opus_mt_id_en",
            "xx.ht.marian.translate_to.en": "opus_mt_ht_en",
            "xx.en.marian.translate_to.run": "opus_mt_en_run",
            "xx.en.marian.translate_to.bg": "opus_mt_en_bg",
            "xx.mul.marian.translate_to.en": "opus_mt_mul_en",
            "xx.mk.marian.translate_to.en": "opus_mt_mk_en",
            "xx.en.marian.translate_to.gil": "opus_mt_en_gil",
            "xx.en.marian.translate_to.nso": "opus_mt_en_nso",
            "xx.gv.marian.translate_to.en": "opus_mt_gv_en",
            "xx.es.marian.translate_to.en": "opus_mt_es_en",
            "xx.ilo.marian.translate_to.en": "opus_mt_ilo_en",
            "xx.srn.marian.translate_to.en": "opus_mt_srn_en",
            "xx.guw.marian.translate_to.en": "opus_mt_guw_en",
            "xx.fiu.marian.translate_to.en": "opus_mt_fiu_en",
            "xx.wls.marian.translate_to.en": "opus_mt_wls_en",
            "xx.en.marian.translate_to.nl": "opus_mt_en_nl",
            "xx.rw.marian.translate_to.en": "opus_mt_rw_en",
            "xx.en.marian.translate_to.ceb": "opus_mt_en_ceb",
            "xx.run.marian.translate_to.en": "opus_mt_run_en",
            "xx.nyk.marian.translate_to.en": "opus_mt_nyk_en",
            "xx.ho.marian.translate_to.en": "opus_mt_ho_en",
            "xx.en.marian.translate_to.urj": "opus_mt_en_urj",
            "xx.en.marian.translate_to.pon": "opus_mt_en_pon",
            "xx.phi.marian.translate_to.en": "opus_mt_phi_en",
            "xx.kl.marian.translate_to.en": "opus_mt_kl_en",
            "xx.bn.marian.translate_to.en": "opus_mt_bn_en",
            "xx.en.marian.translate_to.efi": "opus_mt_en_efi",
            "xx.en.marian.translate_to.pqe": "opus_mt_en_pqe",
            "xx.en.marian.translate_to.rnd": "opus_mt_en_rnd",
            "xx.en.marian.translate_to.id": "opus_mt_en_id",
            "xx.nl.marian.translate_to.en": "opus_mt_nl_en",
            "xx.ru.marian.translate_to.en": "opus_mt_ru_en",
            "xx.en.marian.translate_to.sla": "opus_mt_en_sla",
            "xx.en.marian.translate_to.guw": "opus_mt_en_guw",
            "xx.euq.marian.translate_to.en": "opus_mt_euq_en",
            "xx.lu.marian.translate_to.en": "opus_mt_lu_en",
            "xx.en.marian.translate_to.fj": "opus_mt_en_fj",
            "xx.en.marian.translate_to.ru": "opus_mt_en_ru",
            "xx.en.marian.translate_to.gem": "opus_mt_en_gem",
            "xx.en.marian.translate_to.map": "opus_mt_en_map",
            "xx.en.marian.translate_to.euq": "opus_mt_en_euq",
            "xx.en.marian.translate_to.kwn": "opus_mt_en_kwn",
            "xx.en.marian.translate_to.gl": "opus_mt_en_gl",
            "xx.en.marian.translate_to.ha": "opus_mt_en_ha",
            "xx.cpp.marian.translate_to.en": "opus_mt_cpp_en",
            "xx.en.marian.translate_to.mkh": "opus_mt_en_mkh",
            "xx.en.marian.translate_to.kj": "opus_mt_en_kj",
            "xx.bat.marian.translate_to.en": "opus_mt_bat_en",
            "xx.en.marian.translate_to.sal": "opus_mt_en_sal",
            "xx.pa.marian.translate_to.en": "opus_mt_pa_en",
            "xx.jap.marian.translate_to.en": "opus_mt_jap_en",
            "xx.sla.marian.translate_to.en": "opus_mt_sla_en",
            "xx.ar.marian.translate_to.en": "opus_mt_ar_en",
            "xx.xh.marian.translate_to.en": "opus_mt_xh_en",
            "xx.mfe.marian.translate_to.en": "opus_mt_mfe_en",
            "xx.en.marian.translate_to.zlw": "opus_mt_en_zlw",
            "xx.en.marian.translate_to.lua": "opus_mt_en_lua",
            "xx.en.marian.translate_to.ine": "opus_mt_en_ine",
            "xx.en.marian.translate_to.loz": "opus_mt_en_loz",
            "xx.lus.marian.translate_to.en": "opus_mt_lus_en",
            "xx.lv.marian.translate_to.en": "opus_mt_lv_en",
            "xx.en.marian.translate_to.af": "opus_mt_en_af",
            "xx.sal.marian.translate_to.en": "opus_mt_sal_en",
            "xx.hi.marian.translate_to.en": "opus_mt_hi_en",
            "xx.gaa.marian.translate_to.en": "opus_mt_gaa_en",
            "xx.pon.marian.translate_to.en": "opus_mt_pon_en",
            "xx.ig.marian.translate_to.en": "opus_mt_ig_en",
            "xx.en.marian.translate_to.lus": "opus_mt_en_lus",
            "xx.th.marian.translate_to.en": "opus_mt_th_en",
            "xx.kg.marian.translate_to.en": "opus_mt_kg_en",
            "xx.cus.marian.translate_to.en": "opus_mt_cus_en",
            "xx.cy.marian.translate_to.en": "opus_mt_cy_en",
            "xx.en.marian.translate_to.alv": "opus_mt_en_alv",
            "xx.sem.marian.translate_to.en": "opus_mt_sem_en",
            "xx.en.marian.translate_to.tpi": "opus_mt_en_tpi",
            "xx.en.marian.translate_to.grk": "opus_mt_en_grk",
            "xx.gmq.marian.translate_to.en": "opus_mt_gmq_en",
            "xx.tn.marian.translate_to.en": "opus_mt_tn_en",
            "xx.en.marian.translate_to.sg": "opus_mt_en_sg",
            "xx.pis.marian.translate_to.en": "opus_mt_pis_en",
            "xx.en.marian.translate_to.sm": "opus_mt_en_sm",
            "xx.en.marian.translate_to.ht": "opus_mt_en_ht",
            "xx.mos.marian.translate_to.en": "opus_mt_mos_en",
            "xx.iir.marian.translate_to.en": "opus_mt_iir_en",
            "xx.en.marian.translate_to.mos": "opus_mt_en_mos",
            "xx.ts.marian.translate_to.en": "opus_mt_ts_en",
            "xx.en.marian.translate_to.he": "opus_mt_en_he",
            "xx.en.marian.translate_to.da": "opus_mt_en_da",
            "xx.it.marian.translate_to.en": "opus_mt_it_en",
            "xx.en.marian.translate_to.cel": "opus_mt_en_cel",
            "xx.en.marian.translate_to.el": "opus_mt_en_el",
            "xx.en.marian.translate_to.xh": "opus_mt_en_xh",
            "xx.en.marian.translate_to.eo": "opus_mt_en_eo",
            "xx.az.marian.translate_to.en": "opus_mt_az_en",
            "xx.tvl.marian.translate_to.en": "opus_mt_tvl_en",
            "xx.tl.marian.translate_to.en": "opus_mt_tl_en",
            "xx.bzs.marian.translate_to.en": "opus_mt_bzs_en",
            "xx.en.marian.translate_to.et": "opus_mt_en_et",
            "xx.en.marian.translate_to.sk": "opus_mt_en_sk",
            "xx.en.marian.translate_to.to": "opus_mt_en_to",
            "xx.en.marian.translate_to.ur": "opus_mt_en_ur",
            "xx.lue.marian.translate_to.en": "opus_mt_lue_en",
            "xx.niu.marian.translate_to.en": "opus_mt_niu_en",
            "xx.ti.marian.translate_to.en": "opus_mt_ti_en",
            "xx.en.marian.translate_to.lu": "opus_mt_en_lu",

            # Marian 3.1 Models



            "xx.fr.marian.translate_to.bcl":"opus_mt_bcl_fr",
            "xx.tr.marian.translate_to.ar":"opus_mt_ar_tr",
            "xx.sv.marian.translate_to.af":"opus_mt_af_sv",
            "xx.de.marian.translate_to.ar":"opus_mt_ar_de",
            "xx.fr.marian.translate_to.bi":"opus_mt_bi_fr",
            "xx.es.marian.translate_to.bi":"opus_mt_bi_es",
            "xx.fi.marian.translate_to.af":"opus_mt_af_fi",
            "xx.fi.marian.translate_to.crs":"opus_mt_crs_fi",
            "xx.fi.marian.translate_to.bem":"opus_mt_bem_fi",
            "xx.sv.marian.translate_to.bem":"opus_mt_bem_sv",
            "xx.it.marian.translate_to.ca":"opus_mt_ca_it",
            "xx.fr.marian.translate_to.ca":"opus_mt_ca_fr",
            "xx.es.marian.translate_to.bcl":"opus_mt_bcl_es",
            "xx.uk.marian.translate_to.ca":"opus_mt_ca_uk",
            "xx.fr.marian.translate_to.bem":"opus_mt_bem_fr",
            "xx.de.marian.translate_to.af":"opus_mt_af_de",
            "xx.nl.marian.translate_to.af":"opus_mt_af_nl",
            "xx.fr.marian.translate_to.ase":"opus_mt_ase_fr",
            "xx.es.marian.translate_to.az":"opus_mt_az_es",
            "xx.es.marian.translate_to.chk":"opus_mt_chk_es",
            "xx.sv.marian.translate_to.ceb":"opus_mt_ceb_sv",
            "xx.es.marian.translate_to.ceb":"opus_mt_ceb_es",
            "xx.es.marian.translate_to.aed":"opus_mt_aed_es",
            "xx.pl.marian.translate_to.ar":"opus_mt_ar_pl",
            "xx.es.marian.translate_to.bem":"opus_mt_bem_es",
            "xx.eo.marian.translate_to.af":"opus_mt_af_eo",
            "xx.fr.marian.translate_to.cs":"opus_mt_cs_fr",
            "xx.fi.marian.translate_to.bcl":"opus_mt_bcl_fi",
            "xx.es.marian.translate_to.crs":"opus_mt_crs_es",
            "xx.sv.marian.translate_to.bi":"opus_mt_bi_sv",
            "xx.de.marian.translate_to.bg":"opus_mt_bg_de",
            "xx.ru.marian.translate_to.ar":"opus_mt_ar_ru",
            "xx.es.marian.translate_to.bg":"opus_mt_bg_es",
            "xx.uk.marian.translate_to.cs":"opus_mt_cs_uk",
            "xx.sv.marian.translate_to.bzs":"opus_mt_bzs_sv",
            "xx.es.marian.translate_to.be":"opus_mt_be_es",
            "xx.es.marian.translate_to.bzs":"opus_mt_bzs_es",
            "xx.fr.marian.translate_to.af":"opus_mt_af_fr",
            "xx.pt.marian.translate_to.ca":"opus_mt_ca_pt",
            "xx.fr.marian.translate_to.chk":"opus_mt_chk_fr",
            "xx.de.marian.translate_to.ase":"opus_mt_ase_de",
            "xx.it.marian.translate_to.ar":"opus_mt_ar_it",
            "xx.fi.marian.translate_to.ceb":"opus_mt_ceb_fi",
            "xx.cpp.marian.translate_to.cpp":"opus_mt_cpp_cpp",
            "xx.fr.marian.translate_to.ber":"opus_mt_ber_fr",
            "xx.ru.marian.translate_to.bg":"opus_mt_bg_ru",
            "xx.es.marian.translate_to.ase":"opus_mt_ase_es",
            "xx.es.marian.translate_to.af":"opus_mt_af_es",
            "xx.it.marian.translate_to.bg":"opus_mt_bg_it",
            "xx.sv.marian.translate_to.am":"opus_mt_am_sv",
            "xx.eo.marian.translate_to.ar":"opus_mt_ar_eo",
            "xx.fr.marian.translate_to.ceb":"opus_mt_ceb_fr",
            "xx.es.marian.translate_to.ca":"opus_mt_ca_es",
            "xx.fi.marian.translate_to.bzs":"opus_mt_bzs_fi",
            "xx.de.marian.translate_to.crs":"opus_mt_crs_de",
            "xx.fi.marian.translate_to.cs":"opus_mt_cs_fi",
            "xx.afa.marian.translate_to.afa":"opus_mt_afa_afa",
            "xx.sv.marian.translate_to.bg":"opus_mt_bg_sv",
            "xx.tr.marian.translate_to.bg":"opus_mt_bg_tr",
            "xx.fr.marian.translate_to.crs":"opus_mt_crs_fr",
            "xx.sv.marian.translate_to.ase":"opus_mt_ase_sv",
            "xx.de.marian.translate_to.cs":"opus_mt_cs_de",
            "xx.eo.marian.translate_to.cs":"opus_mt_cs_eo",
            "xx.sv.marian.translate_to.chk":"opus_mt_chk_sv",
            "xx.sv.marian.translate_to.bcl":"opus_mt_bcl_sv",
            "xx.fr.marian.translate_to.ar":"opus_mt_ar_fr",
            "xx.ru.marian.translate_to.af":"opus_mt_af_ru",
            "xx.he.marian.translate_to.ar":"opus_mt_ar_he",
            "xx.fi.marian.translate_to.bg":"opus_mt_bg_fi",
            "xx.es.marian.translate_to.ber":"opus_mt_ber_es",
            "xx.es.marian.translate_to.ar":"opus_mt_ar_es",
            "xx.uk.marian.translate_to.bg":"opus_mt_bg_uk",
            "xx.fr.marian.translate_to.bzs":"opus_mt_bzs_fr",
            "xx.el.marian.translate_to.ar":"opus_mt_ar_el",
            "xx.nl.marian.translate_to.ca":"opus_mt_ca_nl",
            "xx.de.marian.translate_to.bcl":"opus_mt_bcl_de",
            "xx.eo.marian.translate_to.bg":"opus_mt_bg_eo",
            "xx.de.marian.translate_to.efi":"opus_mt_efi_de",
            "xx.bzs.marian.translate_to.de":"opus_mt_de_bzs",
            "xx.fj.marian.translate_to.de":"opus_mt_de_fj",
            "xx.fi.marian.translate_to.da":"opus_mt_da_fi",
            "xx.no.marian.translate_to.da":"opus_mt_da_no",
            "xx.cs.marian.translate_to.de":"opus_mt_de_cs",
            "xx.efi.marian.translate_to.de":"opus_mt_de_efi",
            "xx.gil.marian.translate_to.de":"opus_mt_de_gil",
            "xx.bcl.marian.translate_to.de":"opus_mt_de_bcl",
            "xx.pag.marian.translate_to.de":"opus_mt_de_pag",
            "xx.kg.marian.translate_to.de":"opus_mt_de_kg",
            "xx.fi.marian.translate_to.efi":"opus_mt_efi_fi",
            "xx.is.marian.translate_to.de":"opus_mt_de_is",
            "xx.fr.marian.translate_to.da":"opus_mt_da_fr",
            "xx.pl.marian.translate_to.de":"opus_mt_de_pl",
            "xx.ln.marian.translate_to.de":"opus_mt_de_ln",
            "xx.pap.marian.translate_to.de":"opus_mt_de_pap",
            "xx.vi.marian.translate_to.de":"opus_mt_de_vi",
            "xx.no.marian.translate_to.de":"opus_mt_de_no",
            "xx.eo.marian.translate_to.el":"opus_mt_el_eo",
            "xx.af.marian.translate_to.de":"opus_mt_de_af",
            "xx.es.marian.translate_to.ee":"opus_mt_ee_es",
            "xx.eo.marian.translate_to.de":"opus_mt_de_eo",
            "xx.bi.marian.translate_to.de":"opus_mt_de_bi",
            "xx.mt.marian.translate_to.de":"opus_mt_de_mt",
            "xx.lt.marian.translate_to.de":"opus_mt_de_lt",
            "xx.bg.marian.translate_to.de":"opus_mt_de_bg",
            "xx.hil.marian.translate_to.de":"opus_mt_de_hil",
            "xx.eu.marian.translate_to.de":"opus_mt_de_eu",
            "xx.da.marian.translate_to.de":"opus_mt_de_da",
            "xx.ms.marian.translate_to.de":"opus_mt_de_ms",
            "xx.he.marian.translate_to.de":"opus_mt_de_he",
            "xx.et.marian.translate_to.de":"opus_mt_de_et",
            "xx.es.marian.translate_to.de":"opus_mt_de_es",
            "xx.fr.marian.translate_to.el":"opus_mt_el_fr",
            "xx.fr.marian.translate_to.ee":"opus_mt_ee_fr",
            "xx.el.marian.translate_to.de":"opus_mt_de_el",
            "xx.sv.marian.translate_to.el":"opus_mt_el_sv",
            "xx.es.marian.translate_to.csn":"opus_mt_csn_es",
            "xx.tl.marian.translate_to.de":"opus_mt_de_tl",
            "xx.pon.marian.translate_to.de":"opus_mt_de_pon",
            "xx.fr.marian.translate_to.efi":"opus_mt_efi_fr",
            "xx.uk.marian.translate_to.de":"opus_mt_de_uk",
            "xx.ar.marian.translate_to.el":"opus_mt_el_ar",
            "xx.fi.marian.translate_to.el":"opus_mt_el_fi",
            "xx.ig.marian.translate_to.de":"opus_mt_de_ig",
            "xx.guw.marian.translate_to.de":"opus_mt_de_guw",
            "xx.iso.marian.translate_to.de":"opus_mt_de_iso",
            "xx.sv.marian.translate_to.efi":"opus_mt_efi_sv",
            "xx.ha.marian.translate_to.de":"opus_mt_de_ha",
            "xx.fr.marian.translate_to.de":"opus_mt_de_fr",
            "xx.gaa.marian.translate_to.de":"opus_mt_de_gaa",
            "xx.nso.marian.translate_to.de":"opus_mt_de_nso",
            "xx.ht.marian.translate_to.de":"opus_mt_de_ht",
            "xx.nl.marian.translate_to.de":"opus_mt_de_nl",
            "xx.sv.marian.translate_to.ee":"opus_mt_ee_sv",
            "xx.fi.marian.translate_to.ee":"opus_mt_ee_fi",
            "xx.de.marian.translate_to.ee":"opus_mt_ee_de",
            "xx.eo.marian.translate_to.da":"opus_mt_da_eo",
            "xx.es.marian.translate_to.csg":"opus_mt_csg_es",
            "xx.de.marian.translate_to.da":"opus_mt_da_de",
            "xx.ar.marian.translate_to.de":"opus_mt_de_ar",
            "xx.hu.marian.translate_to.de":"opus_mt_de_hu",
            "xx.ca.marian.translate_to.de":"opus_mt_de_ca",
            "xx.pis.marian.translate_to.de":"opus_mt_de_pis",
            "xx.ho.marian.translate_to.de":"opus_mt_de_ho",
            "xx.de.marian.translate_to.de":"opus_mt_de_de",
            "xx.lua.marian.translate_to.de":"opus_mt_de_lua",
            "xx.loz.marian.translate_to.de":"opus_mt_de_loz",
            "xx.crs.marian.translate_to.de":"opus_mt_de_crs",
            "xx.es.marian.translate_to.da":"opus_mt_da_es",
            "xx.ee.marian.translate_to.de":"opus_mt_de_ee",
            "xx.it.marian.translate_to.de":"opus_mt_de_it",
            "xx.ilo.marian.translate_to.de":"opus_mt_de_ilo",
            "xx.ny.marian.translate_to.de":"opus_mt_de_ny",
            "xx.fi.marian.translate_to.de":"opus_mt_de_fi",
            "xx.ase.marian.translate_to.de":"opus_mt_de_ase",
            "xx.hr.marian.translate_to.de":"opus_mt_de_hr",
            "xx.sl.marian.translate_to.fi":"opus_mt_fi_sl",
            "xx.sk.marian.translate_to.fi":"opus_mt_fi_sk",
            "xx.ru.marian.translate_to.es":"opus_mt_es_ru",
            "xx.sn.marian.translate_to.fi":"opus_mt_fi_sn",
            "xx.pl.marian.translate_to.eo":"opus_mt_eo_pl",
            "xx.cs.marian.translate_to.es":"opus_mt_es_cs",
            "xx.wls.marian.translate_to.fi":"opus_mt_fi_wls",
            "xx.gaa.marian.translate_to.fi":"opus_mt_fi_gaa",
            "xx.is.marian.translate_to.fi":"opus_mt_fi_is",
            "xx.ha.marian.translate_to.es":"opus_mt_es_ha",
            "xx.nl.marian.translate_to.es":"opus_mt_es_nl",
            "xx.ha.marian.translate_to.fi":"opus_mt_fi_ha",
            "xx.fj.marian.translate_to.fi":"opus_mt_fi_fj",
            "xx.ber.marian.translate_to.es":"opus_mt_es_ber",
            "xx.ho.marian.translate_to.fi":"opus_mt_fi_ho",
            "xx.ny.marian.translate_to.fi":"opus_mt_fi_ny",
            "xx.sl.marian.translate_to.es":"opus_mt_es_sl",
            "xx.ts.marian.translate_to.fi":"opus_mt_fi_ts",
            "xx.el.marian.translate_to.eo":"opus_mt_eo_el",
            "xx.war.marian.translate_to.fi":"opus_mt_fi_war",
            "xx.cs.marian.translate_to.fi":"opus_mt_fi_cs",
            "xx.loz.marian.translate_to.es":"opus_mt_es_loz",
            "xx.mk.marian.translate_to.fi":"opus_mt_fi_mk",
            "xx.bg.marian.translate_to.es":"opus_mt_es_bg",
            "xx.srn.marian.translate_to.fi":"opus_mt_fi_srn",
            "xx.is.marian.translate_to.es":"opus_mt_es_is",
            "xx.hu.marian.translate_to.eo":"opus_mt_eo_hu",
            "xx.tw.marian.translate_to.fi":"opus_mt_fi_tw",
            "xx.mt.marian.translate_to.fi":"opus_mt_fi_mt",
            "xx.fr.marian.translate_to.es":"opus_mt_es_fr",
            "xx.yo.marian.translate_to.es":"opus_mt_es_yo",
            "xx.xh.marian.translate_to.fi":"opus_mt_fi_xh",
            "xx.lv.marian.translate_to.fi":"opus_mt_fi_lv",
            "xx.de.marian.translate_to.fi":"opus_mt_fi_de",
            "xx.ve.marian.translate_to.es":"opus_mt_es_ve",
            "xx.es.marian.translate_to.fi":"opus_mt_fi_es",
            "xx.eo.marian.translate_to.es":"opus_mt_es_eo",
            "xx.cs.marian.translate_to.eo":"opus_mt_eo_cs",
            "xx.mt.marian.translate_to.es":"opus_mt_es_mt",
            "xx.el.marian.translate_to.es":"opus_mt_es_el",
            "xx.ee.marian.translate_to.es":"opus_mt_es_ee",
            "xx.de.marian.translate_to.eu":"opus_mt_eu_de",
            "xx.et.marian.translate_to.es":"opus_mt_es_et",
            "xx.fi.marian.translate_to.et":"opus_mt_et_fi",
            "xx.wls.marian.translate_to.es":"opus_mt_es_wls",
            "xx.mg.marian.translate_to.fi":"opus_mt_fi_mg",
            "xx.eu.marian.translate_to.es":"opus_mt_es_eu",
            "xx.lua.marian.translate_to.es":"opus_mt_es_lua",
            "xx.pon.marian.translate_to.es":"opus_mt_es_pon",
            "xx.mfe.marian.translate_to.fi":"opus_mt_fi_mfe",
            "xx.he.marian.translate_to.eo":"opus_mt_eo_he",
            "xx.id.marian.translate_to.es":"opus_mt_es_id",
            "xx.xh.marian.translate_to.es":"opus_mt_es_xh",
            "xx.ar.marian.translate_to.es":"opus_mt_es_ar",
            "xx.crs.marian.translate_to.es":"opus_mt_es_crs",
            "xx.es.marian.translate_to.eu":"opus_mt_eu_es",
            "xx.tpi.marian.translate_to.fi":"opus_mt_fi_tpi",
            "xx.pis.marian.translate_to.fi":"opus_mt_fi_pis",
            "xx.vi.marian.translate_to.es":"opus_mt_es_vi",
            "xx.es.marian.translate_to.et":"opus_mt_et_es",
            "xx.rw.marian.translate_to.fi":"opus_mt_fi_rw",
            "xx.gl.marian.translate_to.es":"opus_mt_es_gl",
            "xx.pt.marian.translate_to.eo":"opus_mt_eo_pt",
            "xx.he.marian.translate_to.fi":"opus_mt_fi_he",
            "xx.af.marian.translate_to.fi":"opus_mt_fi_af",
            "xx.ru.marian.translate_to.fi":"opus_mt_fi_ru",
            "xx.ve.marian.translate_to.fi":"opus_mt_fi_ve",
            "xx.ca.marian.translate_to.es":"opus_mt_es_ca",
            "xx.tr.marian.translate_to.fi":"opus_mt_fi_tr",
            "xx.ht.marian.translate_to.fi":"opus_mt_fi_ht",
            "xx.nl.marian.translate_to.fi":"opus_mt_fi_nl",
            "xx.iso.marian.translate_to.fi":"opus_mt_fi_iso",
            "xx.fi.marian.translate_to.es":"opus_mt_es_fi",
            "xx.da.marian.translate_to.eo":"opus_mt_eo_da",
            "xx.ln.marian.translate_to.es":"opus_mt_es_ln",
            "xx.csn.marian.translate_to.es":"opus_mt_es_csn",
            "xx.pon.marian.translate_to.fi":"opus_mt_fi_pon",
            "xx.af.marian.translate_to.eo":"opus_mt_eo_af",
            "xx.bzs.marian.translate_to.fi":"opus_mt_fi_bzs",
            "xx.no.marian.translate_to.es":"opus_mt_es_no",
            "xx.es.marian.translate_to.es":"opus_mt_es_es",
            "xx.lua.marian.translate_to.fi":"opus_mt_fi_lua",
            "xx.yua.marian.translate_to.es":"opus_mt_es_yua",
            "xx.ru.marian.translate_to.eu":"opus_mt_eu_ru",
            "xx.tpi.marian.translate_to.es":"opus_mt_es_tpi",
            "xx.lue.marian.translate_to.fi":"opus_mt_fi_lue",
            "xx.sv.marian.translate_to.eo":"opus_mt_eo_sv",
            "xx.niu.marian.translate_to.es":"opus_mt_es_niu",
            "xx.tiv.marian.translate_to.fi":"opus_mt_fi_tiv",
            "xx.pag.marian.translate_to.es":"opus_mt_es_pag",
            "xx.run.marian.translate_to.fi":"opus_mt_fi_run",
            "xx.ty.marian.translate_to.es":"opus_mt_es_ty",
            "xx.gil.marian.translate_to.es":"opus_mt_es_gil",
            "xx.ln.marian.translate_to.fi":"opus_mt_fi_ln",
            "xx.ty.marian.translate_to.fi":"opus_mt_fi_ty",
            "xx.prl.marian.translate_to.es":"opus_mt_es_prl",
            "xx.kg.marian.translate_to.es":"opus_mt_es_kg",
            "xx.rw.marian.translate_to.es":"opus_mt_es_rw",
            "xx.kqn.marian.translate_to.fi":"opus_mt_fi_kqn",
            "xx.sq.marian.translate_to.fi":"opus_mt_fi_sq",
            "xx.sw.marian.translate_to.fi":"opus_mt_fi_sw",
            "xx.csg.marian.translate_to.es":"opus_mt_es_csg",
            "xx.ro.marian.translate_to.es":"opus_mt_es_ro",
            "xx.ee.marian.translate_to.fi":"opus_mt_fi_ee",
            "xx.ilo.marian.translate_to.fi":"opus_mt_fi_ilo",
            "xx.eo.marian.translate_to.fi":"opus_mt_fi_eo",
            "xx.iso.marian.translate_to.es":"opus_mt_es_iso",
            "xx.bem.marian.translate_to.fi":"opus_mt_fi_bem",
            "xx.tn.marian.translate_to.fi":"opus_mt_fi_tn",
            "xx.da.marian.translate_to.es":"opus_mt_es_da",
            "xx.es.marian.translate_to.eo":"opus_mt_eo_es",
            "xx.ru.marian.translate_to.eo":"opus_mt_eo_ru",
            "xx.rn.marian.translate_to.es":"opus_mt_es_rn",
            "xx.lt.marian.translate_to.es":"opus_mt_es_lt",
            "xx.guw.marian.translate_to.es":"opus_mt_es_guw",
            "xx.tvl.marian.translate_to.es":"opus_mt_es_tvl",
            "xx.fr.marian.translate_to.et":"opus_mt_et_fr",
            "xx.ht.marian.translate_to.es":"opus_mt_es_ht",
            "xx.mos.marian.translate_to.fi":"opus_mt_fi_mos",
            "xx.ase.marian.translate_to.es":"opus_mt_es_ase",
            "xx.crs.marian.translate_to.fi":"opus_mt_fi_crs",
            "xx.bcl.marian.translate_to.fi":"opus_mt_fi_bcl",
            "xx.tvl.marian.translate_to.fi":"opus_mt_fi_tvl",
            "xx.lus.marian.translate_to.fi":"opus_mt_fi_lus",
            "xx.he.marian.translate_to.es":"opus_mt_es_he",
            "xx.pis.marian.translate_to.es":"opus_mt_es_pis",
            "xx.it.marian.translate_to.es":"opus_mt_es_it",
            "xx.fi.marian.translate_to.eo":"opus_mt_eo_fi",
            "xx.tw.marian.translate_to.es":"opus_mt_es_tw",
            "xx.aed.marian.translate_to.es":"opus_mt_es_aed",
            "xx.bzs.marian.translate_to.es":"opus_mt_es_bzs",
            "xx.nso.marian.translate_to.fi":"opus_mt_fi_nso",
            "xx.gaa.marian.translate_to.es":"opus_mt_es_gaa",
            "xx.zai.marian.translate_to.es":"opus_mt_es_zai",
            "xx.no.marian.translate_to.fi":"opus_mt_fi_no",
            "xx.uk.marian.translate_to.fi":"opus_mt_fi_uk",
            "xx.sg.marian.translate_to.es":"opus_mt_es_sg",
            "xx.ilo.marian.translate_to.es":"opus_mt_es_ilo",
            "xx.bg.marian.translate_to.eo":"opus_mt_eo_bg",
            "xx.pap.marian.translate_to.fi":"opus_mt_fi_pap",
            "xx.ho.marian.translate_to.es":"opus_mt_es_ho",
            "xx.toi.marian.translate_to.fi":"opus_mt_fi_toi",
            "xx.st.marian.translate_to.es":"opus_mt_es_st",
            "xx.to.marian.translate_to.fi":"opus_mt_fi_to",
            "xx.kg.marian.translate_to.fi":"opus_mt_fi_kg",
            "xx.sv.marian.translate_to.fi":"opus_mt_fi_sv",
            "xx.tll.marian.translate_to.fi":"opus_mt_fi_tll",
            "xx.ceb.marian.translate_to.es":"opus_mt_es_ceb",
            "xx.ig.marian.translate_to.es":"opus_mt_es_ig",
            "xx.sv.marian.translate_to.et":"opus_mt_et_sv",
            "xx.af.marian.translate_to.es":"opus_mt_es_af",
            "xx.pl.marian.translate_to.es":"opus_mt_es_pl",
            "xx.ro.marian.translate_to.eo":"opus_mt_eo_ro",
            "xx.tn.marian.translate_to.es":"opus_mt_es_tn",
            "xx.sm.marian.translate_to.fi":"opus_mt_fi_sm",
            "xx.mk.marian.translate_to.es":"opus_mt_es_mk",
            "xx.id.marian.translate_to.fi":"opus_mt_fi_id",
            "xx.hr.marian.translate_to.fi":"opus_mt_fi_hr",
            "xx.sg.marian.translate_to.fi":"opus_mt_fi_sg",
            "xx.hil.marian.translate_to.fi":"opus_mt_fi_hil",
            "xx.nl.marian.translate_to.eo":"opus_mt_eo_nl",
            "xx.pap.marian.translate_to.es":"opus_mt_es_pap",
            "xx.fr.marian.translate_to.fi":"opus_mt_fi_fr",
            "xx.bi.marian.translate_to.es":"opus_mt_es_bi",
            "xx.fi.marian.translate_to.fi":"opus_mt_fi_fi",
            "xx.nso.marian.translate_to.es":"opus_mt_es_nso",
            "xx.et.marian.translate_to.fi":"opus_mt_fi_et",
            "xx.uk.marian.translate_to.es":"opus_mt_es_uk",
            "xx.sh.marian.translate_to.eo":"opus_mt_eo_sh",
            "xx.lu.marian.translate_to.fi":"opus_mt_fi_lu",
            "xx.gil.marian.translate_to.fi":"opus_mt_fi_gil",
            "xx.ro.marian.translate_to.fi":"opus_mt_fi_ro",
            "xx.it.marian.translate_to.eo":"opus_mt_eo_it",
            "xx.hu.marian.translate_to.fi":"opus_mt_fi_hu",
            "xx.bcl.marian.translate_to.es":"opus_mt_es_bcl",
            "xx.fse.marian.translate_to.fi":"opus_mt_fi_fse",
            "xx.hil.marian.translate_to.es":"opus_mt_es_hil",
            "xx.ig.marian.translate_to.fi":"opus_mt_fi_ig",
            "xx.tl.marian.translate_to.es":"opus_mt_es_tl",
            "xx.pag.marian.translate_to.fi":"opus_mt_fi_pag",
            "xx.guw.marian.translate_to.fi":"opus_mt_fi_guw",
            "xx.swc.marian.translate_to.es":"opus_mt_es_swc",
            "xx.swc.marian.translate_to.fi":"opus_mt_fi_swc",
            "xx.lg.marian.translate_to.fi":"opus_mt_fi_lg",
            "xx.srn.marian.translate_to.es":"opus_mt_es_srn",
            "xx.hr.marian.translate_to.es":"opus_mt_es_hr",
            "xx.sm.marian.translate_to.es":"opus_mt_es_sm",
            "xx.de.marian.translate_to.es":"opus_mt_es_de",
            "xx.st.marian.translate_to.fi":"opus_mt_fi_st",
            "xx.fr.marian.translate_to.eo":"opus_mt_eo_fr",
            "xx.de.marian.translate_to.et":"opus_mt_et_de",
            "xx.niu.marian.translate_to.fi":"opus_mt_fi_niu",
            "xx.el.marian.translate_to.fi":"opus_mt_fi_el",
            "xx.efi.marian.translate_to.fi":"opus_mt_fi_efi",
            "xx.war.marian.translate_to.es":"opus_mt_es_war",
            "xx.mfs.marian.translate_to.es":"opus_mt_es_mfs",
            "xx.bg.marian.translate_to.fi":"opus_mt_fi_bg",
            "xx.lus.marian.translate_to.es":"opus_mt_es_lus",
            "xx.de.marian.translate_to.eo":"opus_mt_eo_de",
            "xx.it.marian.translate_to.fi":"opus_mt_fi_it",
            "xx.efi.marian.translate_to.es":"opus_mt_es_efi",
            "xx.ny.marian.translate_to.es":"opus_mt_es_ny",
            "xx.fj.marian.translate_to.es":"opus_mt_es_fj",
            "xx.ru.marian.translate_to.et":"opus_mt_et_ru",
            "xx.mh.marian.translate_to.fi":"opus_mt_fi_mh",
            "xx.es.marian.translate_to.ig":"opus_mt_ig_es",
            "xx.sv.marian.translate_to.hu":"opus_mt_hu_sv",
            "xx.lue.marian.translate_to.fr":"opus_mt_fr_lue",
            "xx.fi.marian.translate_to.ha":"opus_mt_ha_fi",
            "xx.ca.marian.translate_to.it":"opus_mt_it_ca",
            "xx.de.marian.translate_to.ilo":"opus_mt_ilo_de",
            "xx.it.marian.translate_to.he":"opus_mt_he_it",
            "xx.loz.marian.translate_to.fr":"opus_mt_fr_loz",
            "xx.ms.marian.translate_to.fr":"opus_mt_fr_ms",
            "xx.uk.marian.translate_to.it":"opus_mt_it_uk",
            "xx.gaa.marian.translate_to.fr":"opus_mt_fr_gaa",
            "xx.pap.marian.translate_to.fr":"opus_mt_fr_pap",
            "xx.fi.marian.translate_to.ilo":"opus_mt_ilo_fi",
            "xx.lg.marian.translate_to.fr":"opus_mt_fr_lg",
            "xx.it.marian.translate_to.is":"opus_mt_is_it",
            "xx.ms.marian.translate_to.it":"opus_mt_it_ms",
            "xx.es.marian.translate_to.fr":"opus_mt_fr_es",
            "xx.ar.marian.translate_to.he":"opus_mt_he_ar",
            "xx.ro.marian.translate_to.fr":"opus_mt_fr_ro",
            "xx.ru.marian.translate_to.fr":"opus_mt_fr_ru",
            "xx.fi.marian.translate_to.ht":"opus_mt_ht_fi",
            "xx.bg.marian.translate_to.it":"opus_mt_it_bg",
            "xx.mh.marian.translate_to.fr":"opus_mt_fr_mh",
            "xx.to.marian.translate_to.fr":"opus_mt_fr_to",
            "xx.sl.marian.translate_to.fr":"opus_mt_fr_sl",
            "xx.fr.marian.translate_to.gil":"opus_mt_gil_fr",
            "xx.es.marian.translate_to.hr":"opus_mt_hr_es",
            "xx.ilo.marian.translate_to.fr":"opus_mt_fr_ilo",
            "xx.ee.marian.translate_to.fr":"opus_mt_fr_ee",
            "xx.sv.marian.translate_to.he":"opus_mt_he_sv",
            "xx.fr.marian.translate_to.ha":"opus_mt_ha_fr",
            "xx.gil.marian.translate_to.fr":"opus_mt_fr_gil",
            "xx.fi.marian.translate_to.id":"opus_mt_id_fi",
            "xx.iir.marian.translate_to.iir":"opus_mt_iir_iir",
            "xx.pl.marian.translate_to.fr":"opus_mt_fr_pl",
            "xx.tw.marian.translate_to.fr":"opus_mt_fr_tw",
            "xx.sv.marian.translate_to.gaa":"opus_mt_gaa_sv",
            "xx.ar.marian.translate_to.it":"opus_mt_it_ar",
            "xx.es.marian.translate_to.gil":"opus_mt_gil_es",
            "xx.ase.marian.translate_to.fr":"opus_mt_fr_ase",
            "xx.fr.marian.translate_to.gaa":"opus_mt_gaa_fr",
            "xx.lus.marian.translate_to.fr":"opus_mt_fr_lus",
            "xx.fr.marian.translate_to.iso":"opus_mt_iso_fr",
            "xx.sm.marian.translate_to.fr":"opus_mt_fr_sm",
            "xx.mfe.marian.translate_to.fr":"opus_mt_fr_mfe",
            "xx.af.marian.translate_to.fr":"opus_mt_fr_af",
            "xx.de.marian.translate_to.ig":"opus_mt_ig_de",
            "xx.es.marian.translate_to.id":"opus_mt_id_es",
            "xx.kqn.marian.translate_to.fr":"opus_mt_fr_kqn",
            "xx.zne.marian.translate_to.fi":"opus_mt_fi_zne",
            "xx.rw.marian.translate_to.fr":"opus_mt_fr_rw",
            "xx.ny.marian.translate_to.fr":"opus_mt_fr_ny",
            "xx.ig.marian.translate_to.fr":"opus_mt_fr_ig",
            "xx.ur.marian.translate_to.hi":"opus_mt_hi_ur",
            "xx.lt.marian.translate_to.it":"opus_mt_it_lt",
            "xx.srn.marian.translate_to.fr":"opus_mt_fr_srn",
            "xx.tiv.marian.translate_to.fr":"opus_mt_fr_tiv",
            "xx.war.marian.translate_to.fr":"opus_mt_fr_war",
            "xx.fr.marian.translate_to.is":"opus_mt_is_fr",
            "xx.de.marian.translate_to.gaa":"opus_mt_gaa_de",
            "xx.kwy.marian.translate_to.fr":"opus_mt_fr_kwy",
            "xx.sv.marian.translate_to.gil":"opus_mt_gil_sv",
            "xx.hr.marian.translate_to.fr":"opus_mt_fr_hr",
            "xx.fr.marian.translate_to.ig":"opus_mt_ig_fr",
            "xx.sv.marian.translate_to.ht":"opus_mt_ht_sv",
            "xx.de.marian.translate_to.fr":"opus_mt_fr_de",
            "xx.fiu.marian.translate_to.fiu":"opus_mt_fiu_fiu",
            "xx.wls.marian.translate_to.fr":"opus_mt_fr_wls",
            "xx.eo.marian.translate_to.hu":"opus_mt_hu_eo",
            "xx.guw.marian.translate_to.fr":"opus_mt_fr_guw",
            "xx.de.marian.translate_to.is":"opus_mt_is_de",
            "xx.tvl.marian.translate_to.fr":"opus_mt_fr_tvl",
            "xx.zne.marian.translate_to.fr":"opus_mt_fr_zne",
            "xx.ha.marian.translate_to.fr":"opus_mt_fr_ha",
            "xx.fi.marian.translate_to.guw":"opus_mt_guw_fi",
            "xx.es.marian.translate_to.is":"opus_mt_is_es",
            "xx.sv.marian.translate_to.it":"opus_mt_it_sv",
            "xx.uk.marian.translate_to.fr":"opus_mt_fr_uk",
            "xx.uk.marian.translate_to.hu":"opus_mt_hu_uk",
            "xx.mt.marian.translate_to.fr":"opus_mt_fr_mt",
            "xx.gem.marian.translate_to.gem":"opus_mt_gem_gem",
            "xx.fr.marian.translate_to.fj":"opus_mt_fj_fr",
            "xx.fi.marian.translate_to.gil":"opus_mt_gil_fi",
            "xx.fr.marian.translate_to.hu":"opus_mt_hu_fr",
            "xx.bcl.marian.translate_to.fr":"opus_mt_fr_bcl",
            "xx.gmq.marian.translate_to.gmq":"opus_mt_gmq_gmq",
            "xx.kg.marian.translate_to.fr":"opus_mt_fr_kg",
            "xx.sn.marian.translate_to.fr":"opus_mt_fr_sn",
            "xx.bg.marian.translate_to.fr":"opus_mt_fr_bg",
            "xx.fr.marian.translate_to.guw":"opus_mt_guw_fr",
            "xx.ts.marian.translate_to.fr":"opus_mt_fr_ts",
            "xx.pis.marian.translate_to.fr":"opus_mt_fr_pis",
            "xx.bi.marian.translate_to.fr":"opus_mt_fr_bi",
            "xx.ln.marian.translate_to.fr":"opus_mt_fr_ln",
            "xx.de.marian.translate_to.hil":"opus_mt_hil_de",
            "xx.nso.marian.translate_to.fr":"opus_mt_fr_nso",
            "xx.es.marian.translate_to.iso":"opus_mt_iso_es",
            "xx.crs.marian.translate_to.fr":"opus_mt_fr_crs",
            "xx.niu.marian.translate_to.fr":"opus_mt_fr_niu",
            "xx.fr.marian.translate_to.ht":"opus_mt_ht_fr",
            "xx.fi.marian.translate_to.he":"opus_mt_he_fi",
            "xx.gmw.marian.translate_to.gmw":"opus_mt_gmw_gmw",
            "xx.fr.marian.translate_to.hr":"opus_mt_hr_fr",
            "xx.sg.marian.translate_to.fr":"opus_mt_fr_sg",
            "xx.pon.marian.translate_to.fr":"opus_mt_fr_pon",
            "xx.fi.marian.translate_to.gaa":"opus_mt_gaa_fi",
            "xx.pag.marian.translate_to.fr":"opus_mt_fr_pag",
            "xx.fi.marian.translate_to.is":"opus_mt_is_fi",
            "xx.sk.marian.translate_to.fr":"opus_mt_fr_sk",
            "xx.yap.marian.translate_to.fr":"opus_mt_fr_yap",
            "xx.es.marian.translate_to.ha":"opus_mt_ha_es",
            "xx.no.marian.translate_to.fr":"opus_mt_fr_no",
            "xx.ine.marian.translate_to.ine":"opus_mt_ine_ine",
            "xx.fr.marian.translate_to.id":"opus_mt_id_fr",
            "xx.bzs.marian.translate_to.fr":"opus_mt_fr_bzs",
            "xx.he.marian.translate_to.fr":"opus_mt_fr_he",
            "xx.sv.marian.translate_to.fr":"opus_mt_fr_sv",
            "xx.uk.marian.translate_to.he":"opus_mt_he_uk",
            "xx.fr.marian.translate_to.it":"opus_mt_it_fr",
            "xx.fi.marian.translate_to.ig":"opus_mt_ig_fi",
            "xx.vi.marian.translate_to.fr":"opus_mt_fr_vi",
            "xx.fi.marian.translate_to.fse":"opus_mt_fse_fi",
            "xx.es.marian.translate_to.guw":"opus_mt_guw_es",
            "xx.tll.marian.translate_to.fr":"opus_mt_fr_tll",
            "xx.lua.marian.translate_to.fr":"opus_mt_fr_lua",
            "xx.yap.marian.translate_to.fi":"opus_mt_fi_yap",
            "xx.es.marian.translate_to.gaa":"opus_mt_gaa_es",
            "xx.sv.marian.translate_to.ig":"opus_mt_ig_sv",
            "xx.ht.marian.translate_to.fr":"opus_mt_fr_ht",
            "xx.el.marian.translate_to.fr":"opus_mt_fr_el",
            "xx.inc.marian.translate_to.inc":"opus_mt_inc_inc",
            "xx.swc.marian.translate_to.fr":"opus_mt_fr_swc",
            "xx.ar.marian.translate_to.fr":"opus_mt_fr_ar",
            "xx.es.marian.translate_to.ilo":"opus_mt_ilo_es",
            "xx.fi.marian.translate_to.hr":"opus_mt_hr_fi",
            "xx.tpi.marian.translate_to.fr":"opus_mt_fr_tpi",
            "xx.ve.marian.translate_to.fr":"opus_mt_fr_ve",
            "xx.sv.marian.translate_to.guw":"opus_mt_guw_sv",
            "xx.sv.marian.translate_to.iso":"opus_mt_iso_sv",
            "xx.sv.marian.translate_to.is":"opus_mt_is_sv",
            "xx.tum.marian.translate_to.fr":"opus_mt_fr_tum",
            "xx.es.marian.translate_to.ht":"opus_mt_ht_es",
            "xx.ho.marian.translate_to.fr":"opus_mt_fr_ho",
            "xx.efi.marian.translate_to.fr":"opus_mt_fr_efi",
            "xx.es.marian.translate_to.gl":"opus_mt_gl_es",
            "xx.ru.marian.translate_to.he":"opus_mt_he_ru",
            "xx.fi.marian.translate_to.hil":"opus_mt_hil_fi",
            "xx.eo.marian.translate_to.he":"opus_mt_he_eo",
            "xx.lu.marian.translate_to.fr":"opus_mt_fr_lu",
            "xx.sv.marian.translate_to.ha":"opus_mt_ha_sv",
            "xx.rnd.marian.translate_to.fr":"opus_mt_fr_rnd",
            "xx.st.marian.translate_to.fr":"opus_mt_fr_st",
            "xx.tl.marian.translate_to.fr":"opus_mt_fr_tl",
            "xx.bem.marian.translate_to.fr":"opus_mt_fr_bem",
            "xx.eo.marian.translate_to.is":"opus_mt_is_eo",
            "xx.is.marian.translate_to.it":"opus_mt_it_is",
            "xx.hu.marian.translate_to.fr":"opus_mt_fr_hu",
            "xx.yo.marian.translate_to.fi":"opus_mt_fi_yo",
            "xx.iso.marian.translate_to.fr":"opus_mt_fr_iso",
            "xx.de.marian.translate_to.it":"opus_mt_it_de",
            "xx.ty.marian.translate_to.fr":"opus_mt_fr_ty",
            "xx.hil.marian.translate_to.fr":"opus_mt_fr_hil",
            "xx.eo.marian.translate_to.it":"opus_mt_it_eo",
            "xx.sv.marian.translate_to.hr":"opus_mt_hr_sv",
            "xx.ber.marian.translate_to.fr":"opus_mt_fr_ber",
            "xx.de.marian.translate_to.guw":"opus_mt_guw_de",
            "xx.fi.marian.translate_to.hu":"opus_mt_hu_fi",
            "xx.es.marian.translate_to.it":"opus_mt_it_es",
            "xx.de.marian.translate_to.hu":"opus_mt_hu_de",
            "xx.fj.marian.translate_to.fr":"opus_mt_fr_fj",
            "xx.sv.marian.translate_to.id":"opus_mt_id_sv",
            "xx.xh.marian.translate_to.fr":"opus_mt_fr_xh",
            "xx.yo.marian.translate_to.fr":"opus_mt_fr_yo",
            "xx.ca.marian.translate_to.fr":"opus_mt_fr_ca",
            "xx.es.marian.translate_to.he":"opus_mt_he_es",
            "xx.de.marian.translate_to.he":"opus_mt_he_de",
            "xx.pt.marian.translate_to.gl":"opus_mt_gl_pt",
            "xx.ru.marian.translate_to.hy":"opus_mt_hy_ru",
            "xx.mos.marian.translate_to.fr":"opus_mt_fr_mos",
            "xx.ceb.marian.translate_to.fr":"opus_mt_fr_ceb",
            "xx.sh.marian.translate_to.ja":"opus_mt_ja_sh",
            "xx.bg.marian.translate_to.ja":"opus_mt_ja_bg",
            "xx.sv.marian.translate_to.ja":"opus_mt_ja_sv",
            "xx.ru.marian.translate_to.lv":"opus_mt_lv_ru",
            "xx.fr.marian.translate_to.ms":"opus_mt_ms_fr",
            "xx.sv.marian.translate_to.mt":"opus_mt_mt_sv",
            "xx.da.marian.translate_to.ja":"opus_mt_ja_da",
            "xx.de.marian.translate_to.niu":"opus_mt_niu_de",
            "xx.es.marian.translate_to.niu":"opus_mt_niu_es",
            "xx.sv.marian.translate_to.lus":"opus_mt_lus_sv",
            "xx.sv.marian.translate_to.lg":"opus_mt_lg_sv",
            "xx.sv.marian.translate_to.pon":"opus_mt_pon_sv",
            "xx.ru.marian.translate_to.lt":"opus_mt_lt_ru",
            "xx.fi.marian.translate_to.lg":"opus_mt_lg_fi",
            "xx.sv.marian.translate_to.kg":"opus_mt_kg_sv",
            "xx.fr.marian.translate_to.nl":"opus_mt_nl_fr",
            "xx.ms.marian.translate_to.ms":"opus_mt_ms_ms",
            "xx.es.marian.translate_to.lg":"opus_mt_lg_es",
            "xx.fr.marian.translate_to.lu":"opus_mt_lu_fr",
            "xx.fr.marian.translate_to.loz":"opus_mt_loz_fr",
            "xx.ca.marian.translate_to.nl":"opus_mt_nl_ca",
            "xx.sv.marian.translate_to.lue":"opus_mt_lue_sv",
            "xx.vi.marian.translate_to.ja":"opus_mt_ja_vi",
            "xx.fr.marian.translate_to.ja":"opus_mt_ja_fr",
            "xx.fi.marian.translate_to.pap":"opus_mt_pap_fi",
            "xx.pl.marian.translate_to.lt":"opus_mt_lt_pl",
            "xx.de.marian.translate_to.ny":"opus_mt_ny_de",
            "xx.fr.marian.translate_to.lue":"opus_mt_lue_fr",
            "xx.gl.marian.translate_to.pt":"opus_mt_pt_gl",
            "xx.fr.marian.translate_to.pap":"opus_mt_pap_fr",
            "xx.uk.marian.translate_to.pl":"opus_mt_pl_uk",
            "xx.fi.marian.translate_to.niu":"opus_mt_niu_fi",
            "xx.ar.marian.translate_to.ja":"opus_mt_ja_ar",
            "xx.es.marian.translate_to.mh":"opus_mt_mh_es",
            "xx.ar.marian.translate_to.pl":"opus_mt_pl_ar",
            "xx.de.marian.translate_to.pag":"opus_mt_pag_de",
            "xx.es.marian.translate_to.no":"opus_mt_no_es",
            "xx.es.marian.translate_to.mfs":"opus_mt_mfs_es",
            "xx.fr.marian.translate_to.pis":"opus_mt_pis_fr",
            "xx.eo.marian.translate_to.pt":"opus_mt_pt_eo",
            "xx.de.marian.translate_to.lt":"opus_mt_lt_de",
            "xx.fr.marian.translate_to.ln":"opus_mt_ln_fr",
            "xx.es.marian.translate_to.pag":"opus_mt_pag_es",
            "xx.fi.marian.translate_to.nl":"opus_mt_nl_fi",
            "xx.vi.marian.translate_to.it":"opus_mt_it_vi",
            "xx.fi.marian.translate_to.ko":"opus_mt_ko_fi",
            "xx.de.marian.translate_to.nso":"opus_mt_nso_de",
            "xx.fr.marian.translate_to.niu":"opus_mt_niu_fr",
            "xx.ca.marian.translate_to.pt":"opus_mt_pt_ca",
            "xx.fr.marian.translate_to.kwy":"opus_mt_kwy_fr",
            "xx.ru.marian.translate_to.no":"opus_mt_no_ru",
            "xx.fi.marian.translate_to.pon":"opus_mt_pon_fi",
            "xx.fi.marian.translate_to.lu":"opus_mt_lu_fi",
            "xx.es.marian.translate_to.ko":"opus_mt_ko_es",
            "xx.es.marian.translate_to.ny":"opus_mt_ny_es",
            "xx.itc.marian.translate_to.itc":"opus_mt_itc_itc",
            "xx.es.marian.translate_to.ja":"opus_mt_ja_es",
            "xx.fr.marian.translate_to.mk":"opus_mt_mk_fr",
            "xx.it.marian.translate_to.ms":"opus_mt_ms_it",
            "xx.sv.marian.translate_to.lu":"opus_mt_lu_sv",
            "xx.fr.marian.translate_to.nso":"opus_mt_nso_fr",
            "xx.uk.marian.translate_to.pt":"opus_mt_pt_uk",
            "xx.no.marian.translate_to.no":"opus_mt_no_no",
            "xx.sv.marian.translate_to.lua":"opus_mt_lua_sv",
            "xx.es.marian.translate_to.pl":"opus_mt_pl_es",
            "xx.es.marian.translate_to.lu":"opus_mt_lu_es",
            "xx.fr.marian.translate_to.lus":"opus_mt_lus_fr",
            "xx.tr.marian.translate_to.ja":"opus_mt_ja_tr",
            "xx.fi.marian.translate_to.pag":"opus_mt_pag_fi",
            "xx.fr.marian.translate_to.kqn":"opus_mt_kqn_fr",
            "xx.fi.marian.translate_to.ja":"opus_mt_ja_fi",
            "xx.af.marian.translate_to.nl":"opus_mt_nl_af",
            "xx.sv.marian.translate_to.pag":"opus_mt_pag_sv",
            "xx.sv.marian.translate_to.nl":"opus_mt_nl_sv",
            "xx.uk.marian.translate_to.no":"opus_mt_no_uk",
            "xx.es.marian.translate_to.lua":"opus_mt_lua_es",
            "xx.fi.marian.translate_to.mt":"opus_mt_mt_fi",
            "xx.eo.marian.translate_to.lt":"opus_mt_lt_eo",
            "xx.de.marian.translate_to.no":"opus_mt_no_de",
            "xx.eo.marian.translate_to.pl":"opus_mt_pl_eo",
            "xx.es.marian.translate_to.loz":"opus_mt_loz_es",
            "xx.ru.marian.translate_to.ja":"opus_mt_ja_ru",
            "xx.sv.marian.translate_to.pl":"opus_mt_pl_sv",
            "xx.fi.marian.translate_to.mh":"opus_mt_mh_fi",
            "xx.hu.marian.translate_to.ja":"opus_mt_ja_hu",
            "xx.fi.marian.translate_to.mk":"opus_mt_mk_fi",
            "xx.es.marian.translate_to.lue":"opus_mt_lue_es",
            "xx.sv.marian.translate_to.lt":"opus_mt_lt_sv",
            "xx.fr.marian.translate_to.pon":"opus_mt_pon_fr",
            "xx.es.marian.translate_to.pap":"opus_mt_pap_es",
            "xx.es.marian.translate_to.ln":"opus_mt_ln_es",
            "xx.de.marian.translate_to.loz":"opus_mt_loz_de",
            "xx.ru.marian.translate_to.ka":"opus_mt_ka_ru",
            "xx.sv.marian.translate_to.kwy":"opus_mt_kwy_sv",
            "xx.fi.marian.translate_to.lv":"opus_mt_lv_fi",
            "xx.pl.marian.translate_to.ja":"opus_mt_ja_pl",
            "xx.hu.marian.translate_to.ko":"opus_mt_ko_hu",
            "xx.de.marian.translate_to.ja":"opus_mt_ja_de",
            "xx.de.marian.translate_to.ko":"opus_mt_ko_de",
            "xx.es.marian.translate_to.kg":"opus_mt_kg_es",
            "xx.de.marian.translate_to.pap":"opus_mt_pap_de",
            "xx.fi.marian.translate_to.no":"opus_mt_no_fi",
            "xx.fi.marian.translate_to.lue":"opus_mt_lue_fi",
            "xx.no.marian.translate_to.pl":"opus_mt_pl_no",
            "xx.fr.marian.translate_to.mt":"opus_mt_mt_fr",
            "xx.es.marian.translate_to.mg":"opus_mt_mg_es",
            "xx.es.marian.translate_to.pis":"opus_mt_pis_es",
            "xx.fr.marian.translate_to.pl":"opus_mt_pl_fr",
            "xx.sv.marian.translate_to.ko":"opus_mt_ko_sv",
            "xx.sv.marian.translate_to.loz":"opus_mt_loz_sv",
            "xx.fi.marian.translate_to.loz":"opus_mt_loz_fi",
            "xx.pl.marian.translate_to.no":"opus_mt_no_pl",
            "xx.nl.marian.translate_to.ja":"opus_mt_ja_nl",
            "xx.de.marian.translate_to.pl":"opus_mt_pl_de",
            "xx.lt.marian.translate_to.pl":"opus_mt_pl_lt",
            "xx.ru.marian.translate_to.ko":"opus_mt_ko_ru",
            "xx.fr.marian.translate_to.lv":"opus_mt_lv_fr",
            "xx.he.marian.translate_to.ja":"opus_mt_ja_he",
            "xx.sv.marian.translate_to.niu":"opus_mt_niu_sv",
            "xx.de.marian.translate_to.ms":"opus_mt_ms_de",
            "xx.es.marian.translate_to.lt":"opus_mt_lt_es",
            "xx.sv.marian.translate_to.no":"opus_mt_no_sv",
            "xx.nl.marian.translate_to.no":"opus_mt_no_nl",
            "xx.fi.marian.translate_to.lua":"opus_mt_lua_fi",
            "xx.fr.marian.translate_to.lt":"opus_mt_lt_fr",
            "xx.ms.marian.translate_to.ja":"opus_mt_ja_ms",
            "xx.es.marian.translate_to.kqn":"opus_mt_kqn_es",
            "xx.fr.marian.translate_to.lg":"opus_mt_lg_fr",
            "xx.es.marian.translate_to.mk":"opus_mt_mk_es",
            "xx.da.marian.translate_to.no":"opus_mt_no_da",
            "xx.it.marian.translate_to.lt":"opus_mt_lt_it",
            "xx.es.marian.translate_to.prl":"opus_mt_prl_es",
            "xx.fr.marian.translate_to.lua":"opus_mt_lua_fr",
            "xx.es.marian.translate_to.nso":"opus_mt_nso_es",
            "xx.sv.marian.translate_to.lv":"opus_mt_lv_sv",
            "xx.fi.marian.translate_to.pis":"opus_mt_pis_fi",
            "xx.es.marian.translate_to.pon":"opus_mt_pon_es",
            "xx.fr.marian.translate_to.ko":"opus_mt_ko_fr",
            "xx.de.marian.translate_to.ln":"opus_mt_ln_de",
            "xx.uk.marian.translate_to.nl":"opus_mt_nl_uk",
            "xx.eo.marian.translate_to.nl":"opus_mt_nl_eo",
            "xx.es.marian.translate_to.lv":"opus_mt_lv_es",
            "xx.tr.marian.translate_to.lt":"opus_mt_lt_tr",
            "xx.es.marian.translate_to.mt":"opus_mt_mt_es",
            "xx.fi.marian.translate_to.lus":"opus_mt_lus_fi",
            "xx.tl.marian.translate_to.pt":"opus_mt_pt_tl",
            "xx.no.marian.translate_to.nl":"opus_mt_nl_no",
            "xx.sv.marian.translate_to.kqn":"opus_mt_kqn_sv",
            "xx.pt.marian.translate_to.ja":"opus_mt_ja_pt",
            "xx.fi.marian.translate_to.nso":"opus_mt_nso_fi",
            "xx.fr.marian.translate_to.kg":"opus_mt_kg_fr",
            "xx.sv.marian.translate_to.pis":"opus_mt_pis_sv",
            "xx.is.marian.translate_to.sv":"opus_mt_sv_is",
            "xx.sla.marian.translate_to.sla":"opus_mt_sla_sla",
            "xx.sv.marian.translate_to.srn":"opus_mt_srn_sv",
            "xx.niu.marian.translate_to.sv":"opus_mt_sv_niu",
            "xx.to.marian.translate_to.sv":"opus_mt_sv_to",
            "xx.guw.marian.translate_to.sv":"opus_mt_sv_guw",
            "xx.sn.marian.translate_to.sv":"opus_mt_sv_sn",
            "xx.sv.marian.translate_to.rnd":"opus_mt_rnd_sv",
            "xx.tum.marian.translate_to.sv":"opus_mt_sv_tum",
            "xx.mos.marian.translate_to.sv":"opus_mt_sv_mos",
            "xx.srn.marian.translate_to.sv":"opus_mt_sv_srn",
            "xx.ht.marian.translate_to.sv":"opus_mt_sv_ht",
            "xx.no.marian.translate_to.ru":"opus_mt_ru_no",
            "xx.sl.marian.translate_to.sv":"opus_mt_sv_sl",
            "xx.fr.marian.translate_to.sv":"opus_mt_sv_fr",
            "xx.uk.marian.translate_to.ru":"opus_mt_ru_uk",
            "xx.tiv.marian.translate_to.sv":"opus_mt_sv_tiv",
            "xx.es.marian.translate_to.ru":"opus_mt_ru_es",
            "xx.pag.marian.translate_to.sv":"opus_mt_sv_pag",
            "xx.gaa.marian.translate_to.sv":"opus_mt_sv_gaa",
            "xx.kqn.marian.translate_to.sv":"opus_mt_sv_kqn",
            "xx.fr.marian.translate_to.sg":"opus_mt_sg_fr",
            "xx.st.marian.translate_to.sv":"opus_mt_sv_st",
            "xx.ase.marian.translate_to.sv":"opus_mt_sv_ase",
            "xx.es.marian.translate_to.rn":"opus_mt_rn_es",
            "xx.ru.marian.translate_to.sl":"opus_mt_sl_ru",
            "xx.lu.marian.translate_to.sv":"opus_mt_sv_lu",
            "xx.eu.marian.translate_to.ru":"opus_mt_ru_eu",
            "xx.no.marian.translate_to.sv":"opus_mt_sv_no",
            "xx.sq.marian.translate_to.sv":"opus_mt_sv_sq",
            "xx.da.marian.translate_to.ru":"opus_mt_ru_da",
            "xx.ny.marian.translate_to.sv":"opus_mt_sv_ny",
            "xx.kg.marian.translate_to.sv":"opus_mt_sv_kg",
            "xx.pis.marian.translate_to.sv":"opus_mt_sv_pis",
            "xx.sv.marian.translate_to.sk":"opus_mt_sk_sv",
            "xx.lus.marian.translate_to.sv":"opus_mt_sv_lus",
            "xx.fi.marian.translate_to.sl":"opus_mt_sl_fi",
            "xx.tn.marian.translate_to.sv":"opus_mt_sv_tn",
            "xx.fr.marian.translate_to.srn":"opus_mt_srn_fr",
            "xx.lv.marian.translate_to.sv":"opus_mt_sv_lv",
            "xx.uk.marian.translate_to.sl":"opus_mt_sl_uk",
            "xx.sg.marian.translate_to.sv":"opus_mt_sv_sg",
            "xx.he.marian.translate_to.sv":"opus_mt_sv_he",
            "xx.eo.marian.translate_to.ru":"opus_mt_ru_eo",
            "xx.fr.marian.translate_to.ru":"opus_mt_ru_fr",
            "xx.lv.marian.translate_to.ru":"opus_mt_ru_lv",
            "xx.lua.marian.translate_to.sv":"opus_mt_sv_lua",
            "xx.ar.marian.translate_to.ru":"opus_mt_ru_ar",
            "xx.tll.marian.translate_to.sv":"opus_mt_sv_tll",
            "xx.lue.marian.translate_to.sv":"opus_mt_sv_lue",
            "xx.bi.marian.translate_to.sv":"opus_mt_sv_bi",
            "xx.hu.marian.translate_to.sv":"opus_mt_sv_hu",
            "xx.bzs.marian.translate_to.sv":"opus_mt_sv_bzs",
            "xx.ru.marian.translate_to.sv":"opus_mt_sv_ru",
            "xx.eo.marian.translate_to.ro":"opus_mt_ro_eo",
            "xx.es.marian.translate_to.st":"opus_mt_st_es",
            "xx.mt.marian.translate_to.sv":"opus_mt_sv_mt",
            "xx.af.marian.translate_to.sv":"opus_mt_sv_af",
            "xx.ts.marian.translate_to.sv":"opus_mt_sv_ts",
            "xx.af.marian.translate_to.ru":"opus_mt_ru_af",
            "xx.efi.marian.translate_to.sv":"opus_mt_sv_efi",
            "xx.es.marian.translate_to.sv":"opus_mt_sv_es",
            "xx.fi.marian.translate_to.sk":"opus_mt_sk_fi",
            "xx.fr.marian.translate_to.rw":"opus_mt_rw_fr",
            "xx.sv.marian.translate_to.run":"opus_mt_run_sv",
            "xx.th.marian.translate_to.sv":"opus_mt_sv_th",
            "xx.ln.marian.translate_to.sv":"opus_mt_sv_ln",
            "xx.es.marian.translate_to.sk":"opus_mt_sk_es",
            "xx.lt.marian.translate_to.ru":"opus_mt_ru_lt",
            "xx.mfe.marian.translate_to.sv":"opus_mt_sv_mfe",
            "xx.cs.marian.translate_to.sv":"opus_mt_sv_cs",
            "xx.vi.marian.translate_to.ru":"opus_mt_ru_vi",
            "xx.ee.marian.translate_to.sv":"opus_mt_sv_ee",
            "xx.bg.marian.translate_to.ru":"opus_mt_ru_bg",
            "xx.nso.marian.translate_to.sv":"opus_mt_sv_nso",
            "xx.mh.marian.translate_to.sv":"opus_mt_sv_mh",
            "xx.iso.marian.translate_to.sv":"opus_mt_sv_iso",
            "xx.fi.marian.translate_to.st":"opus_mt_st_fi",
            "xx.bg.marian.translate_to.sv":"opus_mt_sv_bg",
            "xx.sv.marian.translate_to.sq":"opus_mt_sq_sv",
            "xx.sv.marian.translate_to.sn":"opus_mt_sn_sv",
            "xx.de.marian.translate_to.rn":"opus_mt_rn_de",
            "xx.pon.marian.translate_to.sv":"opus_mt_sv_pon",
            "xx.ha.marian.translate_to.sv":"opus_mt_sv_ha",
            "xx.fi.marian.translate_to.ru":"opus_mt_ru_fi",
            "xx.sk.marian.translate_to.sv":"opus_mt_sv_sk",
            "xx.es.marian.translate_to.run":"opus_mt_run_es",
            "xx.et.marian.translate_to.ru":"opus_mt_ru_et",
            "xx.swc.marian.translate_to.sv":"opus_mt_sv_swc",
            "xx.hil.marian.translate_to.sv":"opus_mt_sv_hil",
            "xx.ro.marian.translate_to.sv":"opus_mt_sv_ro",
            "xx.fr.marian.translate_to.rnd":"opus_mt_rnd_fr",
            "xx.kwy.marian.translate_to.sv":"opus_mt_sv_kwy",
            "xx.uk.marian.translate_to.sh":"opus_mt_sh_uk",
            "xx.sm.marian.translate_to.sv":"opus_mt_sv_sm",
            "xx.sv.marian.translate_to.rw":"opus_mt_rw_sv",
            "xx.et.marian.translate_to.sv":"opus_mt_sv_et",
            "xx.eo.marian.translate_to.sv":"opus_mt_sv_eo",
            "xx.rnd.marian.translate_to.sv":"opus_mt_sv_rnd",
            "xx.eo.marian.translate_to.sh":"opus_mt_sh_eo",
            "xx.ru.marian.translate_to.rn":"opus_mt_rn_ru",
            "xx.rw.marian.translate_to.sv":"opus_mt_sv_rw",
            "xx.fr.marian.translate_to.sn":"opus_mt_sn_fr",
            "xx.ig.marian.translate_to.sv":"opus_mt_sv_ig",
            "xx.fj.marian.translate_to.sv":"opus_mt_sv_fj",
            "xx.sl.marian.translate_to.ru":"opus_mt_ru_sl",
            "xx.ho.marian.translate_to.sv":"opus_mt_sv_ho",
            "xx.sv.marian.translate_to.sl":"opus_mt_sl_sv",
            "xx.pap.marian.translate_to.sv":"opus_mt_sv_pap",
            "xx.fr.marian.translate_to.sl":"opus_mt_sl_fr",
            "xx.es.marian.translate_to.sl":"opus_mt_sl_es",
            "xx.run.marian.translate_to.sv":"opus_mt_sv_run",
            "xx.el.marian.translate_to.sv":"opus_mt_sv_el",
            "xx.gil.marian.translate_to.sv":"opus_mt_sv_gil",
            "xx.crs.marian.translate_to.sv":"opus_mt_sv_crs",
            "xx.fr.marian.translate_to.sk":"opus_mt_sk_fr",
            "xx.es.marian.translate_to.sq":"opus_mt_sq_es",
            "xx.sv.marian.translate_to.sg":"opus_mt_sg_sv",
            "xx.es.marian.translate_to.srn":"opus_mt_srn_es",
            "xx.fr.marian.translate_to.ro":"opus_mt_ro_fr",
            "xx.fr.marian.translate_to.rn":"opus_mt_rn_fr",
            "xx.fr.marian.translate_to.st":"opus_mt_st_fr",
            "xx.es.marian.translate_to.rw":"opus_mt_rw_es",
            "xx.hr.marian.translate_to.sv":"opus_mt_sv_hr",
            "xx.es.marian.translate_to.sm":"opus_mt_sm_es",
            "xx.es.marian.translate_to.ssp":"opus_mt_ssp_es",
            "xx.nl.marian.translate_to.sv":"opus_mt_sv_nl",
            "xx.bem.marian.translate_to.sv":"opus_mt_sv_bem",
            "xx.sem.marian.translate_to.sem":"opus_mt_sem_sem",
            "xx.sv.marian.translate_to.sv":"opus_mt_sv_sv",
            "xx.sv.marian.translate_to.st":"opus_mt_st_sv",
            "xx.lg.marian.translate_to.sv":"opus_mt_sv_lg",
            "xx.bcl.marian.translate_to.sv":"opus_mt_sv_bcl",
            "xx.toi.marian.translate_to.sv":"opus_mt_sv_toi",
            "xx.id.marian.translate_to.sv":"opus_mt_sv_id",
            "xx.he.marian.translate_to.ru":"opus_mt_ru_he",
            "xx.ceb.marian.translate_to.sv":"opus_mt_sv_ceb",
            "xx.tw.marian.translate_to.sv":"opus_mt_sv_tw",
            "xx.chk.marian.translate_to.sv":"opus_mt_sv_chk",
            "xx.fr.marian.translate_to.sm":"opus_mt_sm_fr",
            "xx.tvl.marian.translate_to.sv":"opus_mt_sv_tvl",
            "xx.es.marian.translate_to.sg":"opus_mt_sg_es",
            "xx.ilo.marian.translate_to.sv":"opus_mt_sv_ilo",
            "xx.sv.marian.translate_to.ro":"opus_mt_ro_sv",
            "xx.fi.marian.translate_to.sg":"opus_mt_sg_fi",
            "xx.hy.marian.translate_to.ru":"opus_mt_ru_hy",
            "xx.fi.marian.translate_to.ro":"opus_mt_ro_fi",
            "xx.tpi.marian.translate_to.sv":"opus_mt_sv_tpi",
            "xx.fi.marian.translate_to.sv":"opus_mt_sv_fi",
            "xx.sv.marian.translate_to.ru":"opus_mt_ru_sv",
            "xx.es.marian.translate_to.toi":"opus_mt_toi_es",
            "xx.no.marian.translate_to.uk":"opus_mt_uk_no",
            "xx.ar.marian.translate_to.tr":"opus_mt_tr_ar",
            "xx.he.marian.translate_to.uk":"opus_mt_uk_he",
            "xx.sv.marian.translate_to.tvl":"opus_mt_tvl_sv",
            "xx.uk.marian.translate_to.sv":"opus_mt_sv_uk",
            "xx.fr.marian.translate_to.tvl":"opus_mt_tvl_fr",
            "xx.bg.marian.translate_to.uk":"opus_mt_uk_bg",
            "xx.fi.marian.translate_to.toi":"opus_mt_toi_fi",
            "xx.ca.marian.translate_to.uk":"opus_mt_uk_ca",
            "xx.fr.marian.translate_to.uk":"opus_mt_uk_fr",
            "xx.eo.marian.translate_to.tr":"opus_mt_tr_eo",
            "xx.uk.marian.translate_to.tr":"opus_mt_tr_uk",
            "xx.es.marian.translate_to.tl":"opus_mt_tl_es",
            "xx.es.marian.translate_to.tr":"opus_mt_tr_es",
            "xx.it.marian.translate_to.uk":"opus_mt_uk_it",
            "xx.fi.marian.translate_to.uk":"opus_mt_uk_fi",
            "xx.lt.marian.translate_to.tr":"opus_mt_tr_lt",
            "xx.es.marian.translate_to.swc":"opus_mt_swc_es",
            "xx.umb.marian.translate_to.sv":"opus_mt_sv_umb",
            "xx.sv.marian.translate_to.tw":"opus_mt_tw_sv",
            "xx.urj.marian.translate_to.urj":"opus_mt_urj_urj",
            "xx.yap.marian.translate_to.sv":"opus_mt_sv_yap",
            "xx.fr.marian.translate_to.ty":"opus_mt_ty_fr",
            "xx.fr.marian.translate_to.swc":"opus_mt_swc_fr",
            "xx.pt.marian.translate_to.tl":"opus_mt_tl_pt",
            "xx.tr.marian.translate_to.uk":"opus_mt_uk_tr",
            "xx.sv.marian.translate_to.tr":"opus_mt_tr_sv",
            "xx.fi.marian.translate_to.tvl":"opus_mt_tvl_fi",
            "xx.es.marian.translate_to.tn":"opus_mt_tn_es",
            "xx.fi.marian.translate_to.swc":"opus_mt_swc_fi",
            "xx.fr.marian.translate_to.toi":"opus_mt_toi_fr",
            "xx.fi.marian.translate_to.ts":"opus_mt_ts_fi",
            "xx.de.marian.translate_to.uk":"opus_mt_uk_de",
            "xx.sv.marian.translate_to.uk":"opus_mt_uk_sv",
            "xx.fi.marian.translate_to.tw":"opus_mt_tw_fi",
            "xx.sv.marian.translate_to.to":"opus_mt_to_sv",
            "xx.sv.marian.translate_to.tll":"opus_mt_tll_sv",
            "xx.fr.marian.translate_to.th":"opus_mt_th_fr",
            "xx.es.marian.translate_to.ty":"opus_mt_ty_es",
            "xx.fr.marian.translate_to.tw":"opus_mt_tw_fr",
            "xx.fr.marian.translate_to.to":"opus_mt_to_fr",
            "xx.sl.marian.translate_to.uk":"opus_mt_uk_sl",
            "xx.xh.marian.translate_to.sv":"opus_mt_sv_xh",
            "xx.war.marian.translate_to.sv":"opus_mt_sv_war",
            "xx.hu.marian.translate_to.uk":"opus_mt_uk_hu",
            "xx.ru.marian.translate_to.uk":"opus_mt_uk_ru",
            "xx.sv.marian.translate_to.tn":"opus_mt_tn_sv",
            "xx.fr.marian.translate_to.tum":"opus_mt_tum_fr",
            "xx.sv.marian.translate_to.toi":"opus_mt_toi_sv",
            "xx.sv.marian.translate_to.ty":"opus_mt_ty_sv",
            "xx.fr.marian.translate_to.tr":"opus_mt_tr_fr",
            "xx.fr.marian.translate_to.tn":"opus_mt_tn_fr",
            "xx.cs.marian.translate_to.uk":"opus_mt_uk_cs",
            "xx.fr.marian.translate_to.ts":"opus_mt_ts_fr",
            "xx.sv.marian.translate_to.swc":"opus_mt_swc_sv",
            "xx.es.marian.translate_to.to":"opus_mt_to_es",
            "xx.es.marian.translate_to.uk":"opus_mt_uk_es",
            "xx.nl.marian.translate_to.uk":"opus_mt_uk_nl",
            "xx.zne.marian.translate_to.sv":"opus_mt_sv_zne",
            "xx.es.marian.translate_to.tvl":"opus_mt_tvl_es",
            "xx.pt.marian.translate_to.uk":"opus_mt_uk_pt",
            "xx.fr.marian.translate_to.tiv":"opus_mt_tiv_fr",
            "xx.fr.marian.translate_to.tll":"opus_mt_tll_fr",
            "xx.sh.marian.translate_to.uk":"opus_mt_uk_sh",
            "xx.wls.marian.translate_to.sv":"opus_mt_sv_wls",
            "xx.ve.marian.translate_to.sv":"opus_mt_sv_ve",
            "xx.es.marian.translate_to.tum":"opus_mt_tum_es",
            "xx.fi.marian.translate_to.tll":"opus_mt_tll_fi",
            "xx.es.marian.translate_to.tw":"opus_mt_tw_es",
            "xx.sv.marian.translate_to.tiv":"opus_mt_tiv_sv",
            "xx.fi.marian.translate_to.ty":"opus_mt_ty_fi",
            "xx.pl.marian.translate_to.uk":"opus_mt_uk_pl",
            "xx.sv.marian.translate_to.tpi":"opus_mt_tpi_sv",
            "xx.az.marian.translate_to.tr":"opus_mt_tr_az",
            "xx.es.marian.translate_to.tll":"opus_mt_tll_es",
            "xx.ty.marian.translate_to.sv":"opus_mt_sv_ty",
            "xx.tzo.marian.translate_to.es":"opus_mt_es_tzo",
            "xx.sv.marian.translate_to.crs":"opus_mt_crs_sv",
            "xx.es.marian.translate_to.zai":"opus_mt_zai_es",
            "xx.niu.marian.translate_to.de":"opus_mt_de_niu",
            "xx.sv.marian.translate_to.nso":"opus_mt_nso_sv",
            "xx.fr.marian.translate_to.bg":"opus_mt_bg_fr",
            "xx.es.marian.translate_to.lus":"opus_mt_lus_es",
            "xx.es.marian.translate_to.nl":"opus_mt_nl_es",
            "xx.fr.marian.translate_to.yo":"opus_mt_yo_fr",
            "xx.sv.marian.translate_to.ilo":"opus_mt_ilo_sv",
            "xx.es.marian.translate_to.ts":"opus_mt_ts_es",
            "xx.run.marian.translate_to.fr":"opus_mt_fr_run",
            "xx.to.marian.translate_to.es":"opus_mt_es_to",
            "xx.ceb.marian.translate_to.fi":"opus_mt_fi_ceb",
            "xx.it.marian.translate_to.ja":"opus_mt_ja_it",
            "xx.es.marian.translate_to.sn":"opus_mt_sn_es",
            "xx.yo.marian.translate_to.sv":"opus_mt_sv_yo",
            "xx.tr.marian.translate_to.az":"opus_mt_az_tr",
            "xx.fr.marian.translate_to.no":"opus_mt_no_fr",
            "xx.tn.marian.translate_to.fr":"opus_mt_fr_tn",
            "xx.id.marian.translate_to.fr":"opus_mt_fr_id",
            "xx.de.marian.translate_to.ca":"opus_mt_ca_de",
            "xx.sv.marian.translate_to.tum":"opus_mt_tum_sv",
            "xx.ru.marian.translate_to.da":"opus_mt_da_ru",
            "xx.de.marian.translate_to.tl":"opus_mt_tl_de",
            "xx.eo.marian.translate_to.fr":"opus_mt_fr_eo",
            "xx.vi.marian.translate_to.zh":"opus_mt_zh_vi",
            "xx.es.marian.translate_to.vi":"opus_mt_vi_es",
            "xx.es.marian.translate_to.mfe":"opus_mt_mfe_es",
            "xx.fi.marian.translate_to.iso":"opus_mt_iso_fi",
            "xx.es.marian.translate_to.tzo":"opus_mt_tzo_es",
            "xx.sn.marian.translate_to.es":"opus_mt_es_sn",
            "xx.es.marian.translate_to.xh":"opus_mt_xh_es",
            "xx.sv.marian.translate_to.zne":"opus_mt_zne_sv",
            "xx.sv.marian.translate_to.ts":"opus_mt_ts_sv",
            "xx.it.marian.translate_to.zh":"opus_mt_zh_it",
            "xx.uk.marian.translate_to.zh":"opus_mt_zh_uk",
            "xx.fi.marian.translate_to.yo":"opus_mt_yo_fi",
            "xx.sv.marian.translate_to.war":"opus_mt_war_sv",
            "xx.sv.marian.translate_to.yo":"opus_mt_yo_sv",
            "xx.tll.marian.translate_to.es":"opus_mt_es_tll",
            "xx.nl.marian.translate_to.zh":"opus_mt_zh_nl",
            "xx.fr.marian.translate_to.wls":"opus_mt_wls_fr",
            "xx.it.marian.translate_to.vi":"opus_mt_vi_it",
            "xx.bg.marian.translate_to.zh":"opus_mt_zh_bg",
            "xx.sv.marian.translate_to.xh":"opus_mt_xh_sv",
            "xx.es.marian.translate_to.zne":"opus_mt_zne_es",
            "xx.zlw.marian.translate_to.zlw":"opus_mt_zlw_zlw",
            "xx.sv.marian.translate_to.yap":"opus_mt_yap_sv",
            "xx.he.marian.translate_to.zh":"opus_mt_zh_he",
            "xx.fr.marian.translate_to.xh":"opus_mt_xh_fr",
            "xx.fi.marian.translate_to.war":"opus_mt_war_fi",
            "xx.sv.marian.translate_to.zh":"opus_mt_zh_sv",
            "xx.zls.marian.translate_to.zls":"opus_mt_zls_zls",
            "xx.fi.marian.translate_to.zne":"opus_mt_zne_fi",
            "xx.es.marian.translate_to.ve":"opus_mt_ve_es",
            "xx.de.marian.translate_to.vi":"opus_mt_vi_de",
            "xx.eo.marian.translate_to.vi":"opus_mt_vi_eo",
            "xx.sv.marian.translate_to.wls":"opus_mt_wls_sv",
            "xx.es.marian.translate_to.war":"opus_mt_war_es",
            "xx.ru.marian.translate_to.vi":"opus_mt_vi_ru",
            "xx.ms.marian.translate_to.zh":"opus_mt_zh_ms",
            "xx.fr.marian.translate_to.zne":"opus_mt_zne_fr",
            "xx.fr.marian.translate_to.yap":"opus_mt_yap_fr",
            "xx.de.marian.translate_to.zh":"opus_mt_zh_de",
            "xx.es.marian.translate_to.yo":"opus_mt_yo_es",
            "xx.es.marian.translate_to.vsl":"opus_mt_vsl_es",
            "xx.zle.marian.translate_to.zle":"opus_mt_zle_zle",
            "xx.fr.marian.translate_to.vi":"opus_mt_vi_fr",
            "xx.fr.marian.translate_to.war":"opus_mt_war_fr",
            "xx.fi.marian.translate_to.zh":"opus_mt_zh_fi",
            "xx.af.marian.translate_to.ru" : "opus_tatoeba_af_ru",
            "xx.he.marian.translate_to.it" : "opus_tatoeba_he_it",
            "xx.he.marian.translate_to.fr" : "opus_tatoeba_he_fr",
            "xx.it.marian.translate_to.he" : "opus_tatoeba_it_he",
            "xx.es.marian.translate_to.zh" : "opus_tatoeba_es_zh",



        },

    }

    pretrained_healthcare_model_references = {


        'en':
            {
                # clinical spellchecker
                # 'en.spell.clinical':   'spellcheck_clinical',  #todo crashing
                # 'en.spell.med':        'context_spell_med', #todo crashing
                # 'en.spell.context.med':'context_spell_med', #todo crashing Byteerror

                'en.detect_sentence.clinical' : 'sentence_detector_dl_healthcare',
                'en.norm_drugs' : 'drug_normalizer', # TODO!?!??!
                # T5
                'en.t5.mediqa' : 't5_base_mediqa_mnli',

                # AssertionDLModel
                'en.assert': 'assertion_dl',
                'en.assert.biobert': 'assertion_dl_biobert',
                'en.assert.healthcare': 'assertion_dl_healthcare',
                'en.assert.large': 'assertion_dl_large',

                # WordEmbedding Model Glove Embeddings
                'en.embed.glove.clinical': 'embeddings_clinical',
                'en.embed.glove.biovec': 'embeddings_biovec',
                'en.embed.glove.healthcare': 'embeddings_healthcare',
                'en.embed.glove.healthcare_100d': 'embeddings_healthcare_100d',
                # 'en.embed.glove.icd10': 'embeddings_icd10_base', # Broken in JSL
                'en.embed.glove.icdoem': 'embeddings_icdoem',
                'en.embed.glove.icdoem_2ng': 'embeddings_icdoem_2ng',

                # BIOBERT embeddings

                # Todo errors with biobert embeds
                # 'en.embed.biobert.clinical': 'biobert_clinical_base_cased', # broken
                # 'en.embed.biobert.discharge': 'biobert_discharge_base_cased',# broken
                # 'en.embed.biobert.pmc': 'biobert_pmc_base_cased', Broken
                # 'en.embed.biobert.pubmed': 'biobert_pubmed_base_cased', # broken
                # 'en.embed.biobert.pubmed_large': 'biobert_pubmed_large_cased', # broken
                # 'en.embed.biobert.pubmed_pmc': 'biobert_pubmed_pmc_base_cased', # broken

                # Sentence Entity resolvers

                # BertSEntenceEmbeddings MLI
                'en.embed_sentence.biobert.mli': 'sbiobert_base_cased_mli',
                'en.embed_sentence.bluebert.mli': 'sbluebert_base_uncased_mli',# Broken

                # 'en.embed_sentence.bluebert.mednli': 'sent_bluebert_base_uncased_mednli', # broken
                # 'en.embed_sentence.biobert.mednli': 'sent_biobert_base_uncased_mednli',  # broken

                # resolve sentence cpt
                'en.resolve': 'sbiobertresolve_cpt',
                'en.resolve.cpt': 'sbiobertresolve_cpt',
                'en.resolve.cpt.augmented': 'sbiobertresolve_cpt_augmented',
                'en.resolve.cpt.procedures_augmented': 'sbiobertresolve_cpt_procedures_augmented',
                # resolve sentence hcc
                'en.resolve.hcc': 'sbiobertresolve_hcc_augmented',
                'en.resolve.hcc.augmented': 'sbiobertresolve_hcc_augmented',
                # resolve sentence icdf
                'en.resolve.icd10cm': 'sbiobertresolve_icd10cm',
                'en.resolve.icd10cm.augmented': 'sbiobertresolve_icd10cm_augmented',
                'en.resolve.icd10cm.augmented_billable': 'sbiobertresolve_icd10cm_augmented_billable_hcc',
                'en.resolve.icd10pcs': 'sbiobertresolve_icd10pcs',
                'en.resolve.icdo': 'sbiobertresolve_icdo',
                # rewsolve sentence rx
                'en.resolve.rxcui': 'sbiobertresolve_rxcui',
                'en.resolve.rxnorm': 'sbiobertresolve_rxnorm',
                # resolve sentence snomed s
                'en.resolve.snomed': 'sbiobertresolve_snomed_auxConcepts',  # alias
                'en.resolve.snomed.aux_concepts': 'sbiobertresolve_snomed_auxConcepts',
                'en.resolve.snomed.aux_concepts_int': 'sbiobertresolve_snomed_auxConcepts_int',
                'en.resolve.snomed.findings': 'sbiobertresolve_snomed_findings',
                'en.resolve.snomed.findings_int': 'sbiobertresolve_snomed_findings_int',

                # Greedy Relation extracction
                'en.relation.posology': 'posology_re',  # TODo OCRASHES SOME STRINGS!

                # RelationExtractionModel

                # These biobert analogus models which are better or some are broken
                # 'en.relation':'re_clinical',
                # 'en.relation.bodypart.direction':'re_bodypart_directions',
                # 'en.relation.bodypart.problem':'re_bodypart_problem',
                # 'en.relation.bodypart.proceduretest':'re_bodypart_proceduretest',
                # 'en.relation.chemprot':'re_chemprot_clinical',
                # 'en.relation.clinical':'re_clinical',
                # 'en.relation.date_clinical':'re_date_clinical',
                # 'en.relation.drug_drug_interaction':'re_drug_drug_interaction_clinical',
                # 'en.relation.human_phenotype_gene':'re_human_phenotype_gene_clinical',
                # 'en.relation.temporal_events':'re_temporal_events_clinical',
                # 'en.relation.temporal_events.enriched':'re_temporal_events_enriched_clinical',
                # RelationExtractionDL

                'en.relation': 'redl_bodypart_direction_biobert',
                'en.relation.bodypart.direction': 'redl_bodypart_direction_biobert',
                'en.relation.bodypart.problem': 'redl_bodypart_problem_biobert',
                'en.relation.bodypart.procedure': 'redl_bodypart_procedure_test_biobert',
                'en.relation.chemprot': 'redl_chemprot_biobert',
                'en.relation.clinical': 'redl_clinical_biobert',
                'en.relation.date': 'redl_date_clinical_biobert',
                'en.relation.drug_drug_interaction': 'redl_drug_drug_interaction_biobert',
                'en.relation.humen_phenotype_gene': 'redl_human_phenotype_gene_biobert',
                'en.relation.temporal_events': 'redl_temporal_events_biobert',

                # PartOfSpeechModels
                'en.pos.clinical': 'pos_clinical',  # DEFAULT POS HC|| RELATION EXTRACTION TRAIN ON THIS!

                # NERDLModels
                # 'en.med_ner.ade.biobert':'ner_ade_biobert', # Todo error param pooling layer does not exist
                'en.med_ner': 'jsl_ner_wip_clinical',
                'en.med_ner.ade.clinical': 'ner_ade_clinical',
                'en.med_ner.ade.clinical_bert': 'ner_ade_clinicalbert',
                'en.med_ner.ade.ade_healthcare': 'ner_ade_healthcare',
                'en.med_ner.anatomy': 'ner_anatomy',
                'en.med_ner.anatomy.biobert': 'ner_anatomy_biobert',
                'en.med_ner.anatomy.coarse': 'ner_anatomy_coarse',
                'en.med_ner.anatomy.coarse_biobert': 'ner_anatomy_coarse_biobert',
                'en.med_ner.aspect_sentiment': 'ner_aspect_based_sentiment',
                'en.med_ner.bacterial_species': 'ner_bacterial_species',
                'en.med_ner.bionlp': 'ner_bionlp',
                'en.med_ner.bionlp.biobert': 'ner_bionlp_biobert',
                'en.med_ner.cancer': 'ner_cancer_genetics',
                'en.med_ner.cellular': 'ner_cellular',
                'en.med_ner.cellular.biobert': 'ner_cellular_biobert',
                'en.med_ner.chemicals': 'ner_chemicals',
                'en.med_ner.chemprot': 'ner_chemprot_biobert',
                'en.med_ner.chemprot.clinical': 'ner_chemprot_clinical',
                'en.med_ner.clinical': 'ner_clinical',
                'en.med_ner.clinical.biobert': 'ner_clinical_biobert',
                'en.med_ner.clinical.noncontrib': 'ner_clinical_noncontrib',
                'en.med_ner.diseases': 'ner_diseases',
                'en.med_ner.diseases.biobert': 'ner_diseases_biobert',
                'en.med_ner.diseases.large': 'ner_diseases_large',
                'en.med_ner.drugs': 'ner_drugs',
                'en.med_ner.drugsgreedy': 'ner_drugs_greedy',
                'en.med_ner.drugs.large': 'ner_drugs_large',
                'en.med_ner.events_biobert': 'ner_events_biobert',
                'en.med_ner.events_clinical': 'ner_events_clinical',
                'en.med_ner.events_healthcre': 'ner_events_healthcare',
                'en.med_ner.financial_contract': 'ner_financial_contract',
                'en.med_ner.healthcare': 'ner_healthcare',
                'en.med_ner.human_phenotype.gene_biobert': 'ner_human_phenotype_gene_biobert',
                'en.med_ner.human_phenotype.gene_clinical': 'ner_human_phenotype_gene_clinical',
                'en.med_ner.human_phenotype.go_biobert': 'ner_human_phenotype_go_biobert',
                'en.med_ner.human_phenotype.go_clinical': 'ner_human_phenotype_go_clinical',
                'en.med_ner.jsl': 'ner_jsl',
                'en.med_ner.jsl.biobert': 'ner_jsl_biobert',
                'en.med_ner.jsl.enriched': 'ner_jsl_enriched',
                'en.med_ner.jsl.enriched_biobert': 'ner_jsl_enriched_biobert',
                'en.med_ner.measurements': 'ner_measurements_clinical',
                'en.med_ner.medmentions': 'ner_medmentions_coarse',
                'en.med_ner.posology': 'ner_posology',
                'en.med_ner.posology.biobert': 'ner_posology_biobert',
                'en.med_ner.posology.greedy': 'ner_posology_greedy',
                'en.med_ner.posology.healthcare': 'ner_posology_healthcare',
                'en.med_ner.posology.large': 'ner_posology_large',
                'en.med_ner.posology.large_biobert': 'ner_posology_large_biobert',
                'en.med_ner.posology.small': 'ner_posology_small',
                'en.med_ner.radiology': 'ner_radiology',
                'en.med_ner.radiology.wip_clinical': 'ner_radiology_wip_clinical',
                'en.med_ner.risk_factors': 'ner_risk_factors',
                'en.med_ner.risk_factors.biobert': 'ner_risk_factors_biobert',
                'en.med_ner.i2b2': 'nerdl_i2b2', #  broken
                'en.med_ner.tumour': 'nerdl_tumour_demo',
                'en.med_ner.jsl.wip.clinical': 'jsl_ner_wip_clinical',
                'en.med_ner.jsl.wip.clinical.greedy': 'jsl_ner_wip_greedy_clinical',
                'en.med_ner.jsl.wip.clinical.modifier': 'jsl_ner_wip_modifier_clinical',
                'en.med_ner.jsl.wip.clinical.rd': 'jsl_rd_ner_wip_greedy_clinical',
                'en.med_ner.deid.augmented': 'ner_deid_augmented',
                'en.med_ner.deid.biobert': 'ner_deid_biobert',
                'en.med_ner.deid.enriched': 'ner_deid_enriched',
                'en.med_ner.deid.enriched_biobert': 'ner_deid_enriched_biobert',
                'en.med_ner.deid.large': 'ner_deid_large',
                'en.med_ner.deid.sd': 'ner_deid_sd',
                'en.med_ner.deid.sd_large': 'ner_deid_sd_large',
                'en.med_ner.deid.synthetic': 'ner_deid_synthetic',
                'en.med_ner.deid.dl': 'ner_deidentify_dl',
                'en.med_ner.deid': 'nerdl_deid',

                # 'en.med_ner.clinical.icdem': 'ner_clinical_icdem', # TODO UNRESOLVED! PIPE?
                # 'en.med_ner.clinical.large': 'ner_clinical_large',# TODO URNESOLVED, PIPE?


                # DeIdentificationModel

                # 'en.de_identify':'deidentify_dl', # todo ????    lOAD AS ner moadel??? THIS ENEDS EMEBDDINGS??
                'en.de_identify': 'deidentify_rb',
                'en.de_identify.rules': 'deid_rules',
                'en.de_identify.clinical': 'deidentify_enriched_clinical',
                'en.de_identify.large': 'deidentify_large',
                'en.de_identify.rb': 'deidentify_rb',
                'en.de_identify.rb_no_regex': 'deidentify_rb_no_regex',
                # ChunkResolverModels
                # 'en.resolve_chunk.cpt_icdoem': 'chunkresolve_cpt_icdoem', # broken
                # 'en.resolve_chunk.icd10cm.icdoem': 'chunkresolve_icd10cm_icdoem', # broken
                # 'en.resolve_chunk.icd10cm.icdoem_2ng': 'chunkresolve_icd10cm_icdoem_2ng', # broken
                # 'en.resolve_chunk.icd10cpt.icdoem': 'chunkresolve_icd10cpt_icdoem_2ng', # broken
                # 'en.resolve_chunk.icd10pcs.icdoem': 'chunkresolve_icd10pcs_icdoem', # broken
                # 'en.resolve_chunk.icd10pcs.icdoem_2ng': 'chunkresolve_icd10pcs_icdoem_2ng', # broken
                # 'en.resolve_chunk.icdo.icdoem': 'chunkresolve_icdo_icdoem', # broken

                'en.resolve_chunk.athena_conditions': 'chunkresolve_athena_conditions_healthcare',
                'en.resolve_chunk.cpt_clinical': 'chunkresolve_cpt_clinical',
                'en.resolve_chunk.icd10cm.clinical': 'chunkresolve_icd10cm_clinical',
                'en.resolve_chunk.icd10cm.diseases_clinical': 'chunkresolve_icd10cm_diseases_clinical',
                'en.resolve_chunk.icd10cm.hcc_clinical': 'chunkresolve_icd10cm_hcc_clinical',
                'en.resolve_chunk.icd10cm.hcc_healthcare': 'chunkresolve_icd10cm_hcc_healthcare',
                'en.resolve_chunk.icd10cm.injuries': 'chunkresolve_icd10cm_injuries_clinical',
                'en.resolve_chunk.icd10cm.musculoskeletal': 'chunkresolve_icd10cm_musculoskeletal_clinical',
                'en.resolve_chunk.icd10cm.neoplasms': 'chunkresolve_icd10cm_neoplasms_clinical',
                'en.resolve_chunk.icd10cm.poison': 'chunkresolve_icd10cm_poison_ext_clinical',
                'en.resolve_chunk.icd10cm.puerile': 'chunkresolve_icd10cm_puerile_clinical',
                'en.resolve_chunk.icd10pcs.clinical': 'chunkresolve_icd10pcs_clinical',
                'en.resolve_chunk.icdo.clinical': 'chunkresolve_icdo_clinical',
                'en.resolve_chunk.loinc': 'chunkresolve_loinc_clinical',
                'en.resolve_chunk.rxnorm.cd': 'chunkresolve_rxnorm_cd_clinical',
                'en.resolve_chunk.rxnorm.in': 'chunkresolve_rxnorm_in_clinical',
                'en.resolve_chunk.rxnorm.in_healthcare': 'chunkresolve_rxnorm_in_healthcare',
                'en.resolve_chunk.rxnorm.sbd': 'chunkresolve_rxnorm_sbd_clinical',
                'en.resolve_chunk.rxnorm.scd': 'chunkresolve_rxnorm_scd_clinical',
                'en.resolve_chunk.rxnorm.scdc': 'chunkresolve_rxnorm_scdc_clinical',
                'en.resolve_chunk.rxnorm.scdc_healthcare': 'chunkresolve_rxnorm_scdc_healthcare',
                'en.resolve_chunk.rxnorm.xsmall.clinical': 'chunkresolve_rxnorm_xsmall_clinical',
                'en.resolve_chunk.snomed.findings': 'chunkresolve_snomed_findings_clinical',

                'en.classify.icd10.clinical':'classifier_icd10cm_hcc_clinical',      #  WHCIH CLASS? # TODO NOT LAODING
                'en.classify.icd10.healthcare':'classifier_icd10cm_hcc_healthcare', # TODO NOT LOADING CORRECt
                'en.classify.ade.biobert':'classifierdl_ade_biobert',
                'en.classify.ade.clinical':'classifierdl_ade_clinicalbert',
                'en.classify.ade.conversational':'classifierdl_ade_conversational_biobert',
                'en.classify.gender.biobert':'classifierdl_gender_biobert',
                'en.classify.gender.sbert':'classifierdl_gender_sbert', # ok!
                'en.classify.pico':'classifierdl_pico_biobert',
                # 'en.classify.icd10.use':'useclassifier_icd10cm_hcc', buggy

                # 3.0.3 healthcare
                'en.resolve.umls':'sbiobertresolve_umls_major_concepts',
                'en.resolve.umls.findings':'sbiobertresolve_umls_findings',
                'en.resolve.loinc':'sbiobertresolve_loinc',
                'en.resolve.loinc.biobert':'sbiobertresolve_loinc',
                'en.resolve.loinc.bluebert':'sbluebertresolve_loinc',
                'en.resolve.HPO':'sbiobertresolve_HPO',






            },

        'de' :
            {
                'de.embed' :'w2v_cc_300d',
                'de.embed.w2v' :'w2v_cc_300d',
                'de.resolve_chunk' :'chunkresolve_ICD10GM',
                'de.resolve_chunk.icd10gm' :'chunkresolve_ICD10GM',
                'de.resolve_chunk.icd10gm.2021' :'chunkresolve_ICD10GM_2021',
                'de.med_ner.legal' :'ner_legal',
                'de.med_ner' :'ner_healthcare',
                'de.med_ner.healthcare' :'ner_healthcare',
                'de.med_ner.healthcare_slim' :'ner_healthcare_slim',
                'de.med_ner.traffic' :'ner_traffic',
            },

        'es' :{
            'es.embed.scielo.150d':'embeddings_scielo_150d',
            'es.embed.scielo.300d':'embeddings_scielo_300d',
            'es.embed.scielo.50d':'embeddings_scielo_50d',
            'es.embed.scielowiki.150d':'embeddings_scielowiki_150d',
            'es.embed.scielowiki.300d':'embeddings_scielowiki_300d',
            'es.embed.scielowiki.50d':'embeddings_scielowiki_50d',
            'es.embed.sciwiki.150d':'embeddings_sciwiki_150d',
            'es.embed.sciwiki.300d':'embeddings_sciwiki_300d',
            'es.embed.sciwiki.50d':'embeddings_sciwiki_50d',
            'es.med_ner' : 'ner_diag_proc',
            'es.med_ner.neoplasm' : 'ner_neoplasms',
            'es.med_ner.diag_proc' : 'ner_diag_proc',
        }
    }
    healthcare_component_alias_references = {}
    pretrained_healthcare_pipe_references = {
        'en': {

            'en.resolve.icd10cm.umls': 'icd10cm_umls_mapping',
            'en.resolve.mesh.umls' :'mesh_umls_mapping',
            'en.resolve.rxnorm.umls' :'rxnorm_umls_mapping',
            'en.resolve.rxnorm.mesh' :'rxnorm_mesh_mapping',
            'en.resolve.snomed.umls' :'snomed_umls_mapping',


            # '' :'clinical_analysis', # Not 3+ compatible
            # '' :'clinical_deidentification', # todo to big ner consumer stack for NLU to handle..
            # '' :'clinical_ner_assertion', Not 3+ compatible


            # Explain Pipes
            'en.explain_doc.carp':'explain_clinical_doc_carp',
            'en.explain_doc.era':'explain_clinical_doc_era',
            # 'en.explain_doc.ade':'explain_clinical_doc_ade', # todo wierd 2x Converter 1x NER pipe, messes up pipe logic






        },
    }
    # map storage ref to nlu ref

    storage_ref_2_nlu_ref = {
        'en': {
            'tfhub_use'         : 'en.embed_sentence.use',
            'glove_100d'        : 'en.embed.glove.100d',


        },
        'zh': {
            'bert_base_chinese' : 'zh.embed',
        },
        'th':{
            'tfhub_use_multi_lg' :'xx.use.multi'

        }


    }  #

    licensed_storage_ref_2_nlu_ref = {
        'en': {
            'clinical': 'en.embed.glove.clinical',
            'biobert_pubmed_base_cased': 'biobert',

            # 'embeddings_healthcare100' : 'en.embed.glove.clinical',
            'embeddings_healthcare100': 'en.embed.glove.healthcare_100d',
            'BERT_SENTENCE_EMBEDDINGS_0bee53f1b2cc': 'en.embed_sentence.biobert.mli',
            # 'BERT_SENTENCE_EMBEDDINGS_0bee53f1b2cc': 'en.embed_sentence.biobert.pubmed_base_cased',
            'BERT_SENTENCE_EMBEDDINGS_59c3cd1e17c4' : 'en.embed_sentence.bluebert.mli',
            'RelationExtractionModel_3ab4750ad5b6': 'en.embed.glove.clinical',
            'RelationExtractionModel_6b61602c8303': 'en.embed.glove.clinical',
            'RelationExtractionModel_9c255241fec3': 'en.embed.glove.clinical',
            # 'bert_base_cased' : 'en.embed.glove.clinical'
            'bert_base_cased': 'en.embed.bert.base_cased',


        },

    }


